@@ -11,7 +11,7 @@
 
 
 static void AboutDialogOKCB(GtkWidget *widget, gpointer data);
-static gint AboutDialogCloseCB(
+static gint AboutDialogDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
 );
 
@@ -30,7 +30,7 @@ void AboutDialogDelete(about_dialog_struct *ad);
  */
 static void AboutDialogOKCB(GtkWidget *widget, gpointer data)
 {
-	about_dialog_struct *ad = (about_dialog_struct *)data;
+	about_dialog_struct *ad = ABOUT_DIALOG(data);
 	if(ad == NULL)
 	    return;
 
@@ -38,20 +38,19 @@ static void AboutDialogOKCB(GtkWidget *widget, gpointer data)
 }
 
 /*
- *	Close callback.
+ *	"delete_event" signal callback.
  */
-static gint AboutDialogCloseCB(
+static gint AboutDialogDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
 )
 {
 	AboutDialogOKCB(widget, data);
-
 	return(TRUE);
 }
 
 
 /*
- *	Create a new about dialog.
+ *	Creates a new About Dialog.
  */
 about_dialog_struct *AboutDialogNew(void *core_ptr)
 {
@@ -61,18 +60,17 @@ about_dialog_struct *AboutDialogNew(void *core_ptr)
 	gchar version_string[256];
 	medit_cursors_list_struct *cursors_list = NULL;
 	medit_styles_list_struct *styles_list = NULL;
-	about_dialog_struct *ad = (about_dialog_struct *)g_malloc0(
+	about_dialog_struct *ad = ABOUT_DIALOG(g_malloc0(
 	    sizeof(about_dialog_struct)
-	);
+	));
 	if(ad == NULL)
 	    return(NULL);
 
-
-	/* Get pointers to resources on core structure */
+	/* Get resources from the core */
 	if(core_ptr != NULL)
 	{
-	    cursors_list = &((medit_core_struct *)core_ptr)->cursors_list;
-	    styles_list = &((medit_core_struct *)core_ptr)->styles_list;
+	    cursors_list = &MEDIT_CORE(core_ptr)->cursors_list;
+	    styles_list = &MEDIT_CORE(core_ptr)->styles_list;
 	}
 
 	/* Reset values */
@@ -80,8 +78,7 @@ about_dialog_struct *AboutDialogNew(void *core_ptr)
 	ad->map_state = FALSE;
 
 	/* Toplevel */
-	w = gtk_window_new(GTK_WINDOW_DIALOG);
-	ad->toplevel = w;
+	ad->toplevel = w = gtk_window_new(GTK_WINDOW_DIALOG);
 	gtk_widget_realize(w);
 	window = w->window;
 	if(window != NULL)
@@ -99,7 +96,7 @@ about_dialog_struct *AboutDialogNew(void *core_ptr)
 	GUISetWMIcon(w->window, (guint8 **)manedit_48x48_xpm);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "delete_event",
-	    GTK_SIGNAL_FUNC(AboutDialogCloseCB), ad
+	    GTK_SIGNAL_FUNC(AboutDialogDeleteEventCB), ad
 	);
 	parent = w;
 
@@ -246,10 +243,6 @@ void AboutDialogDelete(about_dialog_struct *ad)
 	    return;
 
 	GTK_WIDGET_DESTROY(ad->ok_btn)
-	ad->ok_btn = NULL;
-
 	GTK_WIDGET_DESTROY(ad->toplevel)
-	ad->toplevel = NULL;
-
 	g_free(ad);
 }
