@@ -5,16 +5,14 @@
 #ifndef EDITOR_H
 #define EDITOR_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
-
 #include "editorfip.h"
 
 
 /*
- *	Editor ctree item types:
+ *	Editor sections GtkCTree item types:
  */
-#define EditorItemTypeFile	0	/* Main trunk. */
+#define EditorItemTypeFile	0	/* Main trunk */
 #define EditorItemTypeHeader	1
 #define EditorItemTypeSection	2
 
@@ -26,45 +24,44 @@
  *
  *	When adding new members be sure to update functions
  *	EditorItemNew(), EditorItemDup(), and EditorItemDelete()
- *	so that they properly allocate, duplicate, and deallocate the
+ *	so that they properly allocate, duplicate, and delete the
  *	new members.
  *
  *	Note that not all members who are pointers should be
- *	deallocated.
+ *	deleted.
  */
 typedef struct {
 
-	gint type;		/* One of EditorItemType*. */
-	gpointer editor_ptr;	/* Pointer back to editor. */
-	gboolean has_changes;
+	gint		type;		/* One of EditorItemType* */
+	gpointer	editor_ptr;	/* Pointer back to editor */
+	gboolean	has_changes;
 
-	GtkCTree *ctree;		/* Pointer back to parent ctree. */
-	GtkCTreeNode *parent;		/* Parent branch. */
-	GtkCTreeNode *this_branch;	/* Pointer back to this item. */
-	gboolean is_leaf;
+	GtkCTree	*ctree;		/* Pointer back to parent ctree */
+	GtkCTreeNode	*parent;	/* Parent branch */
+	GtkCTreeNode	*this_branch;	/* Pointer back to this item */
+	gboolean	is_leaf;
 
-	/* Members for type EditorItemTypeFile. */
-	gchar *file_name;	/* Just the file's name without a path. */
-	gchar *file_name_full;	/* Full path to file, if this is NULL
-				 * then it implies it's never been
-				 * saved before.
-				 */
+	/* Members for type EditorItemTypeFile */
+	gchar		*file_name;	/* File name without path */
+	gchar		*file_name_full;	/* If NULL then implies it's
+						 * never been saved before */
 
-	/* Members for type EditorItemTypeHeader. */
-	gchar *header_name;
-	gchar *header_section_number;
-	gchar *header_version;
-	gchar *header_author;
-	gchar *header_catagory;
+	/* Members for type EditorItemTypeHeader */
+	gchar		*header_name;
+	gchar		*header_section_number;
+	gchar		*header_version;
+	gchar		*header_author;
+	gchar		*header_catagory;
 
-	/* Members for type EditorItemTypeSection. */
-	gchar *section_name;
+	/* Members for type EditorItemTypeSection */
+	gchar		*section_name;
 
-	/* Common members. */
-	gchar **line;
-	gint total_lines;
+	/* Common members */
+	gchar		**line;
+	gint		total_lines;
 
 } editor_item_struct;
+#define EDITOR_ITEM(p)		((editor_item_struct *)(p))
 
 
 /*
@@ -72,59 +69,62 @@ typedef struct {
  */
 typedef struct {
 
-	gboolean initialized;
-	gboolean map_state;
-	gboolean processing;
-	gboolean syntax_highlighting;
+	gboolean	initialized,
+			map_state,
+			processing,
+			syntax_highlighting;
 
-	gpointer core_ptr;
-	gint viewer_num;	/* Number of manual page viewer on the
-				 * core structure (can be -1 for none).
-				 */
+	gpointer	core_ptr;
+	gint		viewer_num;	/* Index of spawned manual page viewer
+					 * (can be -1 for none) */
 
-	GtkWidget *toplevel;
-	GtkWidget *main_vbox;
+	GtkWidget	*toplevel,
+			*main_vbox;
 
-	GtkWidget *menu_bar_dock, *menu_bar;
-	GtkWidget *tool_bar_dock, *tool_bar;
+	GtkWidget	*menu_bar_dock,
+			*menu_bar,
+			*tool_bar_dock,
+			*tool_bar;
 
-	GtkWidget *layout_ctree;
+	GtkWidget	*layout_ctree;
 
 	/* List of trunk branch nodes on the layout ctree, these may
 	 * not be in any particular order and not in sync on the
-	 * ctree. These should all have user item data type set to
-	 * EditorItemTypeFile, which implies the number of files loaded.
+	 * ctree
+	 *
+	 * These should all have user item data type set to
+	 * EditorItemTypeFile, which implies the number of files loaded
 	 */
-	GtkCTreeNode **layout_trunk;
-	gint total_layout_trunks;
+	GtkCTreeNode	**layout_trunk;
+	gint		total_layout_trunks;
 
-	GtkCTreeNode *selected_branch;	/* NULL for none. */
+	GtkCTreeNode	*selected_branch;	/* Can be NULL for none */
 
 	/* Right pane editing widgets parent, note the type
 	 * corresponds to EditorItemType* and maximum is
 	 * MEDIT_EDIT_PANEL_MAX which must be one greater than
-	 * the highest EditorItemType* code.
+	 * the highest EditorItemType* code
 	 */
 #define MEDIT_EDIT_PANEL_MAX	3
-	GtkWidget *edit_panel_vbox[MEDIT_EDIT_PANEL_MAX];
+	GtkWidget	*edit_panel_vbox[MEDIT_EDIT_PANEL_MAX];
 
 	GtkWidget	*header_name_entry,
 			*header_section_number_entry,
 			*header_version_entry,
 			*header_author_entry,
 			*header_catagory_entry,
-			*header_text;	/* For comments. */
+			*header_text;	/* For comments */
 
 	GtkWidget	*section_name_entry,
 			*section_text;
 
-	/* Syntax highlight timeout callback values. */
-	guint synhl_timeout_cb_id;	/* None if (guint)(-1). */
-	gint synhl_timeout_cb_cursor_pos;
-	gint synhl_timeout_cb_start_pos;
-	gint synhl_timeout_cb_end_pos;
+	/* Syntax highlight timeout callback values */
+	guint		synhl_timeout_cb_id;	/* None if (guint)(-1) */
+	gint		synhl_timeout_cb_cursor_pos;
+	gint		synhl_timeout_cb_start_pos;
+	gint		synhl_timeout_cb_end_pos;
 
-	/* Important menu items. */
+	/* Important menu items */
 	GtkWidget	*file_mh,
 			*new_mi,
 			*new_from_template_mi,
@@ -175,7 +175,7 @@ typedef struct {
                         *windows_new_editor,
                         *windows_new_viewer;
 
-	/* Tool bar buttons. */
+	/* Tool bar buttons */
 	GtkWidget	*new_btn,
 			*new_btn_new_menu,
 			*new_btn_new_mi,
@@ -199,7 +199,7 @@ typedef struct {
 
 			*preview_btn;
 
-	/* Formatting bar buttons. */
+	/* Formatting bar buttons */
 	GtkWidget	*fmt_bar_dock,
 			*fmt_bar,
 			*fmt_pl_btn,
@@ -214,7 +214,7 @@ typedef struct {
 			*fmt_gt_btn,
 			*fmt_strip_tags_btn;
 
-	/* Search bar. */
+	/* Search bar */
 	GtkWidget	*find_bar_dock,
 			*find_bar,
 			*find_combo,
@@ -223,18 +223,18 @@ typedef struct {
 			*replace_btn,
 			*replace_all_btn;
 
-	/* Find bar button find menu. */
+	/* Find bar button find menu */
 	GtkWidget	*find_bar_find_menu,
 			*find_bar_find_in_pages_mi;
 
-	/* Find bar button replace menu. */
+	/* Find bar button replace menu */
 	GtkWidget       *find_bar_replace_menu,
                         *find_bar_replace_entire_page_mi;
 
-	/* Right-click menus. */
+	/* Right-click menus */
 	GtkWidget *layout_menu, *edit_panel_menu;
 
-	/* Important menu items on right-click menus. */
+	/* Important menu items on right-click menus */
 	GtkWidget	*layout_menu_expand_mi,
 			*layout_menu_preview_mi,
 			*layout_menu_add_header_mi,
@@ -258,7 +258,7 @@ typedef struct {
 			*edit_panel_paste_mi,
 			*edit_panel_select_all_mi,
 			*edit_panel_unselect_all_mi;
-	/* Format submenu on edit panel menu. */
+	/* Format submenu on edit panel menu */
 	GtkWidget	*edit_panel_fmt_sub_menu,
                         *edit_panel_fmt_pl_mi,
                         *edit_panel_fmt_pr_mi,
@@ -272,34 +272,34 @@ typedef struct {
                         *edit_panel_fmt_gt_mi,
 			*edit_panel_fmt_strip_tags_mi;
 
-	/* Status bar. */
+	/* Status bar */
 	GtkWidget	*status_bar_dock,
-			*status_bar_toplevel,	/* An hbox. */
+			*status_bar_toplevel,	/* An hbox */
 			*status_bar_progress,
 			*status_bar_label,
 			*status_bar_cursor_label;
 
-	/* Last progress position value from 0.0 to 1.0. */
-	gfloat status_bar_progress_pos_last;
+	/* Last progress position value from 0.0 to 1.0 */
+	gfloat		status_bar_progress_pos_last;
 
-	/* Undo/redo structures. */
-	gpointer *undo;
-	gint total_undos;
+	/* Undo/redo structures */
+	gpointer	*undo;
+	gint		total_undos;
 
-	gpointer *redo;
-	gint total_redos;
+	gpointer	*redo;
+	gint		total_redos;
 
-	gint max_undos;	/* Maximum undos and maximum redos. */
+	gint		max_undos;	/* Maximum undos and maximum redos */
 
 
-	/* Last open file path. */
-	gchar *last_open_path;
+	/* Last open file path */
+	gchar		*last_open_path;
 
-	/* Last save as file path. */
-	gchar *last_save_as_path;
+	/* Last save as file path */
+	gchar		*last_save_as_path;
 
 
-	/* Editor Find In Pages dialog. */
+	/* Editor Find In Pages dialog */
 	editor_fip_struct *fip_dialog;
 
 } editor_struct;
@@ -320,13 +320,13 @@ typedef struct {
 
 
 extern editor_item_struct *EditorItemNew(
-        gint type,		/* One of EditorItemType*. */
+        gint type,		/* One of EditorItemType* */
         editor_struct *editor,
-        GtkCTree *ctree,	/* Pointer back to parent ctree. */
-        GtkCTreeNode *parent,	/* Parent branch. */
-        GtkCTreeNode *this_branch,	/* Pointer back to this item. */
+        GtkCTree *ctree,	/* Pointer back to parent ctree */
+        GtkCTreeNode *parent,	/* Parent branch */
+        GtkCTreeNode *this_branch,	/* Pointer back to this item */
         gboolean is_leaf,
-        gchar **line,		/* Eatened, not copied. */
+        gchar **line,		/* Eatened, not copied */
         gint total_lines
 );
 extern editor_item_struct *EditorItemDup(editor_item_struct *item);
