@@ -1,8 +1,5 @@
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
 #include "../include/string.h"
@@ -22,48 +19,48 @@
 #include "config.h"
 
 
-/* Recieved data command string parsing. */
+/* Recieved data command string parsing */
 void EditorDNDParseCmd(
-	const char *string,
+	const gchar *string,
 	editor_struct **editor_ptr,
-	GtkCTreeNode ***branch, int *total_branches
+	GtkCTreeNode ***branch, gint *total_branches
 );
 gchar *EditorDNDParseURL(
 	const gchar *string, gint len
 );
 
-/* Inserting to target editor routines. */
+/* Inserting to target editor routines */
 static GtkCTreeNode *EditorDNDItemAdd(
 	editor_struct *editor, editor_item_struct *item_ptr,
 	GtkCTreeNode *parent, GtkCTreeNode *sibling
 );
 static void EditorDNDItemListAdd(
 	editor_struct *editor,
-	editor_item_struct **item, int total_items,
-	int insert_row
+	editor_item_struct **item, gint total_items,
+	gint insert_row
 );
 static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	medit_pixmaps_list_struct *pixmaps_list,
 	editor_struct *editor, editor_struct *src_editor,
 	GtkCTree *ctree, GtkCTree *src_ctree,
-	GtkCTreeNode *parent_branch,    /* Parent on target editor. */
-	GtkCTreeNode *sibling_branch,   /* Sibling to insert before. */
-	GtkCTreeNode *src_branch        /* From source editor. */
+	GtkCTreeNode *parent_branch,    /* Parent on target editor */
+	GtkCTreeNode *sibling_branch,   /* Sibling to insert before */
+	GtkCTreeNode *src_branch        /* From source editor */
 );
 static void EditorDNDTrunkListAdd(
 	editor_struct *editor,
 	editor_struct *src_editor,
-	GtkCTreeNode **branch, int total_branches,
-	int insert_row
+	GtkCTreeNode **branch, gint total_branches,
+	gint insert_row
 );
 static void EditorDNDViewerIndexItemLoad(
 	editor_struct *editor, viewer_struct *src_v,
-	GtkCTreeNode **branch, int total_branches,
-	int insert_row
+	GtkCTreeNode **branch, gint total_branches,
+	gint insert_row
 );
 
 
-/* DND handling. */
+/* DND handling */
 void EditorDNDSetIcon(
 	editor_struct *editor, editor_item_struct *item_ptr
 );
@@ -82,7 +79,7 @@ void EditorDNDDataRecievedCB(
 );
 static void EditorDNDDoDeleteItems(
 	editor_struct *editor,   
-	GtkCTreeNode **branch, int total_branches 
+	GtkCTreeNode **branch, gint total_branches 
 );
 void EditorDNDDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
@@ -102,22 +99,22 @@ void EditorDNDDataDeleteCB(
  *	EditorDNDDataRecievedCB().
  */
 void EditorDNDParseCmd(
-	const char *string,
+	const gchar *string,
 	editor_struct **editor_ptr,
-	GtkCTreeNode ***branch, int *total_branches
+	GtkCTreeNode ***branch, gint *total_branches
 )
 {
-	u_int32_t addr_val;
-	int i, n, strc;
-	char **strv;
+	guint32 addr_val;
+	gint i, n, strc;
+	gchar **strv;
 
-	/* Reset returns. */
+	/* Reset returns */
 	if(editor_ptr != NULL)
-	    (*editor_ptr) = NULL;
+	    *editor_ptr = NULL;
 	if(branch != NULL)
-	    (*branch) = NULL;
+	    *branch = NULL;
 	if(total_branches != NULL)
-	    (*total_branches) = 0;
+	    *total_branches = 0;
 
 	if(string == NULL)
 	    return;
@@ -132,26 +129,26 @@ void EditorDNDParseCmd(
 	if(strv == NULL)
 	    return;
 
-	/* Get editor_ptr (format in hex with no "0x" prefix). */
+	/* Get editor_ptr (format in hex with no "0x" prefix) */
 	if(strc > 0)
-	    i = sscanf(strv[0], "%x", (u_int32_t *)&addr_val);
+	    i = sscanf(strv[0], "%x", (guint32 *)&addr_val);
 	else
 	    i = 0;
 	if((i > 0) && (editor_ptr != NULL))
-	    (*editor_ptr) = (editor_struct *)addr_val;
+	    *editor_ptr = EDITOR(addr_val);
 
 	/* Get list of branch pointers which should be branches
-	 * on the parsed editor's layout ctree.
+	 * on the parsed editor's layout ctree
 	 */
 	if((branch != NULL) && (total_branches != NULL))
 	{
-	    const char *cstrptr;
+	    const gchar *cs;
 
-	    /* Start at parsed argument number 1. */
+	    /* Start at parsed argument number 1 */
 	    for(i = 1; i < strc; i++)
 	    {
-		cstrptr = (const char *)strv[i];
-		if(cstrptr == NULL)
+		cs = (const gchar *)strv[i];
+		if(cs == NULL)
 		    continue;
 
 		n = (*total_branches);
@@ -167,7 +164,7 @@ void EditorDNDParseCmd(
 		}
 		else
 		{
-		    i = sscanf(cstrptr, "%x", (u_int32_t *)&addr_val);
+		    i = sscanf(cs, "%x", (guint32 *)&addr_val);
 		    if(i > 0)
 			(*branch)[n] = (GtkCTreeNode *)addr_val;
 		    else
@@ -176,7 +173,7 @@ void EditorDNDParseCmd(
 	    }
 	}
 
-	/* Free exploded string. */
+	/* Free exploded string */
 	strlistfree(strv, strc);
 }
 
@@ -188,32 +185,32 @@ gchar *EditorDNDParseURL(
 	const gchar *string, gint len
 )
 {
-	const gchar *cstrptr, *cstrptr2;
+	const gchar *cs, *cs2;
 
 
 	if(string == NULL)
 	    return(NULL);
 
-	cstrptr = strstr(string, "://");
-	if(cstrptr == NULL)
-	    cstrptr = string;
+	cs = strstr(string, "://");
+	if(cs == NULL)
+	    cs = string;
 	else
-	    cstrptr += strlen("://");
+	    cs += strlen("://");
 
-	cstrptr2 = strchr(cstrptr, '/');
-	if(cstrptr2 == NULL)
-	    cstrptr2 = cstrptr;
+	cs2 = strchr(cs, '/');
+	if(cs2 == NULL)
+	    cs2 = cs;
 
-	return(g_strdup(cstrptr2));
+	return(g_strdup(cs2));
 }
 
 
 /*
  *      Adds the specified item the editor's layout ctree at the specified
- *	insert row. The given item's referances to the editor and widgets
+ *	insert row. The given item's reference to the editor and widgets
  *	will be updated here.
  *
- *      The pointer to the given item should not be referanced again
+ *      The pointer to the given item should not be referenced again
  *      after calling this function.
  *
  *	Inputs assumed valid.
@@ -246,13 +243,13 @@ static GtkCTreeNode *EditorDNDItemAdd(
 	pixmaps_list = &core_ptr->pixmaps_list;
 
 
-	/* Reset name for new branch, it'll be picked below. */
+	/* Reset name for new branch, it'll be picked below */
 	text[0] = NULL;
 
 	/* Item data valid? */
 	if(item_ptr != NULL)
 	{
-	    /* Handle by item data type. */
+	    /* Handle by item data type */
 	    switch(item_ptr->type)
 	    {
 	      case EditorItemTypeFile:
@@ -281,7 +278,7 @@ static GtkCTreeNode *EditorDNDItemAdd(
 	    }
 	}
 
-	/* Create new branch node on the layout ctree. */
+	/* Create new branch node on the layout ctree */
 	if(text[0] == NULL)
 	    text[0] = "New";
 	branch = gtk_ctree_insert_node(
@@ -290,8 +287,8 @@ static GtkCTreeNode *EditorDNDItemAdd(
 	    MEDIT_LIST_ICON_TEXT_SPACING,
 	    closed_p, closed_m,
 	    opened_p, opened_m,
-	    (item_ptr != NULL) ? item_ptr->is_leaf : TRUE,	/* Is leaf. */
-	    FALSE		/* Expanded. */
+	    (item_ptr != NULL) ? item_ptr->is_leaf : TRUE,	/* Is leaf */
+	    FALSE		/* Expanded */
 	);
 
 	/* Update values on the given item data structure to reflect
@@ -310,24 +307,24 @@ static GtkCTreeNode *EditorDNDItemAdd(
 	    /* Item of type file? */
 	    if(item_ptr->type == EditorItemTypeFile)
 	    {
-		/* Need to add this to the editor's layout_trunk list. */
+		/* Need to add this to the editor's layout_trunk list */
 
 /* Need to work on this, currently we can't copy items of type
  * EditorItemTypeFile. They will just be swaped.
  */
-printf("Cannot copy item of type EditorItemTypeFile yet.\n");
+g_printerr("Cannot copy item of type EditorItemTypeFile yet.\n");
 
 	    }
 	}
 
-	/* Set item data to newly inserted branch. */
+	/* Set item data to newly inserted branch */
 	EditorBranchSetData(
 	    ctree, branch,
 	    item_ptr, EditorItemDestroyCB
 	);   
 	item_ptr = NULL;
 
-	/* Mark new branch's item data as having changes. */
+	/* Mark new branch's item data as having changes */
 	EditorItemSetToplevelHasChanges(
 	    editor, branch, TRUE
 	);
@@ -337,22 +334,22 @@ printf("Cannot copy item of type EditorItemTypeFile yet.\n");
 
 /*
  *      Adds the list of items to the given editor's layout ctree.
- *	Each item's referances to the editor and widgets will be updated
+ *	Each item's reference to the editor and widgets will be updated
  *	by this call.
  *
  *      The given list of items will be transfered and should not
- *      longer be referanced (including the pointer array) after calling
+ *      longer be referenced (including the pointer array) after calling
  *      this function.
  *
  *	Only headers and sections (leafs, no trunks) can be added.
  */
 static void EditorDNDItemListAdd(
 	editor_struct *editor,
-	editor_item_struct **item, int total_items,
-	int insert_row
+	editor_item_struct **item, gint total_items,
+	gint insert_row
 )
 {
-	int i;
+	gint i;
 	GtkCTreeNode *parent_node;
 	GtkCList *clist;
 	GtkCTree *ctree;
@@ -361,34 +358,34 @@ static void EditorDNDItemListAdd(
 	{
 	    for(i = 0; i < total_items; i++)
 		EditorItemDelete(item[i]);
-	    free(item);
+	    g_free(item);
 	    return;
 	}
 
-	/* Get pointer to layout ctree. */
+	/* Get pointer to layout ctree */
 	ctree = (GtkCTree *)editor->layout_ctree;
 	clist = (GtkCList *)ctree;
 	if(ctree == NULL)
 	{
 	    for(i = 0; i < total_items; i++)
 		EditorItemDelete(item[i]);
-	    free(item);
+	    g_free(item);
 	    return;
 	}
 
 
-	/* Clip insert row. */
+	/* Clip insert row */
 	if(insert_row < 0)
 	    insert_row = 0;
 
-	/* Begin inserting. */
+	/* Begin inserting */
 	if(1)
 	{
-	    /* Insert at start or in the middle. */
+	    /* Insert at start or in the middle */
 	    GtkCTreeNode *insert_node;
 	    GtkCTreeRow *insert_node_row;
 
-	    /* Match insert row with the node to insert at. */
+	    /* Match insert row with the node to insert at */
 	    if(insert_row >= clist->rows)
 		insert_node = gtk_ctree_node_nth(
 		    ctree, MAX(clist->rows - 1, 0)
@@ -399,7 +396,7 @@ static void EditorDNDItemListAdd(
 	    {
 		for(i = 0; i < total_items; i++)
 		    EditorItemDelete(item[i]);
-		free(item);
+		g_free(item);
 		return;
 	    }
 	    else
@@ -409,7 +406,7 @@ static void EditorDNDItemListAdd(
 		{
 		    for(i = 0; i < total_items; i++)
 			EditorItemDelete(item[i]);
-		    free(item);
+		    g_free(item);
 		    return;
 		}
 	    }
@@ -424,8 +421,8 @@ static void EditorDNDItemListAdd(
 		 * insert at the end.
 		 */
 		parent_node = insert_node_row->parent;
-		insert_node = insert_node_row->sibling;	/* New insert node. */
-		/* Insert last to first. */
+		insert_node = insert_node_row->sibling;	/* New insert node */
+		/* Insert last to first */
 		for(i = total_items - 1; i >= 0; i--)
 		{
 		    insert_node = EditorDNDItemAdd(
@@ -442,7 +439,7 @@ static void EditorDNDItemListAdd(
 		 */
 		parent_node = insert_node;
 		insert_node = insert_node_row->children;
-		/* Insert last to first. */
+		/* Insert last to first */
 		for(i = total_items - 1; i >= 0; i--)
 		{
 		    insert_node = EditorDNDItemAdd(
@@ -456,12 +453,10 @@ static void EditorDNDItemListAdd(
 	    gtk_clist_thaw(clist);
 	}
 
-	/* Free just the list of items. */
-	free(item);
+	/* Delete the item list */
+	g_free(item);
 	item = NULL;
 	total_items = 0;
-
-	return;
 }
 
 
@@ -479,9 +474,9 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	medit_pixmaps_list_struct *pixmaps_list,
 	editor_struct *editor, editor_struct *src_editor,
 	GtkCTree *ctree, GtkCTree *src_ctree,
-	GtkCTreeNode *parent_branch,	/* Parent on target editor. */
-	GtkCTreeNode *sibling_branch,	/* Sibling to insert before. */
-	GtkCTreeNode *src_branch	/* From source editor. */
+	GtkCTreeNode *parent_branch,	/* Parent on target editor */
+	GtkCTreeNode *sibling_branch,	/* Sibling to insert before */
+	GtkCTreeNode *src_branch	/* From source editor */
 )
 {
 	editor_item_struct *item_ptr, *src_item_ptr;
@@ -497,7 +492,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 
 	branch_row = GTK_CTREE_ROW(src_branch);
 
-	/* Get source item pointer from source branch. */
+	/* Get source item pointer from source branch */
 	src_item_ptr = EditorBranchGetData(
 	    src_ctree, src_branch
 	);
@@ -507,7 +502,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	/* Item data valid? */
 	if(src_item_ptr != NULL)
 	{
-	    /* Handle by item data type. */
+	    /* Handle by item data type */
 	    switch(src_item_ptr->type)
 	    {
 	      case EditorItemTypeFile:
@@ -536,11 +531,11 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	    }
 	}
 
-	/* Create new branch node on the layout ctree. */
+	/* Create new branch node on the layout ctree */
 	if(text[0] == NULL)
 	    text[0] = "New";
 
-	/* Insert a new branch on target editor's layout_ctree. */
+	/* Insert a new branch on target editor's layout_ctree */
 	new_branch = gtk_ctree_insert_node(
 	    ctree, parent_branch, sibling_branch,
 	    text,
@@ -551,7 +546,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	    (branch_row != NULL) ? branch_row->expanded : FALSE
 	);
 
-	/* Set item data to newly inserted branch. */
+	/* Set item data to newly inserted branch */
 	item_ptr = EditorItemDup(src_item_ptr);
 	if(item_ptr != NULL)
 	{
@@ -570,7 +565,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	);
 	item_ptr = NULL;
 
-	/* Mark new branch's item data as having changes. */
+	/* Mark new branch's item data as having changes */
 	EditorItemSetToplevelHasChanges(
 	    editor, new_branch, TRUE
 	);
@@ -587,7 +582,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 
 	    sibling_branch = NULL;
 
-	    /* Update source branch to point to the first child. */
+	    /* Update source branch to point to the first child */
 	    src_branch = branch_row->children;
 
 	    /* Add each child branch on source editor to the target
@@ -604,7 +599,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 		    src_branch
 		);
 
-		/* Get next sibling on source editor. */
+		/* Get next sibling on source editor */
 		branch_row = GTK_CTREE_ROW(src_branch);
 		if(branch_row != NULL)
 		    src_branch = branch_row->sibling;
@@ -619,7 +614,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 /*
  *      Adds the list of branches (which all must be of type
  *	EditorItemTypeFile) to the given editor's layout ctree. Each
- *	branch item's referances to the editor and widgets will be updated
+ *	branch item's reference to the editor and widgets will be updated
  *      by this call.
  *
  *      The given list of branch pointers will not be modified by this
@@ -628,11 +623,11 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 static void EditorDNDTrunkListAdd(
 	editor_struct *editor,
 	editor_struct *src_editor,
-	GtkCTreeNode **branch, int total_branches,
-	int insert_row
+	GtkCTreeNode **branch, gint total_branches,
+	gint insert_row
 )
 {
-	int i, n;
+	gint i, n;
 	GtkCTreeNode *sibling_branch;
 	GtkCList *clist, *src_clist;
 	GtkCTree *ctree, *src_ctree;
@@ -645,37 +640,37 @@ static void EditorDNDTrunkListAdd(
 	)
 	    return;
 
-	/* Get pointer to layout ctree on target editor. */
+	/* Get pointer to layout ctree on target editor */
 	ctree = (GtkCTree *)editor->layout_ctree;
 	clist = (GtkCList *)ctree;
 	if(ctree == NULL)
 	    return;
 
-	/* Get pointer to layout ctree on source editor. */
+	/* Get pointer to layout ctree on source editor */
 	src_ctree = (GtkCTree *)src_editor->layout_ctree;
 	src_clist = (GtkCList *)src_ctree;
 	if(src_ctree == NULL)
 	    return;
 
-	/* Get pointer to core structure on target editor. */
+	/* Get pointer to core structure on target editor */
 	core_ptr = (medit_core_struct *)editor->core_ptr;
 	if(core_ptr == NULL)
 	    return;
 	else
 	    pixmaps_list = &core_ptr->pixmaps_list;
 
-	/* Clip insert row. */
+	/* Clip insert row */
 	if(insert_row < 0)
 	    insert_row = 0;
 
-	/* Begin inserting. */
+	/* Begin inserting */
 	if(1)
 	{               
-	    /* Insert at start or in the middle. */
+	    /* Insert at start or in the middle */
 	    GtkCTreeNode *insert_node;
 	    GtkCTreeRow *insert_node_row;
 
-	    /* Match insert row with the node to insert at. */
+	    /* Match insert row with the node to insert at */
 	    if(insert_row >= clist->rows)
 		insert_node = gtk_ctree_node_nth(
 		    ctree, MAX(clist->rows - 1, 0)
@@ -711,12 +706,12 @@ static void EditorDNDTrunkListAdd(
 		    pixmaps_list,
 		    editor, src_editor,
 		    ctree, src_ctree,
-		    NULL,		/* Parent branch. */
-		    sibling_branch,	/* Insert before this branch. */
-		    branch[i]		/* Branch to copy and insert. */
+		    NULL,		/* Parent branch */
+		    sibling_branch,	/* Insert before this branch */
+		    branch[i]		/* Branch to copy and insert */
 		);
 
-		/* Add trunk branch to editor's list of layout trunks. */
+		/* Add trunk branch to editor's list of layout trunks */
 		if(editor->total_layout_trunks < 0)
 		    editor->total_layout_trunks = 0;
 		n = editor->total_layout_trunks;
@@ -737,8 +732,6 @@ static void EditorDNDTrunkListAdd(
 
 	    gtk_clist_thaw(clist);
 	}
-
-	return;
 }
 
 /*
@@ -751,11 +744,11 @@ static void EditorDNDTrunkListAdd(
  */
 static void EditorDNDViewerIndexItemLoad(
 	editor_struct *editor, viewer_struct *src_v,
-	GtkCTreeNode **branch, int total_branches,
-	int insert_row
+	GtkCTreeNode **branch, gint total_branches,
+	gint insert_row
 )
 {
-	int i;
+	gint i;
 	GtkCList *clist, *src_clist;
 	GtkCTree *ctree, *src_ctree;
 	viewer_index_item_struct *item_ptr;
@@ -766,29 +759,29 @@ static void EditorDNDViewerIndexItemLoad(
 	)
 	    return;
 
-	/* Get pointer to target editor's layout ctree. */
+	/* Get pointer to target editor's layout ctree */
 	ctree = (GtkCTree *)editor->layout_ctree;
 	clist = (GtkCList *)ctree;
 	if(ctree == NULL)
 	    return;
 
-	/* Get pointer to source viewer's index ctree. */
+	/* Get pointer to source viewer's index ctree */
 	src_ctree = (GtkCTree *)src_v->index_ctree;
 	src_clist = (GtkCList *)src_ctree;
 	if(src_ctree == NULL)
 	    return;
 
-	/* Clip insert row. */
+	/* Clip insert row */
 	if(insert_row < 0)
 	    insert_row = 0;
 
-	/* Begin inserting. */
+	/* Begin inserting */
 	if(1)
 	{
-	    /* Insert at start or in the middle. */
+	    /* Insert at start or in the middle */
 	    GtkCTreeNode *insert_node;
 
-	    /* Get branch pointer to insert after (can be NULL). */
+	    /* Get branch pointer to insert after (can be NULL) */
 	    if(insert_row >= clist->rows)
 		insert_node = gtk_ctree_node_nth(
 		    ctree, MAX(clist->rows - 1, 0)
@@ -830,8 +823,6 @@ static void EditorDNDViewerIndexItemLoad(
 		}
 	    }
 	}
-
-	return;
 }
 
 
@@ -870,7 +861,7 @@ void EditorDNDSetIcon(
 	    switch(item_ptr->type)
 	    {
 	      case EditorItemTypeFile:
-/* Check if opened or closed. */
+/* Check if opened or closed */
 		pixmap = pixmaps_list->manual_closed_20x20;
 		mask = pixmaps_list->manual_closed_20x20_mask;
 		break;
@@ -892,9 +883,9 @@ void EditorDNDSetIcon(
 
 		gdk_window_get_size((GdkWindow *)pixmap, &w, &h);
 
-		/* Need to increase referance count on pixmap and mask
+		/* Need to increase reference count on pixmap and mask
 		 * pair since the call to gtk_drag_set_default_icon() will
-		 * reduce the referance count by one after one drag and
+		 * reduce the reference count by one after one drag and
 		 * drop operation has completed.
 		 */
 		gdk_pixmap_ref(pixmap);
@@ -906,8 +897,6 @@ void EditorDNDSetIcon(
 		);
 	    }
 	}
-
-	return;
 }
 
 
@@ -929,9 +918,8 @@ void EditorDNDDataRequestCB(
 {
 	gboolean data_sent = FALSE;
 	gchar *buf;
-	gint buf_len;
 	GtkCTreeNode *branch_ptr;
-	editor_struct *editor = (editor_struct *)data;
+	editor_struct *editor = EDITOR(data);
 	if((widget == NULL) || (editor == NULL) || (dc == NULL))
 	    return;
 
@@ -940,8 +928,7 @@ void EditorDNDDataRequestCB(
 
 	if(widget != editor->layout_ctree)
 	{
-	    fprintf(
-		stderr,
+	    g_printerr(
 		"EditorDNDDataRequestCB(): widget != editor->layout_ctree\n"
 	    );
 	    return;
@@ -949,76 +936,65 @@ void EditorDNDDataRequestCB(
 
 	/* Get selected branch on editor's layout ctree.
 	 * Note currently we only allow one selected branch at
-	 * a time.
+	 * a time
 	 */
 	branch_ptr = editor->selected_branch;
 
 	/* Need to apply values if this is the selected branch to ensure
 	 * we send out a command with a branch pointer who's data is up
-	 * to date.
+	 * to date
 	 */
 	if(branch_ptr == editor->selected_branch)
 	{
 	    /* Fetch values from the editor's widgets and place them to
 	     * the branch data depending on its type. Menus will be
-	     * updated.
+	     * updated
 	     */
 	    EditorDoApplyValues(editor, branch_ptr);
 	}
 
 	/* Allocate buffer that we will be sending out, containing
 	 * the following command format:
+	 *
 	 * <editor_ptr> <branch_ptr...>
 	 */
-	buf_len = 24 + (24 * 1);
-	buf = (gchar *)malloc(buf_len * sizeof(gchar));
-	if(buf != NULL)
-	{
-	    char num_str[80];
-
-
-	    /* Format buf. */
-	    (*buf) = '\0';
-	    sprintf(num_str, "%.8x", (guint32)editor);
-	    strcat(buf, num_str);
-
-	    if(branch_ptr != NULL)
-	    {
-		strcat(buf, " ");
-		sprintf(num_str, "%.8x", (guint32)branch_ptr);
-		strcat(buf, num_str);
-	    }
-
-	    /* Send out data. */
-	    gtk_selection_data_set(
-		selection_data,
-		GDK_SELECTION_TYPE_STRING,
-		8,		/* 8 bits per character. */
-		buf, strlen(buf)
+	if(branch_ptr != NULL)
+	    buf = g_strdup_printf(
+		"%.8x %.8x",
+		(guint32)editor,
+		(guint32)branch_ptr
+	    );
+	else
+	    buf = g_strdup_printf(
+                "%.8x",
+		(guint32)editor
 	    );
-	    data_sent = TRUE;
 
-	    /* Free buffer. */
-	    free(buf);
-	    buf = NULL;
-	    buf_len = 0;
-	}
+	/* Send out data */
+	gtk_selection_data_set(
+	    selection_data,
+	    GDK_SELECTION_TYPE_STRING,
+	    8,			/* 8 bits per character */
+	    buf, strlen(buf)
+	);
+	data_sent = TRUE;
+
+	g_free(buf);
+
 
 	/* Failed to send out data? */
 	if(!data_sent)
 	{
-	    const char *strptr = "Error";
+	    const gchar *s = "Error";
 
 	    gtk_selection_data_set(
 		selection_data,
 		GDK_SELECTION_TYPE_STRING,
-		8,      /* 8 bits per character. */
-		strptr, strlen(strptr)
+		8,      /* 8 bits per character */
+		s, strlen(s)
 	    );
 	    data_sent = TRUE;
 	}
-
-	return;
 }
 
 /*
@@ -1042,30 +1018,30 @@ void EditorDNDDataRecievedCB(
 	GtkWidget *source_widget;
 	GtkCList *clist;
 	GtkCTree *ctree;
-	editor_struct *editor = (editor_struct *)data;
+	editor_struct *editor = EDITOR(data);
 	if((widget == NULL) || (editor == NULL) || (dc == NULL))
-		return;
+	    return;
 
 	if(!editor->initialized)
 	    return;
 
-	/* Important, check if we got data. */
+	/* Important, check if we got data */
 	if(selection_data == NULL)
-		return;
+	    return;
 	if(selection_data->length < 0)
-		return;
+	    return;
 
 	/* Source and target same? */
 	source_widget = gtk_drag_get_source_widget(dc);
 	same = ((source_widget == widget) ? TRUE : FALSE);
 
 	/* Check if data needs to be deleted by testing if this
-	 * drag operation is not a copy.
+	 * drag operation is not a copy
 	 */
 	if(dc->action != GDK_ACTION_COPY)
 	    need_delete = TRUE;
 
-	/* Get clist and ctree from the input widget. */
+	/* Get clist and ctree from the input widget */
 	ctree = ((GTK_IS_CLIST(widget)) ? GTK_CTREE(widget) : NULL);
 	clist = (GtkCList *)ctree;
 	if(clist != NULL)
@@ -1079,7 +1055,7 @@ void EditorDNDDataRecievedCB(
 		    clist, x, y, &row, &column
 	    ))
 	    {
-/*		row -= 1;	*/	/* Need to offset. */
+/*		row -= 1;	*/	/* Need to offset */
 	    }
 	    else
 	    {
@@ -1095,22 +1071,20 @@ void EditorDNDDataRecievedCB(
 	    /* Editor layout ctree branch node transfer command? */
 	    if(info == MEDIT_DND_TYPE_INFO_EDITOR_BRANCH_CMD)
 	    {
-		gint i;
+		gint i, total_branches = 0;
 		editor_struct *src_editor = NULL;
 		GtkCTreeNode **branch = NULL;
-		gint total_branches = 0;
-		gbool	is_branch_file = FALSE,
-			is_branch_header = FALSE,
-			is_branch_section = FALSE;
+		gboolean	is_branch_file = FALSE,
+				is_branch_header = FALSE,
+				is_branch_section = FALSE;
 
 
-		/* Parse command string. Value of src_editor points to
-		 * the source editor and branch and total_branches are   
-		 * the selected branch(es) on the source editor's layout   
-		 * ctree.
+		/* Parse command string, src_editor points to the source
+		 * editor and branch and total_branches are the selected
+		 * branch(es) on the source editor's layout GtkCTree
 		 */
 		EditorDNDParseCmd(
-		    (const char *)selection_data->data,
+		    (const gchar *)selection_data->data,
 		    &src_editor,
 		    &branch, &total_branches
 		);
@@ -1132,7 +1106,7 @@ void EditorDNDDataRecievedCB(
 			if(item_ptr == NULL)
 			    continue;
 
-			/* Check item type. */
+			/* Check item type */
 			switch(item_ptr->type)
 			{
 			  case EditorItemTypeFile:
@@ -1155,9 +1129,9 @@ void EditorDNDDataRecievedCB(
 		    {
 			CDialogGetResponse(
 			    "Invalid operation!",
-"Cannot drag and drop both file referances and sectional\n\
+"Cannot drag and drop both file reference and sectional\n\
 data types at once.",
-"You cannot drag and drop items of type file referances\n\
+"You cannot drag and drop items of type file reference\n\
 and sectional data (ie header and section types) at once.\n\
 You need to select only one or a group of source items of\n\
 the same type to drag and drop.",
@@ -1166,14 +1140,14 @@ the same type to drag and drop.",
 			    CDIALOG_BTNFLAG_OK
 			);
 
-			/* Free only list of branches from source editor. */
-			free(branch);
+			/* Free only list of branches from source editor */
+			g_free(branch);
 			branch = NULL;
 			total_branches = 0;
 
 			return;
 		    }
-		    /* `No operation' check. */
+		    /* `No operation' check */
 		    if(same && (total_branches == 1))
 		    {
 			GtkCTreeNode *insert_row_node = gtk_ctree_node_nth(
@@ -1183,8 +1157,8 @@ the same type to drag and drop.",
 			/* Drag and drop on same? */
 			if(branch[0] == insert_row_node)
 			{
-			    /* Free only list of branches from source editor. */
-			    free(branch);
+			    /* Free only list of branches from source editor */
+			    g_free(branch);
 			    branch = NULL;
 			    total_branches = 0;
 
@@ -1194,7 +1168,7 @@ the same type to drag and drop.",
 
 
 		    /* ************************************************ */
-		    /* Handle by branch item data type. */
+		    /* Handle by branch item data type */
 		    /* File (which implies toplevel trunk branch)? */
 		    if(is_branch_file)
 		    {
@@ -1223,10 +1197,10 @@ the same type to drag and drop.",
 			    total_branches = 0;
 			}
 
-			/* Update column widths and menus. */
+			/* Update column widths and menus */
 			gtk_clist_set_column_width(
 			    (GtkCList *)ctree,
-			    0,			/* Column. */
+			    0,			/* Column */
 			    gtk_clist_optimal_column_width(
 				(GtkCList *)ctree, 0
 			    )
@@ -1240,7 +1214,7 @@ the same type to drag and drop.",
 			{
 			    gtk_clist_set_column_width(
 				(GtkCList *)src_editor->layout_ctree,
-				0,		/* Column. */
+				0,		/* Column */
 				gtk_clist_optimal_column_width(
 				    (GtkCList *)src_editor->layout_ctree, 0
 				)
@@ -1253,13 +1227,13 @@ the same type to drag and drop.",
 		    else if(is_branch_header || is_branch_section)
 		    {
 			editor_item_struct **new_item;
-			int total_new_items;
+			gint total_new_items;
 
-			/* Copy new items from source editor. */
+			/* Copy new items from source editor */
 			total_new_items = total_branches;
 			if(total_new_items > 0)
-			    new_item = (editor_item_struct **)calloc(
-				total_new_items, sizeof(editor_item_struct *)
+			    new_item = (editor_item_struct **)g_malloc0(
+				total_new_items * sizeof(editor_item_struct *)
 			    );
 			else
 			    new_item = NULL;
@@ -1269,7 +1243,7 @@ the same type to drag and drop.",
 			}
 			else
 			{
-			    /* Make duplicates for each new item. */
+			    /* Make duplicates for each new item */
 			    for(i = 0; i < total_new_items; i++)
 			    {
 				item_ptr = EditorBranchGetData(
@@ -1278,7 +1252,7 @@ the same type to drag and drop.",
 				);
 				if(item_ptr != NULL)
 				{
-				    /* Duplicate item. */
+				    /* Duplicate item */
 				    new_item[i] = EditorItemDup(item_ptr);
 				}
 			    }
@@ -1313,10 +1287,10 @@ the same type to drag and drop.",
 			    total_branches = 0;
 			}
 
-			/* Update column widths and menus. */
+			/* Update column widths and menus */
 			gtk_clist_set_column_width(
 			    (GtkCList *)ctree,
-			    0,			/* Column. */
+			    0,			/* Column */
 			    gtk_clist_optimal_column_width(
 				(GtkCList *)ctree, 0
 			    )
@@ -1330,7 +1304,7 @@ the same type to drag and drop.",
 			{
 			    gtk_clist_set_column_width(
 				(GtkCList *)src_editor->layout_ctree,
-				0,			/* Column. */
+				0,			/* Column */
 				gtk_clist_optimal_column_width(
 				    (GtkCList *)src_editor->layout_ctree, 0
 				)
@@ -1340,8 +1314,8 @@ the same type to drag and drop.",
 		    }
 		}
 
-		/* Free only list of branches from source editor. */
-		free(branch);
+		/* Free only list of branches from source editor */
+		g_free(branch);
 		branch = NULL;
 		total_branches = 0;
 	    }
@@ -1351,7 +1325,7 @@ the same type to drag and drop.",
 	    {
 		viewer_struct *src_viewer = NULL;
 		GtkCTreeNode **branch = NULL;   
-		int total_branches = 0;
+		gint total_branches = 0;
 
 
 		/* Parse command string. Value of src_viewer points to
@@ -1360,18 +1334,18 @@ the same type to drag and drop.",
 		 * ctree.
 		 */
 		ViewerIndexCTreeDNDParseCmd(
-		    (const char *)selection_data->data,
+		    (const gchar *)selection_data->data,
 		    &src_viewer,
 		    &branch, &total_branches
 		);
 
 		/* Is source viewer valid? */
-		if((src_viewer == NULL) ?
-		    0 : (src_viewer->index_ctree != NULL)
+		if((src_viewer != NULL) ?
+		    (src_viewer->index_ctree != NULL) : FALSE
 		)
 		{
-		    /* Go through each selected branch from source
-		     * viewer and load then into the target editor.
+		    /* Iterate through each selected branch from source
+		     * viewer and load then into the target editor
 		     */
 		    EditorDNDViewerIndexItemLoad(
 			editor, src_viewer,
@@ -1393,7 +1367,7 @@ the same type to drag and drop.",
 		/* Free only list of branches from source viewer's
 		 * index ctree.
 		 */
-		free(branch);
+		g_free(branch);
 		branch = NULL;
 		total_branches = 0;
 	    }
@@ -1406,14 +1380,12 @@ the same type to drag and drop.",
 		gchar *path = EditorDNDParseURL(
 		    selection_data->data, selection_data->length
 		);
-
 		EditorFileLoad(editor, path, editor->selected_branch, FALSE);
-
 		g_free(path);
 	    }
  
 	    /* ******************************************************** */ 
-	    /* Add support for other types of DND here. */
+	    /* Add support for other types of DND here */
 
 
 
@@ -1429,10 +1401,10 @@ the same type to drag and drop.",
  */
 static void EditorDNDDoDeleteItems(
 	editor_struct *editor,
-	GtkCTreeNode **branch, int total_branches
+	GtkCTreeNode **branch, gint total_branches
 )
 {
-	int i;
+	gint i;
 	GtkCList *clist;
 	GtkCTree *ctree;
 	gpointer *data_list;
@@ -1442,7 +1414,7 @@ static void EditorDNDDoDeleteItems(
 
 	if(total_branches <= 0)
 	{
-	    free(branch);
+	    g_free(branch);
 	    return;
 	}
 
@@ -1450,21 +1422,23 @@ static void EditorDNDDoDeleteItems(
 	clist = (GtkCList *)ctree;
 	if(ctree == NULL)
 	{
-	    free(branch);
+	    g_free(branch);
 	    return;
 	}
 
 
 	/* Make a local list of item data pointers before we start
-	 * deleting branches.
+	 * deleting branches
 	 */
-	data_list = (gpointer *)calloc(total_branches, sizeof(gpointer));
+	data_list = (gpointer *)g_malloc0(
+	    total_branches * sizeof(gpointer)
+	);
 	if(data_list == NULL)
 	{
-	    free(branch);
+	    g_free(branch);
 	    return;
 	}
-	/* Copy item data pointers from given list of branches. */
+	/* Copy item data pointers from given list of branches */
 	for(i = 0; i < total_branches; i++)
 	    data_list[i] = (gpointer)EditorBranchGetData(
 		ctree, branch[i]
@@ -1472,7 +1446,7 @@ static void EditorDNDDoDeleteItems(
 
 
 	/* Match and delete each branch node on the layout ctree by
-	 * using the item data list as referance. This way
+	 * using the item data list as reference. This way
 	 * gtk_ctree_find_by_row_data() will be able to make matches to
 	 * only those nodes that actually exist.
 	 */
@@ -1494,7 +1468,7 @@ static void EditorDNDDoDeleteItems(
 	    /* Remove this branch node from the ctree and all subsiquent
 	     * child branches if any.
 	     *
-	     * Editor's referance to the selected branch and layout_trunks
+	     * Editor's reference to the selected branch and layout_trunks
 	     * list will be updated as needed when the destroy notify
 	     * callback is called upon deleting this branch node.
 	     */
@@ -1502,13 +1476,11 @@ static void EditorDNDDoDeleteItems(
 	}
 
 
-	/* Free local item data list. */
-	free(data_list);
+	/* Delete local item data list */
+	g_free(data_list);
 
-	/* Free given list of branch pointers. */
-	free(branch);
-
-	return;
+	/* Delete list of branch pointers */
+	g_free(branch);
 }
 
 /*
@@ -1520,6 +1492,5 @@ void EditorDNDDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
-	/* Function no longer used. */
-	return;
+
 }
