@@ -1,8 +1,3 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
 #include "../include/string.h"
@@ -101,14 +96,14 @@ gint EditorFIPAddItem(
 	if(clist == NULL)
 	    return(row);
 
-	/* Allocate a new item structure. */
+	/* Allocate a new item structure */
 	item_ptr = (editor_fip_item_struct *)g_malloc0(
 	    sizeof(editor_fip_item_struct)
 	);
 	if(item_ptr == NULL)
 	    return(row);
 
-	/* Set values on new item structure. */
+	/* Set values on new item structure */
 	item_ptr->editor_fip_ptr = (gpointer )fip;
 	item_ptr->clist = clist;
 
@@ -118,23 +113,25 @@ gint EditorFIPAddItem(
 	item_ptr->text_sel_end = text_sel_end;
 	item_ptr->line_num = line_num;
 
-	/* Allocate text for columns on results clist. */
+	/* Allocate text for columns on results clist */
 	text = (gchar **)g_malloc0(4 * sizeof(gchar *));
 	if(text != NULL)
 	{
-	    char num_str[80];
+	    gchar *s;
 
 	    if(line_num < 0)
-		sprintf(num_str, "n/a");
+		s = g_strdup_printf("n/a");
 	    else
-		sprintf(num_str, "#%i", line_num + 1);
+		s = g_strdup_printf("#%i", line_num + 1);
 
-	    text[0] = strdup((excerpt == NULL) ? "" : excerpt);
-	    text[1] = strdup((num_str == NULL) ? "" : num_str);
-	    text[2] = strdup((name == NULL) ? "" : name);
-	    text[3] = strdup((manual_page == NULL) ? "" : manual_page);
+	    text[0] = g_strdup((excerpt != NULL) ? excerpt : "");
+	    text[1] = g_strdup((s != NULL) ? s : "");
+	    text[2] = g_strdup((name != NULL) ? name : "");
+	    text[3] = g_strdup((manual_page != NULL) ? manual_page : "");
 
-	    row = (gint)gtk_clist_append(clist, text);
+	    g_free(s);
+
+	    row = gtk_clist_append(clist, text);
 
 	    strlistfree(text, 4);
 	    text = NULL;
@@ -143,8 +140,7 @@ gint EditorFIPAddItem(
 	if(row > -1)
 	{
 	    /* Set item structure pointer to new row on results clist
-	     * and also set the destroy notify callback function.
-	     */
+	     * and also set the destroy notify callback function */
 	    gtk_clist_set_row_data_full(
 		clist, (gint)row, (gpointer)item_ptr,
 		EditorFIPItemDestroyCB
@@ -153,8 +149,7 @@ gint EditorFIPAddItem(
 	else
 	{
 	    /* Could not add item pointer to row that was not created,
-	     * so deallocate item structure.
-	     */
+	     * so delete item structure */
 	    EditorFIPItemDelete(item_ptr);
 	}
 
@@ -163,7 +158,7 @@ gint EditorFIPAddItem(
 
 
 /*
- *	Deallocates the results item structure and all its allocated
+ *	Deletes the results item structure and all its allocated
  *	resources.
  */
 void EditorFIPItemDelete(editor_fip_item_struct *item_ptr)
@@ -171,11 +166,7 @@ void EditorFIPItemDelete(editor_fip_item_struct *item_ptr)
 	if(item_ptr == NULL)
 	    return;
 
-	/* No members to deallocate. */
-
-	free(item_ptr);
-
-	return;
+	g_free(item_ptr);
 }
 
 /*
@@ -186,30 +177,27 @@ void EditorFIPSetBusy(editor_fip_struct *fip)
 	GtkWidget *w;
 	GdkCursor *cur;
 	medit_core_struct *core_ptr;
-	    
-	 
+
 	if(fip == NULL)
 	    return;  
- 
+
 	core_ptr = (medit_core_struct *)fip->core_ptr;
 	if(core_ptr == NULL)
 	    return;
-  
+
 	w = fip->toplevel;
 	if(w == NULL)
 	    return;
- 
+
 	cur = core_ptr->cursors_list.busy;
 	if(cur == NULL)
 	    return;
-	    
+
 	if(GTK_WIDGET_NO_WINDOW(w))
 	    return;
- 
+
 	gdk_window_set_cursor(w->window, cur);
 	gdk_flush(); 
- 
-	return;
 }       
 
 /*
@@ -231,8 +219,6 @@ void EditorFIPSetReady(editor_fip_struct *fip)
 
 	gdk_window_set_cursor(w->window, NULL);
 	gdk_flush();
-
-	return;
 }
 
 
@@ -251,27 +237,27 @@ static void EditorFIPCreateStatusBar(
 	GtkAdjustment *adj;
 
 
-	/* Main hbox for status bar and window map buttons. */
+	/* Main hbox for status bar and window map buttons */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent = w;
 
-	/* Handle for status bar. */
+	/* Handle for status bar */
 	w = gtk_handle_box_new();
 	fip->status_bar_dock = w;
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Toplevel hbox inside dock. */
+	/* Toplevel hbox inside dock */
 	w = gtk_hbox_new(FALSE, 0);
 	fip->status_bar_toplevel = w;
 	gtk_container_add(GTK_CONTAINER(parent2), w);
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Main frame in toplevel. */
+	/* Main frame in toplevel */
 	w = gtk_frame_new(NULL);
 	gtk_widget_set_usize(w, -1, 25);
 	gtk_frame_set_shadow_type(GTK_FRAME(w), GTK_SHADOW_OUT);
@@ -280,14 +266,14 @@ static void EditorFIPCreateStatusBar(
 	gtk_widget_show(w);
 	parent2 = w;
  
-	/* Table in main frame. */
+	/* Table in main frame */
 	w = gtk_table_new(1, 2, FALSE);
 	gtk_container_add(GTK_CONTAINER(parent2), w);
 	gtk_widget_show(w);
 	parent2 = w;
 
 
-	/* Progress bar. */
+	/* Progress bar */
 	adj = (GtkAdjustment *)gtk_adjustment_new(0, 1, 100, 0, 0, 0);
 	w = gtk_progress_bar_new_with_adjustment(adj);
 	fip->status_bar_progress = w;
@@ -311,7 +297,7 @@ static void EditorFIPCreateStatusBar(
 	gtk_widget_show(w);
 	
 	
-	/* Label. */
+	/* Label */
 	w = gtk_frame_new(NULL);
 	gtk_frame_set_shadow_type(GTK_FRAME(w), GTK_SHADOW_IN);
 	gtk_container_border_width(GTK_CONTAINER(w), 1);
@@ -337,14 +323,14 @@ static void EditorFIPCreateStatusBar(
 	gtk_widget_show(w);
 
 
-	/* Handle bar for window map buttons. */
+	/* Handle bar for window map buttons */
 	w = gtk_handle_box_new();
 /*      editor->window_map_dock = w; */
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 	
-	/* Main frame in toplevel. */
+	/* Main frame in toplevel */
 	w = gtk_frame_new(NULL);
 	gtk_widget_set_usize(w, -1, 25);
 	gtk_frame_set_shadow_type(GTK_FRAME(w), GTK_SHADOW_OUT);
@@ -353,15 +339,15 @@ static void EditorFIPCreateStatusBar(
 	gtk_widget_show(w);
 	parent2 = w;
 	  
-	/* Hbox for window map buttons. */
+	/* Hbox for window map buttons */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(parent2), w);
 	gtk_widget_show(w);
 	parent2 = w;
    
-	/* Window map buttons. */
+	/* Window map buttons */
 	w = (GtkWidget *)GUIButtonPixmap(
-	    (u_int8_t **)manedit_16x16_xpm
+	    (guint8 **)manedit_16x16_xpm
 	);
 	gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NONE);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
@@ -376,7 +362,7 @@ static void EditorFIPCreateStatusBar(
 	gtk_widget_show(w);
 
 	w = (GtkWidget *)GUIButtonPixmap(
-	    (u_int8_t **)mp_viewer_16x16_xpm
+	    (guint8 **)mp_viewer_16x16_xpm
 	);
 	gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NONE);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
@@ -404,28 +390,27 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	GSList *gslist;
 	GtkCList *clist;
 	gpointer combo_rtn;
-	gint accel_key;
+	guint accel_key, accel_mods;
 	gpointer accel_group;  
-	guint accel_mods;
 	const gchar *label;
-	u_int8_t **icon;
+	guint8 **icon;
 	gpointer mclient_data;
 	void (*func_cb)(GtkWidget *w, gpointer);
 	gchar *heading[4];
 	medit_cursors_list_struct *cursors_list;
-	editor_fip_struct *fip = (editor_fip_struct *)g_malloc0(
-	    sizeof(editor_fip_struct)   
-	);
+	editor_fip_struct *fip = EDITOR_FIP(g_malloc0(
+	    sizeof(editor_fip_struct)
+	));
 	if(fip == NULL)
 	    return(NULL);
 
-	/* Get pointers to resources on core structure. */
+	/* Get pointers to resources on core structure */
 	if(core_ptr != NULL)
 	    cursors_list = &((medit_core_struct *)core_ptr)->cursors_list;
 	else
 	    cursors_list = NULL;
 
-	/* Reset values. */
+	/* Reset values */
 	fip->initialized = TRUE;
 	fip->map_state = FALSE;
 	fip->processing = FALSE;
@@ -469,7 +454,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
  ); \
 }
 
-	/* Toplevel. */  
+	/* Toplevel */  
 	w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	fip->toplevel = w;
 /*
@@ -488,7 +473,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	);
  */
 	gtk_widget_realize(w);   
-	GUISetWMIcon(w->window, (u_int8_t **)manedit_48x48_xpm);
+	GUISetWMIcon(w->window, (guint8 **)manedit_48x48_xpm);
 	gtk_widget_set_usize(
 	    w,
 	    FIP_DEF_WIDTH,
@@ -510,7 +495,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	);
 	parent = w;
 
-	/* Main vbox. */
+	/* Main vbox */
 	w = gtk_vbox_new(FALSE, 0);
 	fip->main_vbox = w;
 	gtk_container_add(GTK_CONTAINER(parent), w);
@@ -518,7 +503,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	parent = w;
 
 
-	/* Hbox to hold left and right columns of vboxes. */
+	/* Hbox to hold left and right columns of vboxes */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
@@ -532,7 +517,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	gtk_widget_show(w);
 	left_vbox = w;
 
-	/* Right side vbox, this holds the find and close buttons. */
+	/* Right side vbox, this holds the find and close buttons */
 	w = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 /*	gtk_widget_set_usize(w, 120, -1); */
@@ -541,22 +526,22 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 
 
 
-	/* Create widgets for left side vbox. */
+	/* Create widgets for left side vbox */
 	parent2 = left_vbox;
 
-	/* Match all or match any radio buttons vbox. */
+	/* Match all or match any radio buttons vbox */
 	w = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 2);
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Hbox for match all radio button. */
+	/* Hbox for match all radio button */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Reset gslist and create match all radio button. */
+	/* Reset gslist and create match all radio button */
 	gslist = NULL;
 	w = gtk_radio_button_new_with_label(gslist, "Match All Occurances");
 	fip->match_all_radio = w;
@@ -565,45 +550,45 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	gtk_widget_show(w);
 	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Hbox for match any radio button. */
+	/* Hbox for match any radio button */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Match any radio button. */
+	/* Match any radio button */
 	w = gtk_radio_button_new_with_label(gslist, "Match Any Occurance");
 	fip->match_any_radio = w;
 	gtk_box_pack_start(GTK_BOX(parent4), w, TRUE, TRUE, 2);  
 	gtk_widget_show(w);
 	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Hbox for match phrase radio button. */
+	/* Hbox for match phrase radio button */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Match phrase radio button. */
+	/* Match phrase radio button */
 	w = gtk_radio_button_new_with_label(gslist, "Match Phrase Occurance");
 	fip->match_phrase_radio = w;
 	gtk_box_pack_start(GTK_BOX(parent4), w, TRUE, TRUE, 2);
 	gtk_widget_show(w);
 
 
-	/* Hbox for the find combo. */
+	/* Hbox for the find combo */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 2);
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Find combo. */
+	/* Find combo */
 	w = (GtkWidget *)GUIComboCreate(
-	    "Of:",		/* Label. */
-	    NULL,               /* Initial text value. */
-	    NULL,               /* Initial glist of items. */
-	    20,                 /* Max items. */
-	    &combo_rtn,         /* Combo widget return. */
+	    "Of:",		/* Label */
+	    NULL,               /* Initial text value */
+	    NULL,               /* Initial glist of items */
+	    20,                 /* Max items */
+	    &combo_rtn,         /* Combo widget return */
 	    (gpointer )fip,
 	    EditorFIPFindActivateCB,
 	    NULL
@@ -617,14 +602,14 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	gtk_widget_show(w);
 
 
-	/* Hbox for additional options. */
+	/* Hbox for additional options */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 2);
 	gtk_widget_show(w);
 	parent3 = w;
 
 
-	/* Case sensitive toggle. */
+	/* Case sensitive toggle */
 	w = gtk_check_button_new_with_label(
 	    "Case Sensitive"
 	);
@@ -637,19 +622,19 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 
 
 
-	/* Horizontal rule. */
+	/* Horizontal rule */
 	w = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
 
-	/* Hbox for results clist. */
+	/* Hbox for results clist */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 2);
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Scrolled window, parent for results clist. */
+	/* Scrolled window, parent for results clist */
 	w = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(
 	    GTK_SCROLLED_WINDOW(w),   
@@ -660,7 +645,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	gtk_widget_show(w);
 	scroll_parent = w;
 
-	/* Results clist. */
+	/* Results clist */
 	heading[0] = "Excerpt";
 	heading[1] = "Line";
 	heading[2] = "Name";
@@ -682,7 +667,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	}
 	gtk_clist_set_selection_mode(GTK_CLIST(w), GTK_SELECTION_SINGLE);
 	gtk_clist_set_sort_type(GTK_CLIST(w), GTK_SORT_ASCENDING);
-	gtk_clist_set_sort_column(GTK_CLIST(w), 3);	/* By manual page name. */
+	gtk_clist_set_sort_column(GTK_CLIST(w), 3);	/* By manual page name */
 	gtk_clist_set_row_height(GTK_CLIST(w), MEDIT_LIST_ROW_SPACING);
 /*	gtk_clist_set_auto_sort(GTK_CLIST(w), TRUE); */
 	gtk_container_add(GTK_CONTAINER(scroll_parent), w);
@@ -710,7 +695,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	gtk_widget_show(w);
 
 
-	/* Results clist right click menu. */
+	/* Results clist right click menu */
 	menu = (GtkWidget *)GUIMenuCreate();
 	fip->results_menu = menu;
 	accel_group = NULL;
@@ -718,7 +703,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
  
 	if(menu != NULL)
 	{
-	    icon = (u_int8_t **)icon_goto_20x20_xpm;
+	    icon = (guint8 **)icon_goto_20x20_xpm;
 	    label = "Goto";
 	    accel_key = 0;
 	    accel_mods = 0;
@@ -729,24 +714,24 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 
 
 
-	/* Begin creating buttons on right side vbox. */
+	/* Begin creating buttons on right side vbox */
 	parent2 = right_vbox;
 
-	/* Vbox to group find and clear buttons. */
+	/* Vbox to group find and clear buttons */
 	w = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 10);
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Hbox for find button. */
+	/* Hbox for find button */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Find button. */
+	/* Find button */
 	w = GUIButtonPixmapLabelH(
-	    (u_int8_t **)icon_search_20x20_xpm, "Search", NULL
+	    (guint8 **)icon_search_20x20_xpm, "Search", NULL
 	);
 	fip->find_btn = w;
 	gtk_widget_set_usize(w, FIP_BTN_WIDTH, FIP_BTN_HEIGHT);
@@ -759,15 +744,15 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	);
 	gtk_widget_show(w);
 
-	/* Hbox for stop button. */ 
+	/* Hbox for stop button */ 
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Stop button. */
+	/* Stop button */
 	w = GUIButtonPixmapLabelH(
-	    (u_int8_t **)icon_stop_20x20_xpm, "Stop", NULL
+	    (guint8 **)icon_stop_20x20_xpm, "Stop", NULL
 	);
 	fip->stop_btn = w;
 	gtk_widget_set_usize(w, FIP_BTN_WIDTH, FIP_BTN_HEIGHT);
@@ -780,13 +765,13 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	);
 	gtk_widget_show(w);
 
-	/* Hbox for clear button. */
+	/* Hbox for clear button */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Clear button. */
+	/* Clear button */
 	w = GUIButtonPixmapLabelH(
 	    NULL, "Clear", NULL
 	);
@@ -802,21 +787,21 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 	gtk_widget_show(w);
 
 
-	/* Vbox for grouping just the close button. */
+	/* Vbox for grouping just the close button */
 	w = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 10);
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Hbox for close button. */
+	/* Hbox for close button */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Close button. */ 
+	/* Close button */ 
 	w = GUIButtonPixmapLabelH(
-	    (u_int8_t **)icon_close_20x20_xpm, "Close", NULL
+	    (guint8 **)icon_close_20x20_xpm, "Close", NULL
 	);
 	fip->close_btn = w;
 	gtk_widget_set_usize(w, FIP_BTN_WIDTH, FIP_BTN_HEIGHT);
@@ -832,23 +817,23 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 
 
 
-	/* Goto button and other stuff near bottom. */
+	/* Goto button and other stuff near bottom */
 	parent2 = fip->main_vbox;
 
-	/* Horizontal rule. */ 
+	/* Horizontal rule */ 
 	w = gtk_hseparator_new();   
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
-	/* Hbox to hold buttons homogeniously. */
+	/* Hbox to hold buttons homogeniously */
 	w = gtk_hbox_new(TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 5);
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Goto button. */
+	/* Goto button */
 	w = GUIButtonPixmapLabelH(
-	    (u_int8_t **)icon_goto_20x20_xpm, "Goto", NULL
+	    (guint8 **)icon_goto_20x20_xpm, "Goto", NULL
 	);
 	fip->goto_btn = w;
 	gtk_widget_set_usize(w, FIP_BTN_WIDTH, FIP_BTN_HEIGHT);
@@ -867,7 +852,7 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 
 
 
-	/* Create status bar. */
+	/* Create status bar */
 	EditorFIPCreateStatusBar(fip, fip->main_vbox);
 
 
@@ -878,10 +863,10 @@ editor_fip_struct *EditorFIPNew(gpointer core_ptr, gpointer editor_ptr)
 #undef DO_ADD_MENU_ITEM_CHECK
 #undef DO_ADD_MENU_SEP
 
-	/* Reset values to defaults. */
+	/* Reset values to defaults */
 	EditorFIPReset(fip, FALSE);
 
-	/* Update menus. */
+	/* Update menus */
 	EditorFIPUpdateMenus(fip);
 
 	return(fip);
@@ -903,7 +888,7 @@ void EditorFIPUpdateMenus(editor_fip_struct *fip)
 	if(!fip->initialized)
 	    return;
 
-	/* Okay to handle if processing. */
+	/* Okay to handle if processing */
 
 	if(reenterant)
 	    return;
@@ -925,7 +910,7 @@ void EditorFIPUpdateMenus(editor_fip_struct *fip)
 }
 
 
-	/* Results clist pop up menu. */
+	/* Results clist pop up menu */
 	menu = fip->results_menu;
 	if(menu != NULL)
 	{
@@ -937,7 +922,7 @@ void EditorFIPUpdateMenus(editor_fip_struct *fip)
 	}
 
 
-	/* Match options radio buttons. */
+	/* Match options radio buttons */
 	w = fip->match_all_radio;
 	sensitivity = ((fip->processing) ? FALSE : TRUE);
 	SET_WIDGET_SENSITIVITY
@@ -955,13 +940,13 @@ void EditorFIPUpdateMenus(editor_fip_struct *fip)
 	SET_WIDGET_SENSITIVITY
 
 
-	/* Find combo. */
+	/* Find combo */
 	w = fip->find_combo;
 	sensitivity = ((fip->processing) ? FALSE : TRUE);
 	SET_WIDGET_SENSITIVITY
 
 
-	/* Buttons. */
+	/* Buttons */
 	w = fip->find_btn;
 	sensitivity = ((fip->processing) ? FALSE : TRUE);
 	SET_WIDGET_SENSITIVITY
@@ -988,7 +973,6 @@ void EditorFIPUpdateMenus(editor_fip_struct *fip)
 #undef SET_CHECK_MENU_ITEM_STATE
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
@@ -1013,12 +997,10 @@ void EditorFIPSetStatusMessage(
 	);
 
 	/* Itterate through GTK main function until all events are handled
-	 * so that we ensure this label text is updated.
+	 * so that we ensure this label text is updated
 	 */
 	while(gtk_events_pending() > 0)
 	    gtk_main_iteration();
-
-	return;
 }
 
 /*
@@ -1038,7 +1020,7 @@ void EditorFIPSetStatusProgress(
 	if(w == NULL)
 	    return;  
 
-	/* Negative? Implies just do activity. */        
+	/* Negative? Implies just do activity */        
 	if(percent < 0.0)
 	{
 	    GtkAdjustment *adj = GTK_PROGRESS(w)->adjustment;
@@ -1102,8 +1084,6 @@ void EditorFIPSetStatusProgress(
 	}
 	 
 	fip->status_bar_progress_pos_last = percent;
-	    
-	return;
 }
 
 /*
@@ -1129,25 +1109,25 @@ void EditorFIPReset(editor_fip_struct *fip, gboolean need_unmap)
 	else
 	    reenterant = TRUE;
 
-	/* Reset values. */
+	/* Reset values */
 	fip->processing = FALSE;
 	fip->status_bar_progress_pos_last = 0;
 	fip->stop_find_count = 0;
 	fip->selected_result = -1;
 
-	/* Reset status messages. */
+	/* Reset status messages */
 	EditorFIPSetStatusMessage(fip, NULL);
 	EditorFIPSetStatusProgress(fip, 0.0);
 
 
-	/* Match all radio button. */
+	/* Match all radio button */
 	w = fip->match_all_radio;
 	if(w != NULL)
 	    gtk_toggle_button_set_active(
 		GTK_TOGGLE_BUTTON(w), TRUE
 	    );
 
-	/* Case sensitive. */
+	/* Case sensitive */
 	w = fip->case_sensitive_toggle;
 	if(w != NULL)
 	    gtk_toggle_button_set_active(
@@ -1155,14 +1135,14 @@ void EditorFIPReset(editor_fip_struct *fip, gboolean need_unmap)
 	    );
 
 	/* Remove all items on the results clist, destroy notify
-	 * will be called to deallocate all item data.
+	 * will be called to delete all item data.
 	 */
 	w = fip->results_clist;
 	if(w != NULL)
 	    gtk_clist_clear(GTK_CLIST(w));
 
 
-	/* Unmap as needed. */
+	/* Unmap as needed */
 	if(need_unmap)
 	{
 	    w = fip->toplevel;
@@ -1172,7 +1152,6 @@ void EditorFIPReset(editor_fip_struct *fip, gboolean need_unmap)
 	}
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
@@ -1197,8 +1176,6 @@ void EditorFIPMap(editor_fip_struct *fip)
 	    fip->map_state = TRUE;
 	    gtk_widget_show(w);
 	}
-
-	return;
 }
 
 /*
@@ -1223,14 +1200,12 @@ void EditorFIPUnmap(editor_fip_struct *fip)
 	    fip->map_state = FALSE;
 	    gtk_widget_hide(w);
 	}
-
-	return;
 }
 
 /*
  *      Destroys the dialog and all its widgets and allocated resources.
  *
- *      The dialog structure itself will also be deallocated.
+ *      The dialog structure itself will also be deleted.
  */
 void EditorFIPDelete(editor_fip_struct *fip)
 {
@@ -1247,7 +1222,7 @@ void EditorFIPDelete(editor_fip_struct *fip)
 		return;
 
 	    /* Reset values to defaults, this will cause any loaded data
-	     * to be deallocated.
+	     * to be deleted.
 	     */
 	    EditorFIPReset(fip, TRUE);
 
@@ -1333,8 +1308,5 @@ void EditorFIPDelete(editor_fip_struct *fip)
 #undef DO_DESTROY_WIDGET
 	}
 
-	/* Free structure itself. */
-	free(fip);
-
-	return;
+	g_free(fip);
 }
