@@ -8,97 +8,92 @@
 #ifndef EDITORFIP_H
 #define EDITORFIP_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
-#ifndef gbool
-# define gbool	gboolean
-#endif
-
 
 /*
- *	Item data structure for results_clist:
+ *	Find In Pages Dialog Item:
  */
 typedef struct {
 
-	gpointer editor_fip_ptr;	/* Pointer back to Find In Pages dialog. */
-	GtkCList *clist;	/* Pointer back to clist of this item. */
+	gpointer	editor_fip_ptr;		/* Find In Pages dialog */
+	GtkCList	*clist;
 
 	/* Pointer to the matched branch node on the layout_ctree on
-	 * editor that was searched through.
-	 */
-	GtkCTreeNode *found_branch;
+	 * editor that was searched through */
+	GtkCTreeNode	*found_branch;
 
 	/* This will be used for matching branch data on the editor
 	 * when the user wants to `go to' the matched result. This is
 	 * better since the found_branch may get deleted and matching
-	 * by the branch's data seems to work out better.
+	 * by the branch's data seems to work out better
 	 */
-	gpointer branch_data;
+	gpointer	branch_data;
 
 	/* Matched text position (usually for GtkEntry or
 	 * GtkEditable/GtkText widgets. Can be -1 to indicate neither.
 	 */
-	gint text_sel_start, text_sel_end;
+	gint		text_sel_start,
+			text_sel_end;
 
-	/* Matched line number (not very useful), can be -1 for n/a. */
-	gint line_num;
+	/* Matched line number, can be -1 for n/a */
+	gint		line_num;
 
 } editor_fip_item_struct;
 
 /*
- *	Find In Pages dialog structure:
+ *	Find In Pages Dialog:
  */
 typedef struct {
 
-	gboolean initialized;
-	gboolean map_state;
-	gboolean processing;
+	gboolean	initialized,
+			map_state,
+			processing;
 
-	gpointer core_ptr;
-	gpointer editor_ptr;
+	gpointer	core_ptr;
+	gpointer	editor_ptr;
 
-	GtkWidget *toplevel;
-	GtkWidget *main_vbox;
+	GtkWidget	*toplevel,
+			*main_vbox,
+			*find_combo;
 
-	GtkWidget *find_combo;
-
-	/* Buttons on right column. */
+	/* Buttons on right column */
 	GtkWidget	*find_btn,
 			*clear_btn,
 			*stop_btn,
 			*close_btn;
 
-	gint stop_find_count;
+	gint		stop_find_count;
 
-	/* Search options. */
+	/* Search options */
 	GtkWidget	*match_all_radio,
 			*match_any_radio,
 			*match_phrase_radio;
-	GtkWidget *case_sensitive_toggle;	/* Case sensitive if togged. */
+	GtkWidget	*case_sensitive_toggle;	/* Case sensitive if togged */
 
 	/* Search results put into this clist, it has 4 columns which
 	 * are for; excerpt, type, name (header or section's name), and
 	 * manual page name.
 	 */
-	GtkWidget *results_clist;
-	gint selected_result;			/* Can be -1. */
+	GtkWidget	*results_clist;
+	gint		selected_result;		/* Can be -1 */
 	GtkWidget *results_menu;
 
-	/* Important menu items on results menu. */
+	/* Important menu items on results menu */
 	GtkWidget	*goto_mi;
 
-	/* Goto selected result button. */
-	GtkWidget *goto_btn;
+	/* Goto selected result button */
+	GtkWidget	*goto_btn;
 
 	GtkWidget	*status_bar_dock,
 			*status_bar_toplevel,
 			*status_bar_progress,
 			*status_bar_label;
 
-	gfloat status_bar_progress_pos_last;
+	gfloat		status_bar_progress_pos_last;
 
 } editor_fip_struct;
+#define EDITOR_FIP(p)		((editor_fip_struct *)(p))
 
 
 extern gint EditorFIPAddItem(
