@@ -1,8 +1,3 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <sys/types.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -51,7 +46,7 @@ void EditorFIPResultsListColumnClickCB(
 
 
 /*
- *	Dialog results item data destroy callback, deallocates the
+ *	Dialog results item data destroy callback, deletes the
  *	results item structure.
  */
 void EditorFIPItemDestroyCB(gpointer data)
@@ -65,10 +60,8 @@ void EditorFIPItemDestroyCB(gpointer data)
 	fip = (editor_fip_struct *)item_ptr->editor_fip_ptr;
 
 
-	/* Deallocate results item structure */
+	/* Delete results item structure */
 	EditorFIPItemDelete(item_ptr);
-
-	return;
 }
 
 /*
@@ -76,7 +69,7 @@ void EditorFIPItemDestroyCB(gpointer data)
  */
 void EditorFIPDestroyCB(GtkObject *object, gpointer data)
 {
-	return;
+
 }
 
 /*
@@ -117,7 +110,6 @@ gint EditorFIPCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 void EditorFIPCloseMCB(GtkWidget *widget, gpointer data)
 {
 	EditorFIPCloseCB(widget, NULL, data);
-	return;
 }
 
 
@@ -160,7 +152,6 @@ void EditorFIPFindCB(GtkWidget *widget, gpointer data)
 	g_free(value);
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
@@ -169,14 +160,13 @@ void EditorFIPFindCB(GtkWidget *widget, gpointer data)
 void EditorFIPFindActivateCB(GtkWidget *widget, gpointer data)
 {
 	static gboolean reenterant = FALSE;
-	char *search_string;
+	gchar *s, *search_string;
 	GtkWidget *w;
 	GtkCombo *find_combo;
 	GtkCList *results_clist;
-	int matches;
-	int throughness = 0;
+	gint matches;
+	gint throughness = 0;
 	gboolean case_sensitive = FALSE;
-	char text[256];
 	editor_fip_struct *fip = (editor_fip_struct *)data;
 	if(fip == NULL)
 	    return;
@@ -205,7 +195,7 @@ void EditorFIPFindActivateCB(GtkWidget *widget, gpointer data)
 	/* Get search string and make a copy of it */
 	search_string = gtk_entry_get_text(GTK_ENTRY(find_combo->entry));
 	if(search_string != NULL)
-	    search_string = strdup(search_string);
+	    search_string = g_strdup(search_string);
 
 	if(search_string == NULL)
 	{   
@@ -261,8 +251,8 @@ void EditorFIPFindActivateCB(GtkWidget *widget, gpointer data)
 	);
 
 
-	/* Deallocate search string */
-	free(search_string);
+	/* Delete search string */
+	g_free(search_string);
 	search_string = NULL;
 
 
@@ -271,9 +261,13 @@ void EditorFIPFindActivateCB(GtkWidget *widget, gpointer data)
 	gtk_clist_thaw(results_clist);
 
 	/* Print match results */
-	sprintf(text, "Search done: %i results", matches);
-	EditorFIPSetStatusMessage(fip, text);
-	EditorFIPSetStatusProgress(fip, 0.0);
+	s = g_strdup_printf(
+	    "Search done: %i results",
+	    matches
+	);
+	EditorFIPSetStatusMessage(fip, s);
+	g_free(s);
+	EditorFIPSetStatusProgress(fip, 0.0f);
 
 
 	/* Update menus */
@@ -282,7 +276,6 @@ void EditorFIPFindActivateCB(GtkWidget *widget, gpointer data)
 	EditorFIPSetReady(fip);
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
@@ -308,15 +301,15 @@ void EditorFIPClearCB(GtkWidget *widget, gpointer data)
 
 	gtk_entry_set_text(GTK_ENTRY(combo->entry), "");
 
-/* Er, let's just clear the find combo's entry widget.
+#if 0
+/* Just clear the find combo's entry widget */
 	gtk_clist_freeze(clist);
 	gtk_clist_clear(clist);
 	gtk_clist_thaw(clist);
- */
+#endif
+
 	EditorFIPUpdateMenus(fip);
 	EditorFIPSetReady(fip);
-
-	return;
 }
 
 /*
@@ -342,7 +335,6 @@ void EditorFIPStopCB(GtkWidget *widget, gpointer data)
 	    fip->stop_find_count = 1;
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
@@ -447,7 +439,7 @@ item data.",
 "Tree branch on the editor's layout tree could not be\n\
 found with the result's branch item pointer.",
 "The goto procedure could not be completed due to\n\
-an unfindable referance to the layout tree's branch\n\
+an unfindable reference to the layout tree's branch\n\
 by branch item pointer. It is possible that the\n\
 branch and corresponding item data pointer no longer\n\
 exist on the layout tree.",
@@ -528,7 +520,6 @@ exist on the layout tree.",
 
 
 	reenterant = FALSE;
-	return;
 }
 
 
@@ -643,7 +634,6 @@ void EditorFIPResultsListSelectCB(
 	}
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
@@ -669,7 +659,6 @@ void EditorFIPResultsListUnselectCB(
 
 
 	reenterant = FALSE;
-	return;
 }
 
 
@@ -694,5 +683,4 @@ void EditorFIPResultsListColumnClickCB(
 	gtk_clist_sort(GTK_CLIST(widget));
 
 	reenterant = FALSE;
-	return;
 }
