@@ -18,52 +18,50 @@
 
 
 /*
- *      Tempory structure to return matched information.
+ *	Return Match Information:
  */
 typedef struct {
-	
-	int line_num;
-	int start_pos, end_pos;
-	
+	gint		line_num;
+	gint		start_pos, end_pos;
 } fip_match_struct;
 
 
 static fip_match_struct *EditorFIPDoSearchInArray(
-	const char **line, int total_lines,
-	const char *string, int *matches_rtn
+	const gchar **line, gint total_lines,
+	const gchar *string, gint *matches_rtn
 );
 
-static int EditorFIPDoFindAnyBranchIteration(
+static gint EditorFIPDoFindAnyBranchIteration(
 	editor_fip_struct *fip, editor_struct *editor,
 	GtkCList *results_clist, GtkCTree *layout_ctree,
 	GtkCTreeNode *branch,
-	char **strv, int strc, gbool case_sensitive,
-	const char *manual_page_name
+	gchar **strv, gint strc, gboolean case_sensitive,
+	const gchar *manual_page_name
 );
-static int EditorFIPDoFindAllBranchIteration(
+static gint EditorFIPDoFindAllBranchIteration(
 	editor_fip_struct *fip, editor_struct *editor,
 	GtkCList *results_clist, GtkCTree *layout_ctree,
 	GtkCTreeNode *branch,
-	char **strv, int strc, gbool case_sensitive,
-	const char *manual_page_name
+	gchar **strv, gint strc, gboolean case_sensitive,
+	const gchar *manual_page_name
 );
 
-static int EditorFIPDoFindAny(
+static gint EditorFIPDoFindAny(
 	editor_fip_struct *fip, editor_struct *editor,
 	GtkCList *results_clist, GtkCTree *layout_ctree,
-	const char *string, gbool case_sensitive, gbool explode_string
+	const gchar *string, gboolean case_sensitive, gboolean explode_string
 );
-static int EditorFIPDoFindAll(
+static gint EditorFIPDoFindAll(
 	editor_fip_struct *fip, editor_struct *editor,
 	GtkCList *results_clist, GtkCTree *layout_ctree,
-	const char *string, gbool case_sensitive, gbool explode_string
+	const gchar *string, gboolean case_sensitive, gboolean explode_string
 );
-int EditorFIPDoFind(
+gint EditorFIPDoFind(
 	editor_fip_struct *fip,
 	editor_struct *editor,
-	int throughness,        /* 0 = match all, 1 = match any. */
-	const char *string, 
-	gbool case_sensitive
+	gint throughness,        /* 0 = match all, 1 = match any */
+	const gchar *string, 
+	gboolean case_sensitive
 );
 
 
@@ -83,18 +81,18 @@ int EditorFIPDoFind(
  *	matches (or 0 if return is NULL).
  */
 static fip_match_struct *EditorFIPDoSearchInArray(
-	const char **line, int total_lines,
-	const char *string, int *matches_rtn
+	const gchar **line, gint total_lines,
+	const gchar *string, gint *matches_rtn
 )
 {
-	int i, n;
-	const char *cstrptr;
-	const char *line_ptr;
+	gint i, n;
+	const gchar *cstrptr;
+	const gchar *line_ptr;
 	fip_match_struct *match = NULL;
-	int buf_len, total_matches = 0;
+	gint buf_len, total_matches = 0;
 
 
-	/* Update returns. */
+	/* Update returns */
 	if(matches_rtn != NULL)
 	    (*matches_rtn) = total_matches;
 
@@ -106,12 +104,12 @@ static fip_match_struct *EditorFIPDoSearchInArray(
 
 	for(i = 0, buf_len = 0; i < total_lines; i++)
 	{
-	    line_ptr = (const char *)line[i];
+	    line_ptr = (const gchar *)line[i];
 	    if(line_ptr == NULL)
 		continue;
 
 	    /* Is string found on this line? */
-	    cstrptr = (const char *)strstr(line_ptr, string);
+	    cstrptr = (const gchar *)strstr(line_ptr, string);
 	    if(cstrptr == NULL)
 	    {
 		/* Add the length of this line plus one for the newline
@@ -122,12 +120,12 @@ static fip_match_struct *EditorFIPDoSearchInArray(
 	    else
 	    {
 		/* Got match! */
-		int sp, ep;
+		gint sp, ep;
 
-		sp = buf_len + (int)(cstrptr - line_ptr);
+		sp = buf_len + (gint)(cstrptr - line_ptr);
 		ep = sp + strlen(string);
 
-		/* Allocate a new return. */
+		/* Allocate a new return */
 		n = total_matches;
 		total_matches = n + 1;
 
@@ -142,7 +140,7 @@ static fip_match_struct *EditorFIPDoSearchInArray(
 		}
 		else
 		{
-		    /* Set new match structure values. */
+		    /* Set new match structure values */
 		    fip_match_struct *match_ptr = &(match[n]);
 
 		    match_ptr->line_num = i;
@@ -157,7 +155,7 @@ static fip_match_struct *EditorFIPDoSearchInArray(
 	    }
 	}
 
-	/* Update returns. */
+	/* Update returns */
 	if(matches_rtn != NULL)
 	    (*matches_rtn) = total_matches;
 
@@ -173,16 +171,16 @@ static fip_match_struct *EditorFIPDoSearchInArray(
  *
  *      Returns the number of matches.
  */
-static int EditorFIPDoFindAnyBranchIteration(
+static gint EditorFIPDoFindAnyBranchIteration(
 	editor_fip_struct *fip, editor_struct *editor,
 	GtkCList *results_clist, GtkCTree *layout_ctree,
 	GtkCTreeNode *branch,
-	char **strv, int strc, gbool case_sensitive,
-	const char *manual_page_name
+	gchar **strv, gint strc, gboolean case_sensitive,
+	const gchar *manual_page_name
 )
 {
-	int i, n, new_matches, match_count = 0;
-	char **line;
+	gint i, n, new_matches, match_count = 0;
+	gchar **line;
 	GtkCTreeRow *branch_row;
 	editor_item_struct *item_ptr;
 	fip_match_struct *match, *match_ptr;
@@ -196,70 +194,51 @@ static int EditorFIPDoFindAnyBranchIteration(
 
 	EditorFIPSetStatusProgress(fip, -1.0);
 
-	/* Get item data from branch. */
+	/* Get item data from branch */
 	item_ptr = EditorBranchGetData(layout_ctree, branch);
 	if(item_ptr != NULL)
 	{
-	    char *tmp_buf;
-	    int tmp_buf_len;
+	    gchar *s;
 
-	    /* Search through item data by its type. */
+	    /* Search through item data by its type */
 	    switch(item_ptr->type)
 	    {
 	      case EditorItemTypeFile:
-		/* Allocate message. */
-		tmp_buf_len = ((item_ptr->file_name == NULL) ?
-		    0 : strlen(item_ptr->file_name)) + 256;
-		tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-		if(tmp_buf != NULL)
-		    sprintf(tmp_buf, "Searching: Manual Page \"%s\"",
-			item_ptr->file_name
-		    );
-
-		EditorFIPSetStatusMessage(fip, tmp_buf);
-
-		/* Deallocate message. */
-		free(tmp_buf);
-		tmp_buf = NULL;
-
-		/* Nothing to search. */
-
+		s = g_strdup_printf(
+		    "Searching: Manual Page \"%s\"",
+		    item_ptr->file_name
+		);
+		EditorFIPSetStatusMessage(fip, s);
+		g_free(s);
+		/* Nothing to search */
 		break;
 
 	       case EditorItemTypeHeader:
-		/* Allocate message. */
-		tmp_buf_len = 256;
-		tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-		if(tmp_buf != NULL)
-		    sprintf(tmp_buf, "Searching: Header");
+		s = g_strdup_printf(
+		    "Searching: Header"
+		);
+		EditorFIPSetStatusMessage(fip, s);
+		g_free(s);
 
-		EditorFIPSetStatusMessage(fip, tmp_buf);
-
-		/* Deallocate message. */
-		free(tmp_buf);
-		tmp_buf = NULL;
-
-
-		/* Create a line array with just one pointer. */
-		line = (char **)malloc(1 * sizeof(char *));
+		/* Create a line array with just one pointer */
+		line = (gchar **)g_malloc(1 * sizeof(gchar *));
 		if(line != NULL)
 		{
-		    /* Search through header name. */
-		    line[0] = ((item_ptr->header_name == NULL) ?
-			NULL : strdup(item_ptr->header_name)
-		    );
+		    /* Search through header name */
+		    line[0] = (item_ptr->header_name != NULL) ?
+			g_strdup(item_ptr->header_name) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0, n = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray(
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match != NULL)
 			{
 			    n++;
-			    free(match);
+			    g_free(match);
 			}
 		    }
 		    if(n > 0)
@@ -267,32 +246,31 @@ static int EditorFIPDoFindAnyBranchIteration(
 			EditorFIPAddItem(
 			    fip,
 			    item_ptr->header_name,
-			    -1,                 /* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
-		    /* Search through header section number. */
-		    free(line[0]);
-		    line[0] = ((item_ptr->header_section_number == NULL) ?
-			NULL : strdup(item_ptr->header_section_number)
-		    );
+		    /* Search through header section number */
+		    g_free(line[0]);
+		    line[0] = (item_ptr->header_section_number != NULL) ?
+			g_strdup(item_ptr->header_section_number) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0, n = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray(
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match != NULL)
 			{
 			    n++;
-			    free(match);
+			    g_free(match);
 			}
 		    }
 		    if(n > 0)
@@ -300,17 +278,17 @@ static int EditorFIPDoFindAnyBranchIteration(
 			EditorFIPAddItem(   
 			    fip,
 			    item_ptr->header_section_number,
-			    -1,                 /* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 		
-		    /* Search through header version. */
-		    free(line[0]);
+		    /* Search through header version */
+		    g_free(line[0]);
 		    line[0] = ((item_ptr->header_version == NULL) ?
 			NULL : strdup(item_ptr->header_version)
 		    );
@@ -319,13 +297,13 @@ static int EditorFIPDoFindAnyBranchIteration(
 		    for(i = 0, n = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray(
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match != NULL)
 			{
 			    n++;
-			    free(match);
+			    g_free(match);
 			}
 		    }
 		    if(n > 0)
@@ -333,17 +311,17 @@ static int EditorFIPDoFindAnyBranchIteration(
 			EditorFIPAddItem(   
 			    fip,
 			    item_ptr->header_version,
-			    -1,                 /* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 		
-		    /* Search through header author. */ 
-		    free(line[0]);
+		    /* Search through header author */ 
+		    g_free(line[0]);
 		    line[0] = ((item_ptr->header_author == NULL) ? 
 			NULL : strdup(item_ptr->header_author) 
 		    );
@@ -352,13 +330,13 @@ static int EditorFIPDoFindAnyBranchIteration(
 		    for(i = 0, n = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray(
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match != NULL)
 			{   
 			    n++;
-			    free(match);
+			    g_free(match);
 			}
 		    }
 		    if(n > 0)
@@ -366,17 +344,17 @@ static int EditorFIPDoFindAnyBranchIteration(
 			EditorFIPAddItem(   
 			    fip,
 			    item_ptr->header_author, 
-			    -1,                 /* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 		
-		    /* Search through header catagory. */
-		    free(line[0]);
+		    /* Search through header catagory */
+		    g_free(line[0]);
 		    line[0] = ((item_ptr->header_catagory == NULL) ?
 			NULL : strdup(item_ptr->header_catagory)
 		    );
@@ -385,13 +363,13 @@ static int EditorFIPDoFindAnyBranchIteration(
 		    for(i = 0, n = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray(
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match != NULL)
 			{   
 			    n++;
-			    free(match);
+			    g_free(match);
 			}
 		    }
 		    if(n > 0)
@@ -399,27 +377,27 @@ static int EditorFIPDoFindAnyBranchIteration(
 			EditorFIPAddItem(   
 			    fip,
 			    item_ptr->header_catagory,
-			    -1,                 /* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
-		    /* Free coppied lines array. */
-		    free(line[0]);
-		    free(line);
+		    /* Free coppied lines array */
+		    g_free(line[0]);
+		    g_free(line);
 		    line = NULL;
 		}
 
 
-		/* Begin searching through header comments. */
+		/* Begin searching through header comments */
 
-		/* Make a duplicate of each line. */
+		/* Make a duplicate of each line */
 		line = strlistcopy(
-		    (const char **)item_ptr->line, item_ptr->total_lines
+		    (const gchar **)item_ptr->line, item_ptr->total_lines
 		);
 		if(!case_sensitive && (line != NULL))
 		{
@@ -435,7 +413,7 @@ static int EditorFIPDoFindAnyBranchIteration(
 		    EditorFIPSetStatusProgress(fip, -1.0);
 
 		    match = EditorFIPDoSearchInArray(
-			(const char **)line, item_ptr->total_lines,
+			(const gchar **)line, item_ptr->total_lines,
 			strv[i], &new_matches
 		    );
 		    match_count += new_matches;
@@ -445,47 +423,39 @@ static int EditorFIPDoFindAnyBranchIteration(
 
 			EditorFIPAddItem(
 			    fip,
-			    ((match_ptr->line_num > -1) ?
-				item_ptr->line[match_ptr->line_num] : ""
-			    ),
+			    (match_ptr->line_num > -1) ?
+				item_ptr->line[match_ptr->line_num] : "",
 			    match_ptr->line_num,
 			    "Header",
 			    manual_page_name,
-			    branch,		/* Found branch. */
-			    (void *)item_ptr,	/* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    match_ptr->start_pos, match_ptr->end_pos
 			);
 		    }
 
-		    /* Deallocate match structures list return. */
-		    free(match);
+		    /* Delete match structures list return */
+		    g_free(match);
 		    match = NULL;
 		    new_matches = 0;
 		}
 
-		/* Deallocate coppied lines. */
+		/* Delete coppied lines */
 		strlistfree(line, item_ptr->total_lines);
 		line = NULL;
 		break;
 
 	      case EditorItemTypeSection:
-		/* Allocate message. */
-		tmp_buf_len = ((item_ptr->section_name == NULL) ?
-		    0 : strlen(item_ptr->section_name)
-		) + 256;
-		tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-		if(tmp_buf != NULL)
-		    sprintf(tmp_buf, "Searching: \"%s\"", item_ptr->section_name);
+		s = g_strdup_printf(
+		    "Searching: \"%s\"",
+		    item_ptr->section_name
+		);
+		EditorFIPSetStatusMessage(fip, s);
+		g_free(s);
 
-		EditorFIPSetStatusMessage(fip, tmp_buf);
-
-		/* Deallocate message. */
-		free(tmp_buf);
-		tmp_buf = NULL;
-
-		/* Make a duplicate of each line. */
+		/* Make a duplicate of each line */
 		line = strlistcopy(
-		    (const char **)item_ptr->line, item_ptr->total_lines
+		    (const gchar **)item_ptr->line, item_ptr->total_lines
 		);
 		if(!case_sensitive && (line != NULL))
 		{
@@ -494,14 +464,14 @@ static int EditorFIPDoFindAnyBranchIteration(
 		}
 
 		/* Search through each coppied line, recording any
-		 * occurance of each search string.
+		 * occurance of each search string
 		 */
 		for(i = 0; i < strc; i++)
 		{
 		    EditorFIPSetStatusProgress(fip, -1.0);
 
 		    match = EditorFIPDoSearchInArray(
-			(const char **)line, item_ptr->total_lines,
+			(const gchar **)line, item_ptr->total_lines,
 			strv[i], &new_matches
 		    );
 		    match_count += new_matches;
@@ -511,27 +481,25 @@ static int EditorFIPDoFindAnyBranchIteration(
 
 			EditorFIPAddItem(
 			    fip,
-			    ((match_ptr->line_num > -1) ?
-				item_ptr->line[match_ptr->line_num] : ""
-			    ),
+			    (match_ptr->line_num > -1) ?
+				item_ptr->line[match_ptr->line_num] : "",
 			    match_ptr->line_num,
-			    ((item_ptr->section_name == NULL) ?
-				"(null)" : item_ptr->section_name
-			    ),
+			    (item_ptr->section_name != NULL) ?
+				item_ptr->section_name : "(null)",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    match_ptr->start_pos, match_ptr->end_pos
 			);
 		    }
 
-		    /* Deallocate match structures list return. */
-		    free(match);
+		    /* Delete match structures list return */
+		    g_free(match);
 		    match = NULL;
 		    new_matches = 0;
 		}
 
-		/* Deallocate coppied lines. */
+		/* Delete coppied lines */
 		strlistfree(line, item_ptr->total_lines);
 		line = NULL;
 
@@ -539,13 +507,13 @@ static int EditorFIPDoFindAnyBranchIteration(
 	    }
 	}
 
-	/* Get branch row. */
+	/* Get branch row */
 	branch_row = GTK_CTREE_ROW(branch);
 
 	/* Branch has children? */
 	if(branch_row->children != NULL)
 	{
-	    /* Set branch to point to first child. */
+	    /* Set branch to point to first child */
 	    branch = branch_row->children;
 
 	    while(branch != NULL)
@@ -574,16 +542,16 @@ static int EditorFIPDoFindAnyBranchIteration(
  *
  *	Returns the number of matches.
  */
-static int EditorFIPDoFindAllBranchIteration(
+static gint EditorFIPDoFindAllBranchIteration(
 	editor_fip_struct *fip, editor_struct *editor,
 	GtkCList *results_clist, GtkCTree *layout_ctree,
 	GtkCTreeNode *branch,
-	char **strv, int strc, gbool case_sensitive,
-	const char *manual_page_name
+	gchar **strv, gint strc, gboolean case_sensitive,
+	const gchar *manual_page_name
 )
 {
-	int i, new_matches, match_count = 0;
-	char **line;
+	gint i, new_matches, match_count = 0;
+	gchar **line;
 	GtkCTreeRow *branch_row;
 	editor_item_struct *item_ptr;
 	fip_match_struct *match;
@@ -597,88 +565,71 @@ static int EditorFIPDoFindAllBranchIteration(
 
 	EditorFIPSetStatusProgress(fip, -1.0);
 
-	/* Get item data from branch. */
+	/* Get item data from branch */
 	item_ptr = EditorBranchGetData(layout_ctree, branch);
 	if(item_ptr != NULL)
 	{
-	    char *tmp_buf;
-	    int tmp_buf_len;
+	    gchar *s;
 
-	    /* Search through item data by its type. */
+	    /* Search through item data by its type */
 	    switch(item_ptr->type)
 	    {
 	      case EditorItemTypeFile:
-		/* Allocate message. */
-		tmp_buf_len = ((item_ptr->file_name == NULL) ?
-		    0 : strlen(item_ptr->file_name)) + 256;
-		tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-		if(tmp_buf != NULL)
-		    sprintf(tmp_buf, "Searching: Manual Page \"%s\"",
-			item_ptr->file_name
-		    );
+		s = g_strdup_printf(
+		    "Searching: Manual Page \"%s\"",
+		    item_ptr->file_name
+		);
+		EditorFIPSetStatusMessage(fip, s);
+		g_free(s);
 
-		EditorFIPSetStatusMessage(fip, tmp_buf);
-
-		/* Deallocate message. */
-		free(tmp_buf);   
-		tmp_buf = NULL;
-
-		/* Nothing to search. */
+		/* Nothing to search */
 
 		break;
 
 	      case EditorItemTypeHeader:
-		/* Allocate message. */
-		tmp_buf_len = 256;
-		tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-		if(tmp_buf != NULL)
-		    sprintf(tmp_buf, "Searching: Header");
+		s = g_strdup_printf(
+		    "Searching: Header"
+		);
+		EditorFIPSetStatusMessage(fip, s);
+		g_free(s);
 
-		EditorFIPSetStatusMessage(fip, tmp_buf);
-
-		/* Deallocate message. */
-		free(tmp_buf);
-		tmp_buf = NULL;
-
-
-		/* Create a line array with just one pointer. */
-		line = (char **)malloc(1 * sizeof(char *));
+		/* Create a line array with just one pointer */
+		line = (gchar **)g_malloc(1 * sizeof(gchar *));
 		if(line != NULL)
 		{
-		    /* Search through header name. */
-		    line[0] = ((item_ptr->header_name == NULL) ?
-			NULL : strdup(item_ptr->header_name)
-		    );
+		    /* Search through header name */
+		    line[0] = (item_ptr->header_name != NULL) ?
+			g_strdup(item_ptr->header_name) : NULL;
 		    if(!case_sensitive)
 			strtoupper(line[0]);
 		    for(i = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray(
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match == NULL)
 			    break;
 
-			/* Deallocate match structures list return. */
-			free(match);
+			/* Delete match structures list return */
+			g_free(match);
 		    }
 		    if(i >= strc)
 		    {
 			EditorFIPAddItem(
 			    fip,
 			    item_ptr->header_name,
-			    -1,			/* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,		/* Found branch. */
-			    (void *)item_ptr,	/* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
-		    /* Search through header section number. */
-		    free(line[0]);
+		    /* Search through header section number */
+		    g_free(line[0]);
 		    line[0] = ((item_ptr->header_section_number == NULL) ?
 			NULL : strdup(item_ptr->header_section_number)
 		    );
@@ -687,31 +638,31 @@ static int EditorFIPDoFindAllBranchIteration(
 		    for(i = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray(
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match == NULL)
 			    break;
 		   
-			/* Deallocate match structures list return. */
-			free(match);
+			/* Delete match structures list return */
+			g_free(match);
 		    }
 		    if(i >= strc)
 		    {
 			EditorFIPAddItem(
 			    fip,
 			    item_ptr->header_section_number,
-			    -1,			/* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,		/* Found branch. */
-			    (void *)item_ptr,	/* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
-		    /* Search through header version. */
-		    free(line[0]);
+		    /* Search through header version */
+		    g_free(line[0]);
 		    line[0] = ((item_ptr->header_version == NULL) ?
 			NULL : strdup(item_ptr->header_version)
 		    );
@@ -720,31 +671,31 @@ static int EditorFIPDoFindAllBranchIteration(
 		    for(i = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray(
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match == NULL)
 			    break;
 
-			/* Deallocate match structures list return. */
-			free(match);
+			/* Delete match structures list return */
+			g_free(match);
 		    }
 		    if(i >= strc)
 		    {
 			EditorFIPAddItem(
 			    fip,
 			    item_ptr->header_version,
-			    -1,                 /* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
-		    /* Search through header author. */
-		    free(line[0]);
+		    /* Search through header author */
+		    g_free(line[0]);
 		    line[0] = ((item_ptr->header_author == NULL) ?
 			NULL : strdup(item_ptr->header_author)
 		    );
@@ -753,31 +704,31 @@ static int EditorFIPDoFindAllBranchIteration(
 		    for(i = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray( 
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match == NULL)
 			    break;
 
-			/* Deallocate match structures list return. */
-			free(match);
+			/* Delete match structures list return */
+			g_free(match);
 		    }
 		    if(i >= strc)
 		    {
 			EditorFIPAddItem(
 			    fip,
 			    item_ptr->header_author,
-			    -1,                 /* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
-		    /* Search through header catagory. */
-		    free(line[0]);
+		    /* Search through header catagory */
+		    g_free(line[0]);
 		    line[0] = ((item_ptr->header_catagory == NULL) ?
 			NULL : strdup(item_ptr->header_catagory)
 		    );
@@ -786,41 +737,41 @@ static int EditorFIPDoFindAllBranchIteration(
 		    for(i = 0; i < strc; i++)
 		    {
 			match = EditorFIPDoSearchInArray( 
-			    (const char **)line, 1,
+			    (const gchar **)line, 1,
 			    strv[i], &new_matches
 			);
 			if(match == NULL)
 			    break;
 
-			/* Deallocate match structures list return. */
-			free(match);
+			/* Delete match structures list return */
+			g_free(match);
 		    }
 		    if(i >= strc) 
 		    {
 			EditorFIPAddItem(
 			    fip,
 			    item_ptr->header_catagory,
-			    -1,                 /* N/a. */
+			    -1,			/* N/a */
 			    "Header",
 			    manual_page_name,
-			    branch,             /* Found branch. */
-			    (void *)item_ptr,   /* Branch data. */
+			    branch,		/* Found branch */
+			    item_ptr,		/* Branch data */
 			    -1, -1
 			);
 		    }
 
-		    /* Free coppied lines array. */
-		    free(line[0]);
-		    free(line);
+		    /* Free coppied lines array */
+		    g_free(line[0]);
+		    g_free(line);
 		    line = NULL;
 		}
 
 
-		/* Begin searching through header comments. */
+		/* Begin searching through header comments */
 
-		/* Make a duplicate of each line. */
+		/* Make a duplicate of each line */
 		line = strlistcopy(
-		    (const char **)item_ptr->line, item_ptr->total_lines
+		    (const gchar **)item_ptr->line, item_ptr->total_lines
 		);
 		if(!case_sensitive && (line != NULL))
 		{
@@ -836,7 +787,7 @@ static int EditorFIPDoFindAllBranchIteration(
 		    EditorFIPSetStatusProgress(fip, -1.0);
 
 		    match = EditorFIPDoSearchInArray(
-			(const char **)line, item_ptr->total_lines,
+			(const gchar **)line, item_ptr->total_lines,
 			strv[i], &new_matches
 		    );
 		    /* Break if one of the search strings is not in the
@@ -845,8 +796,8 @@ static int EditorFIPDoFindAllBranchIteration(
 		    if(match == NULL)
 			break;
 
-		    /* Deallocate match structures list return. */
-		    free(match);
+		    /* Delete match structures list return */
+		    g_free(match);
 		    match = NULL;
 		    new_matches = 0;
 		}
@@ -855,45 +806,37 @@ static int EditorFIPDoFindAllBranchIteration(
 		    /* All search strings matched! */
 		    match_count++;
 
-		    /* Consider this as one match. */
+		    /* Consider this as one match */
 		    EditorFIPAddItem(
 			fip,
-			((item_ptr->total_lines > 0) ?
-			    item_ptr->line[0] : ""
-			),
-			-1,		/* N/a. */
+			(item_ptr->total_lines > 0) ?
+			    item_ptr->line[0] : "",
+			-1,			/* N/a */
 			"Header",
 			manual_page_name,
-			branch,			/* Found branch. */
-			(void *)item_ptr,	/* Branch data. */
+			branch,			/* Found branch */
+			item_ptr,		/* Branch data */
 			-1, -1
 		   );
 		}
 
-		/* Deallocate coppied lines. */
+		/* Delete coppied lines */
 		strlistfree(line, item_ptr->total_lines);
 		line = NULL;
 
 		break;
 
 	      case EditorItemTypeSection:
-		/* Allocate message. */ 
-		tmp_buf_len = ((item_ptr->section_name == NULL) ?
-		    0 : strlen(item_ptr->section_name)
-		) + 256;
-		tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-		if(tmp_buf != NULL)
-		    sprintf(tmp_buf, "Searching: \"%s\"", item_ptr->section_name);
+		s = g_strdup_printf(
+		    "Searching: \"%s\"",
+		    item_ptr->section_name
+		);
+		EditorFIPSetStatusMessage(fip, s);
+		g_free(s);
 
-		EditorFIPSetStatusMessage(fip, tmp_buf);
-
-		/* Deallocate message. */
-		free(tmp_buf);
-		tmp_buf = NULL;
-
-		/* Make a duplicate of each line. */
+		/* Make a duplicate of each line */
 		line = strlistcopy(
-		    (const char **)item_ptr->line, item_ptr->total_lines
+		    (const gchar **)item_ptr->line, item_ptr->total_lines
 		);
 		if(!case_sensitive && (line != NULL))
 		{
@@ -901,13 +844,13 @@ static int EditorFIPDoFindAllBranchIteration(
 			strtoupper(line[i]);
 		}
 
-		/* Search through each coppied line. */
+		/* Search through each coppied line */
 		for(i = 0; i < strc; i++)
 		{
 		    EditorFIPSetStatusProgress(fip, -1.0);
 
 		    match = EditorFIPDoSearchInArray(
-			(const char **)line, item_ptr->total_lines,
+			(const gchar **)line, item_ptr->total_lines,
 			strv[i], &new_matches
 		    );
 		    /* Break if one of the search strings is not in the
@@ -916,8 +859,8 @@ static int EditorFIPDoFindAllBranchIteration(
 		    if(match == NULL)
 			break;
 
-		    /* Deallocate match structures list return. */
-		    free(match);
+		    /* Delete match structures list return */
+		    g_free(match);
 		    match = NULL;
 		    new_matches = 0;
 		}
@@ -926,24 +869,22 @@ static int EditorFIPDoFindAllBranchIteration(
 		    /* All search strings matched! */
 		    match_count++;
 
-		    /* Consider this as one match. */
+		    /* Consider this as one match */
 		    EditorFIPAddItem(
 			fip,
-			((item_ptr->total_lines > 0) ?
-			    item_ptr->line[0] : ""
-			),
-			-1,              /* N/a. */
-			((item_ptr->section_name == NULL) ?
-			    "(null)" : item_ptr->section_name
-			),
+			(item_ptr->total_lines > 0) ?
+			    item_ptr->line[0] : "",
+			-1,			/* N/a */
+			(item_ptr->section_name != NULL) ?
+			    item_ptr->section_name : "(null)",
 			manual_page_name,
-			branch,			/* Found branch. */
-			(void *)item_ptr,	/* Branch data. */
+			branch,			/* Found branch */
+			item_ptr,		/* Branch data */
 			-1, -1
 		    );
 		}
 
-		/* Deallocate coppied lines. */
+		/* Delete coppied lines */
 		strlistfree(line, item_ptr->total_lines);
 		line = NULL;
 
@@ -951,13 +892,13 @@ static int EditorFIPDoFindAllBranchIteration(
 	    }
 	}
 
-	/* Get branch row. */
+	/* Get branch row */
 	branch_row = GTK_CTREE_ROW(branch);
 
 	/* Branch has children? */
 	if(branch_row->children != NULL)
 	{
-	    /* Set branch to point to first child. */
+	    /* Set branch to point to first child */
 	    branch = branch_row->children;
 
 	    while(branch != NULL)
@@ -984,22 +925,22 @@ static int EditorFIPDoFindAllBranchIteration(
  *
  *	Returns number of matches made.
  */
-static int EditorFIPDoFindAny(
+static gint EditorFIPDoFindAny(
 	editor_fip_struct *fip, editor_struct *editor,
 	GtkCList *results_clist, GtkCTree *layout_ctree,
-	const char *string, gbool case_sensitive, gbool explode_string
+	const gchar *string, gboolean case_sensitive, gboolean explode_string
 )
 {
-	int match_count = 0;
+	gint match_count = 0;
 	GtkCTreeNode *branch;
 	GtkCTreeRow *branch_row;
-	char **strv;
-	int strc;
+	gchar **strv;
+	gint strc;
 	editor_item_struct *item_ptr;
-	const char *manual_page_name;
+	const gchar *manual_page_name;
 
 
-	/* Get first branch on layout ctree. */
+	/* Get first branch on layout ctree */
 	branch = gtk_ctree_node_nth(layout_ctree, 0);
 	if(branch == NULL)
 	    return(match_count);
@@ -1014,7 +955,7 @@ static int EditorFIPDoFindAny(
 	else
 	{
 	    strc = 1;
-	    strv = (char **)malloc(strc * sizeof(char *));
+	    strv = (gchar **)g_malloc(strc * sizeof(gchar *));
 	    if(strv == NULL)
 		return(match_count);
 	    else
@@ -1026,13 +967,13 @@ static int EditorFIPDoFindAny(
 	 */
 	if(!case_sensitive)
 	{
-	    int i;
+	    gint i;
 
 	    for(i = 0; i < strc; i++)
 		strtoupper(strv[i]);
 	}   
 
-	/* Begin searching for all occurances through each branch. */
+	/* Begin searching for all occurances through each branch */
 	while(branch != NULL)
 	{
 	    while(gtk_events_pending() > 0)
@@ -1041,17 +982,17 @@ static int EditorFIPDoFindAny(
 	    if(fip->stop_find_count > 0)
 		break;
 
-	    /* Get item data pointer for branch. */
+	    /* Get item data pointer for branch */
 	    item_ptr = EditorBranchGetData(layout_ctree, branch);
 
 	    /* Get manual page name from (assumed) toplevel branch
 	     * item data.
 	     */
-	    manual_page_name = (const char *)(
+	    manual_page_name = (const gchar *)(
 		(item_ptr == NULL) ? NULL : item_ptr->file_name
 	    );
 
-	    /* Do find any for this branch and all its child branches. */
+	    /* Do find any for this branch and all its child branches */
 	    match_count += EditorFIPDoFindAnyBranchIteration(
 		fip, editor,
 		results_clist, layout_ctree,
@@ -1060,14 +1001,14 @@ static int EditorFIPDoFindAny(
 		manual_page_name
 	    );
 
-	    /* Get branch row. */
+	    /* Get branch row */
 	    branch_row = GTK_CTREE_ROW(branch);
 
-	    /* Get sibling of branch and set it as new branch. */
+	    /* Get sibling of branch and set it as new branch */
 	    branch = ((branch_row == NULL) ? NULL : branch_row->sibling);
 	}
 
-	/* Deallocate exploded search string. */
+	/* Delete exploded search string */
 	strlistfree(strv, strc);
 
 	return(match_count);
@@ -1080,22 +1021,22 @@ static int EditorFIPDoFindAny(
  *
  *	Returns number of matches made.
  */
-static int EditorFIPDoFindAll(
+static gint EditorFIPDoFindAll(
 	editor_fip_struct *fip, editor_struct *editor,
 	GtkCList *results_clist, GtkCTree *layout_ctree,
-	const char *string, gbool case_sensitive, gbool explode_string
+	const gchar *string, gboolean case_sensitive, gboolean explode_string
 )
 {
-	int match_count = 0;
+	gint match_count = 0;
 	GtkCTreeNode *branch;
 	GtkCTreeRow *branch_row;
-	char **strv;
-	int strc;
+	gchar **strv;
+	gint strc;
 	editor_item_struct *item_ptr;
-	const char *manual_page_name;
+	const gchar *manual_page_name;
 
 
-	/* Get first branch on layout ctree. */
+	/* Get first branch on layout ctree */
 	branch = gtk_ctree_node_nth(layout_ctree, 0);
 	if(branch == NULL)
 	    return(match_count);
@@ -1110,7 +1051,7 @@ static int EditorFIPDoFindAll(
 	else
 	{
 	    strc = 1;
-	    strv = (char **)malloc(strc * sizeof(char *));
+	    strv = (gchar **)g_malloc(strc * sizeof(gchar *));
 	    if(strv == NULL)
 		return(match_count);
 	    else
@@ -1122,13 +1063,13 @@ static int EditorFIPDoFindAll(
 	 */
 	if(!case_sensitive)
 	{
-	    int i;
+	    gint i;
 
 	    for(i = 0; i < strc; i++)
 		strtoupper(strv[i]);
 	}
 
-	/* Begin searching for all occurances through each branch. */
+	/* Begin searching for all occurances through each branch */
 	while(branch != NULL)
 	{
 	    while(gtk_events_pending() > 0)
@@ -1137,17 +1078,17 @@ static int EditorFIPDoFindAll(
 	    if(fip->stop_find_count > 0)
 		break;              
 
-	    /* Get item data pointer for branch. */
+	    /* Get item data pointer for branch */
 	    item_ptr = EditorBranchGetData(layout_ctree, branch);
 	    
 	    /* Get manual page name from (assumed) toplevel branch
 	     * item data.
 	     */
-	    manual_page_name = (const char *)(
+	    manual_page_name = (const gchar *)(
 		(item_ptr == NULL) ? NULL : item_ptr->file_name
 	    );
 
-	    /* Do find all for this branch and all its child branches. */
+	    /* Do find all for this branch and all its child branches */
 	    match_count += EditorFIPDoFindAllBranchIteration(
 		fip, editor,
 		results_clist, layout_ctree,
@@ -1156,14 +1097,14 @@ static int EditorFIPDoFindAll(
 		manual_page_name
 	    );
 
-	    /* Get branch row. */
+	    /* Get branch row */
 	    branch_row = GTK_CTREE_ROW(branch);
 
-	    /* Get sibling of branch and set it as new branch. */
+	    /* Get sibling of branch and set it as new branch */
 	    branch = ((branch_row == NULL) ? NULL : branch_row->sibling);
 	}
 
-	/* Deallocate exploded search string. */
+	/* Delete exploded search string */
 	strlistfree(strv, strc);
 
 	return(match_count);
@@ -1178,14 +1119,14 @@ static int EditorFIPDoFindAll(
  *
  *	Returns the number of matches.
  */
-int EditorFIPDoFind(
+gint EditorFIPDoFind(
 	editor_fip_struct *fip, editor_struct *editor,
-	int throughness,        /* 0 = match all, 1 = match any. */
-	const char *string,
-	gbool case_sensitive
+	gint throughness,        /* 0 = match all, 1 = match any */
+	const gchar *string,
+	gboolean case_sensitive
 )
 {
-	int matches_count = 0;
+	gint matches_count = 0;
 	GtkCList *results_clist;
 	GtkCTree *layout_ctree;
 
@@ -1206,17 +1147,17 @@ int EditorFIPDoFind(
 	EditorDoApplyValues(editor, editor->selected_branch);
 
 
-	/* Mark dialog as processing. */
+	/* Mark dialog as processing */
 	fip->processing = TRUE;
 
-	/* Reset stop_find_count on dialog. */
+	/* Reset stop_find_count on dialog */
 	fip->stop_find_count = 0;
 
-	/* Update menus and buttons to reflect processing. */
+	/* Update menus and buttons to reflect processing */
 	EditorFIPUpdateMenus(fip);
 
 
-	/* Get pointer to results clist on dialog (must be valid). */
+	/* Get pointer to results clist on dialog (must be valid) */
 	results_clist = (GtkCList *)fip->results_clist;
 	if(results_clist == NULL)
 	{
@@ -1224,7 +1165,7 @@ int EditorFIPDoFind(
 	    return(matches_count);
 	}
 
-	/* Get pointer to layout ctree on editor (must be valid). */
+	/* Get pointer to layout ctree on editor (must be valid) */
 	layout_ctree = (GtkCTree *)editor->layout_ctree;
 	if(layout_ctree == NULL)
 	{
@@ -1238,7 +1179,7 @@ int EditorFIPDoFind(
 	 */
 	if((throughness == 0) || (throughness == 2))
 	{
-	    const char *cstrptr = (const char *)strchr(string, ' ');
+	    const gchar *cstrptr = (const gchar *)strchr(string, ' ');
 	    if(cstrptr == NULL)
 	    {
 		/* Only one argument, so there is no need to match all or
@@ -1248,10 +1189,10 @@ int EditorFIPDoFind(
 	    }
 	}
 
-	/* Handle by throughness. */
+	/* Handle by throughness */
 	switch(throughness)
 	{
-	  case 2:	/* Match phrase. */
+	  case 2:	/* Match phrase */
 	    matches_count += EditorFIPDoFindAny(  
 		fip, editor,
 		results_clist, layout_ctree,
@@ -1259,7 +1200,7 @@ int EditorFIPDoFind(
 	    );
 	    break;
 
-	  case 1:	/* Match any occurance. */
+	  case 1:	/* Match any occurance */
 	    matches_count += EditorFIPDoFindAny(
 		fip, editor,
 		results_clist, layout_ctree,
@@ -1267,7 +1208,7 @@ int EditorFIPDoFind(
 	    );
 	    break;
 
-	  case 0:	/* Match all occurances. */
+	  case 0:	/* Match all occurances */
 	    matches_count += EditorFIPDoFindAll(
 		fip, editor,
 		results_clist, layout_ctree,
@@ -1277,7 +1218,7 @@ int EditorFIPDoFind(
 	}
 
 
-	/* Mark dialog as done processing. */
+	/* Mark dialog as done processing */
 	fip->processing = FALSE;
 
 	return(matches_count);
