@@ -1,15 +1,12 @@
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdlib.h>
 #include <ctype.h>
-#include <unistd.h>		/* For unlink(). */
-#include <sys/stat.h>
-#include <sys/types.h>
 #include <gtk/gtk.h>
+#include <unistd.h>		/* For unlink() */
 
 #include "../include/string.h"
 #include "../include/strexp.h"
+#include "../include/disk.h"
 
 #include "guiutils.h"
 #include "cdialog.h"
@@ -24,11 +21,12 @@
 
 #include "manedit.h"
 #include "maneditop.h"
+#include "config.h"
 
 
 void EditorSyntaxHighlight(
 	editor_struct *editor, GtkWidget *w,
-	int cursor_pos, int start_pos, int end_pos
+	gint cursor_pos, gint start_pos, gint end_pos
 );
 
 void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch);
@@ -37,27 +35,27 @@ void EditorDoClearValues(editor_struct *editor);
 
 void EditorDoPreview(
 	editor_struct *editor, GtkCTreeNode *branch,
-	int viewer_num
+	gint viewer_num
 );
 
-gbool EditorDoFind(
+gboolean EditorDoFind(
 	editor_struct *editor, GtkText *text,
-	char *haystack, char *needle,
-	int haystack_len, int start_pos,
-	gbool case_sensitive,
-	gbool move_to,
-	gbool *search_wrapped
+	gchar *haystack, gchar *needle,
+	gint haystack_len, gint start_pos,
+	gboolean case_sensitive,
+	gboolean move_to,
+	gboolean *search_wrapped
 );
-gbool EditorDoReplace(
+gboolean EditorDoReplace(
 	editor_struct *editor, GtkText *text,
-	char *haystack, char *needle, const char *replacement,
-	int haystack_len, int start_pos,
-	gbool case_sensitive
+	gchar *haystack, gchar *needle, const gchar *replacement,
+	gint haystack_len, gint start_pos,
+	gboolean case_sensitive
 );
-int EditorDoReplaceAll(
+gint EditorDoReplaceAll(
 	editor_struct *editor, GtkText *text,
-	char *needle, const char *replacement,
-	gbool case_sensitive
+	gchar *needle, const gchar *replacement,
+	gboolean case_sensitive
 );
 
 
@@ -78,13 +76,13 @@ int EditorDoReplaceAll(
  */
 void EditorSyntaxHighlight(
 	editor_struct *editor, GtkWidget *w,
-	int cursor_pos, int start_pos, int end_pos
+	gint cursor_pos, gint start_pos, gint end_pos
 )
 {
-	gbool in_tag, in_sym;
-	int c, orig_cur_pos, cur_pos, text_start, text_end;
-	gbool orig_has_selection;
-	int orig_sel_start = -1, orig_sel_end = -1;
+	gboolean in_tag, in_sym;
+	gint c, orig_cur_pos, cur_pos, text_start, text_end;
+	gboolean orig_has_selection;
+	gint orig_sel_start = -1, orig_sel_end = -1;
 	GtkStyle *style_ptr;
 	GtkText *text = (GtkText *)w;
 	GtkEditable *editable = (GtkEditable *)w;
@@ -106,11 +104,11 @@ void EditorSyntaxHighlight(
 
 	styles_list = &core_ptr->styles_list;
 
-	/* Set text bounds. */
-	text_start = 0;		/* Duh. */
-	text_end = (int)gtk_text_get_length(text);
+	/* Set text bounds */
+	text_start = 0;		/* Duh */
+	text_end = (gint)gtk_text_get_length(text);
 
-	/* Make sure start and end positions are in bounds. */
+	/* Make sure start and end positions are in bounds */
 	if(cursor_pos >= text_end)
 	    cursor_pos = text_end - 1;
 	if(start_pos >= text_end)
@@ -125,10 +123,10 @@ void EditorSyntaxHighlight(
 	if((cursor_pos < 0) && (start_pos > -1))
 	    cursor_pos = start_pos;
 
-	/* Record original cursor position. */
+	/* Record original cursor position */
 	orig_cur_pos = gtk_editable_get_position(editable);
 
-	/* Record original selection. */
+	/* Record original selection */
 	orig_has_selection = editable->has_selection;
 	if(orig_has_selection)
 	{
@@ -139,7 +137,7 @@ void EditorSyntaxHighlight(
 	/* Cursor position defined? */
 	if(cursor_pos > -1)
 	{
-	    /* Set starting cursor position. */
+	    /* Set starting cursor position */
 	    cur_pos = cursor_pos;
 
 	    /* Itterate backwards untill a deliminator is encountered,
@@ -173,7 +171,7 @@ gtk_text_freeze(text);
 			);
 		    }
 		    in_tag = TRUE;
-		    cur_pos++;	/* Seek past tag. */
+		    cur_pos++;	/* Seek past tag */
 		    break;
 		}
 		/* Is character an tag deliminator end? */
@@ -193,7 +191,7 @@ gtk_text_freeze(text);
 			    1
 			);
 		    }
-		    cur_pos++;	/* Seek past tag. */
+		    cur_pos++;	/* Seek past tag */
 		    break;
 		}
 		/* Is character a start of a symbol representation? */
@@ -214,7 +212,7 @@ gtk_text_freeze(text);
 			);
 		    }
 		    in_sym = TRUE;
-		    cur_pos++;  /* Seek past symbol rep. */
+		    cur_pos++;  /* Seek past symbol rep */
 		    break;
 		}
 		/* Skip symbol representation end ';' when itterating
@@ -225,11 +223,11 @@ gtk_text_freeze(text);
 		    cur_pos--;
 		}
 	    }
-	    /* Make sure current position stays at or above text_start. */
+	    /* Make sure current position stays at or above text_start */
 	    if(cur_pos < text_start)
 		cur_pos = text_start;
 
-	    if(1)
+	    if(TRUE)
 	    {
 		/* Itterate to end of text or to a start or end
 		 * deliminator after end_pos.
@@ -254,7 +252,7 @@ gtk_text_freeze(text);
 				1
 			    );         
 			}
-			in_tag = TRUE;	/* Mark as in a tag. */
+			in_tag = TRUE;	/* Mark as in a tag */
 
 			/* Encountered a deliminator after end_pos? */
 			if(end_pos > -1)
@@ -280,7 +278,7 @@ gtk_text_freeze(text);
 				1  
 			    );
 			}
-			in_tag = FALSE;	/* Mark no longer in a tag. */
+			in_tag = FALSE;	/* Mark no longer in a tag */
 
 			/* Encountered a deliminator after end_pos? */
 			if(end_pos > -1)
@@ -306,7 +304,7 @@ gtk_text_freeze(text);
 				1
 			    );
 			}
-			in_sym = TRUE;  /* Mark as in a sym. */
+			in_sym = TRUE;  /* Mark as in a sym */
 
 			/* Encountered a deliminator after end_pos? */
 			if(end_pos > -1)
@@ -332,7 +330,7 @@ gtk_text_freeze(text);
 				1
 			    );
 			}
-			in_sym = FALSE;  /* Mark as no longer in sym. */
+			in_sym = FALSE;  /* Mark as no longer in sym */
 
 			/* Encountered a deliminator after end_pos? */
 			if(end_pos > -1)
@@ -351,7 +349,7 @@ gtk_text_freeze(text);
 			    style_ptr = styles_list->edit_text_standard;
 			if(style_ptr != NULL)
 			{
-			    char tmp_str[2];
+			    gchar tmp_str[2];
 
 			    tmp_str[0] = (char)c;
 			    tmp_str[1] = '\0';
@@ -369,7 +367,7 @@ gtk_text_freeze(text);
 			}
 		    }
 
-		    /* Increment to next position. */
+		    /* Increment to next position */
 		    cur_pos++;
 		}
 	    }
@@ -377,16 +375,16 @@ gtk_text_thaw(text);
 	}
 	else
 	{
-	    /* Highlight entire buffer. */
+	    /* Highlight entire buffer */
 
-	    /* Set cur_pos at start of text. */
+	    /* Set cur_pos at start of text */
 	    cur_pos = text_start;
 
-	    /* Reset in tag marker. */
+	    /* Reset in tag marker */
 	    in_tag = FALSE;
 	    in_sym = FALSE;
 
-	    /* Itterate to end of text. */
+	    /* Itterate to end of text */
 gtk_text_freeze(text);
 	    while(cur_pos < text_end)
 	    {
@@ -408,7 +406,7 @@ gtk_text_freeze(text);
 			    1
 			);
 		    }
-		    in_tag = TRUE;	/* Mark as in a tag. */
+		    in_tag = TRUE;	/* Mark as in a tag */
 		}
 		/* Is character a tag deliminator end? */
 		else if((c == '>') && in_tag)
@@ -427,7 +425,7 @@ gtk_text_freeze(text);
 			    1
 			);
 		    }
-		    in_tag = FALSE; /* Mark no longer in a tag. */
+		    in_tag = FALSE; /* Mark no longer in a tag */
 		}
 		/* Is character a symbol representation start? */
 		else if((c == '&') && !in_sym)
@@ -446,7 +444,7 @@ gtk_text_freeze(text);
 			    1   
 			);   
 		    }
-		    in_sym = TRUE;	/* Mark as in a sym. */
+		    in_sym = TRUE;	/* Mark as in a sym */
 		}
 		/* Is character a symbol representation end? */
 		else if((c == ';') && in_sym)
@@ -465,7 +463,7 @@ gtk_text_freeze(text);
 			    1
 			);
 		    }
-		    in_sym = FALSE;	/* Mark no longer in a sym. */
+		    in_sym = FALSE;	/* Mark no longer in a sym */
 		}
 		else
 		{
@@ -477,7 +475,7 @@ gtk_text_freeze(text);
 			style_ptr = styles_list->edit_text_standard;
 		    if(style_ptr != NULL)
 		    {
-			char tmp_str[2];
+			gchar tmp_str[2];
 
 			tmp_str[0] = (char)c;
 			tmp_str[1] = '\0';
@@ -499,7 +497,7 @@ gtk_text_freeze(text);
 gtk_text_thaw(text);
 	}
 
-	/* Set back original cursor position. */
+	/* Set back original cursor position */
 	gtk_text_set_point(text, orig_cur_pos);
 	gtk_editable_set_position(editable, orig_cur_pos);
 
@@ -512,7 +510,6 @@ gtk_text_thaw(text);
 	}
 
 
-	return;
 }
 
 
@@ -522,8 +519,8 @@ gtk_text_thaw(text);
  */
 void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 {
-	int i;
-	int map_editor_panel_type = -1;
+	gint i;
+	gint map_editor_panel_type = -1;
 	GtkWidget *w;
 	editor_item_struct *item_data_ptr;
 	medit_core_struct *core_ptr;
@@ -537,11 +534,11 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	if(!editor->initialized)
 	    return;
 
-	/* Check if already processing. */
+	/* Check if already processing */
 	if(editor->processing)
 	    return;
 
-	/* Get core pointer and subsequently the styles list. */
+	/* Get core pointer and subsequently the styles list */
 	core_ptr = (medit_core_struct *)editor->core_ptr;
 	if(core_ptr == NULL)
 	    styles_list = NULL;
@@ -549,13 +546,13 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    styles_list = &core_ptr->styles_list;
 
 
-	/* Get pointer to item data from ctree branch node. */
+	/* Get pointer to item data from ctree branch node */
 	item_data_ptr = EditorBranchGetData(
 	    (GtkCTree *)editor->layout_ctree, branch
 	);
 
 
-	/* Map and unmap editor panel widgets. */
+	/* Map and unmap editor panel widgets */
 	if(item_data_ptr != NULL)
 	    map_editor_panel_type = item_data_ptr->type;
 
@@ -582,7 +579,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    break;
 
 	  case EditorItemTypeHeader:
-	    /* Set entry widgets. */
+	    /* Set entry widgets */
 	    w = editor->header_name_entry;
 	    if(w != NULL)
 	    {
@@ -638,14 +635,13 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		    );
 	    }
 
-	    /* Get pointer to header text widget. */
+	    /* Get pointer to header text widget */
 	    w = editor->header_text;
 	    if(w != NULL)
 	    {
-		int text_len;
+		gint text_len;
 
-
-		/* Remove all text. */
+		/* Remove all text */
 		text_len = gtk_text_get_length(GTK_TEXT(w));
 		gtk_text_set_point(GTK_TEXT(w), 0);
 		gtk_text_freeze(GTK_TEXT(w));
@@ -655,7 +651,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		/* Item data valid? */
 		if(item_data_ptr != NULL)
 		{
-		    char *line_ptr;
+		    gchar *line_ptr;
 
 
 		    if(styles_list != NULL)
@@ -663,7 +659,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		    else
 			style_ptr = NULL;
 
-		    /* Set lines from item to text widget. */
+		    /* Set lines from item to text widget */
 		    gtk_text_freeze(GTK_TEXT(w));
 		    for(i = 0; i < item_data_ptr->total_lines; i++)
 		    {
@@ -671,22 +667,22 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 			if(line_ptr == NULL)
 			    continue;
 
-			/* Insert this line. */
+			/* Insert this line */
 			gtk_text_insert(
 			    GTK_TEXT(w),
 			    (style_ptr != NULL) ? style_ptr->font : NULL,
-			    NULL,	/* Foreground color. */
-			    NULL,	/* Background color. */
+			    NULL,	/* Foreground color */
+			    NULL,	/* Background color */
 			    line_ptr,
 			    -1
 			);
 
-			/* Need to insert a newline character at end. */
+			/* Need to insert a newline character at end */
 			gtk_text_insert(
 			    GTK_TEXT(w),
 			    (style_ptr != NULL) ? style_ptr->font : NULL,
-			    NULL,       /* Foreground color. */
-			    NULL,       /* Background color. */
+			    NULL,       /* Foreground color */
+			    NULL,       /* Background color */
 			    "\n",
 			    -1
 			);
@@ -697,7 +693,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    break;
 
 	  case EditorItemTypeSection:
-	    /* Section name entry. */
+	    /* Section name entry */
 	    w = editor->section_name_entry;
 	    if(w != NULL)
 	    {
@@ -708,14 +704,13 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		);
 	    }
 
-	    /* Get pointer to section text widget. */
+	    /* Get pointer to section text widget */
 	    w = editor->section_text;
 	    if(w != NULL)
 	    {
-		int text_len;
+		gint text_len;
 
-
-		/* Remove all text. */
+		/* Remove all text */
 		text_len = gtk_text_get_length(GTK_TEXT(w));
 		gtk_text_set_point(GTK_TEXT(w), 0);
 		gtk_text_freeze(GTK_TEXT(w));
@@ -725,7 +720,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		/* Item data valid? */  
 		if(item_data_ptr != NULL)
 		{
-		    char *line_ptr;
+		    gchar *line_ptr;
 
 
 		    if(styles_list != NULL)
@@ -733,7 +728,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		    else  
 			style_ptr = NULL;
 
-		    /* Set lines from item to text widget. */
+		    /* Set lines from item to text widget */
 		    gtk_text_freeze(GTK_TEXT(w));
 		    for(i = 0; i < item_data_ptr->total_lines; i++)
 		    {
@@ -741,29 +736,29 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 			if(line_ptr == NULL)
 			    continue;
 
-			/* Insert this line. */
+			/* Insert this line */
 			gtk_text_insert(
 			    GTK_TEXT(w),
 			    (style_ptr != NULL) ? style_ptr->font : NULL,
-			    NULL,       /* Foreground color. */
-			    NULL,       /* Background color. */
+			    NULL,       /* Foreground color */
+			    NULL,       /* Background color */
 			    line_ptr,
 			    -1
 			);
 
-			/* Need to insert a newline character at end. */
+			/* Need to insert a newline character at end */
 			gtk_text_insert( 
 			    GTK_TEXT(w),
 			    (style_ptr != NULL) ? style_ptr->font : NULL,
-			    NULL,       /* Foreground color. */
-			    NULL,       /* Background color. */
+			    NULL,       /* Foreground color */
+			    NULL,       /* Background color */
 			    "\n",
 			    -1
 			);
 		    }
 		    gtk_text_thaw(GTK_TEXT(w));
 
-		    /* Syntax highlighting for entire buffer. */
+		    /* Syntax highlighting for entire buffer */
 		    EditorSyntaxHighlight(
 			editor, w,
 			-1, -1, -1
@@ -773,10 +768,8 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    break;
 	}
 
-	/* Update menus. */
+	/* Update menus */
 	EditorUpdateMenus(editor);
-
-	return;
 }
 
 
@@ -787,7 +780,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 {
 	GtkWidget *w;
-	char *strptr;
+	gchar *strptr;
 	medit_pixmaps_list_struct *pixmaps_list;
 	medit_core_struct *core_ptr;
 	editor_item_struct *item_data_ptr;
@@ -799,7 +792,7 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	if(!editor->initialized)
 	    return;
 
-	/* Check if already processing. */
+	/* Check if already processing */
 	if(editor->processing)   
 	    return;
 
@@ -810,17 +803,17 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	pixmaps_list = &core_ptr->pixmaps_list;
 
 
-	/* Get pointer to item data from ctree branch node. */
+	/* Get pointer to item data from ctree branch node */
 	item_data_ptr = EditorBranchGetData(
 	    (GtkCTree *)editor->layout_ctree, branch
 	);
 	if(item_data_ptr == NULL)
 	{
-	    /* No data to apply. */
+	    /* No data to apply */
 	    return;
 	}
 
-	/* Check ctree branch node data type. */
+	/* Check ctree branch node data type */
 	switch(item_data_ptr->type)
 	{
 	  case EditorItemTypeFile:
@@ -828,88 +821,83 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	    break;
 			    
 	  case EditorItemTypeHeader:
-	    /* Header name entry. */
+	    /* Header name entry */
 	    w = editor->header_name_entry;
 	    if(w != NULL)
 	    {
 		strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		if(item_data_ptr != NULL)
 		{
-		    free(item_data_ptr->header_name);
-		    item_data_ptr->header_name = ((strptr == NULL) ?
-			NULL : strdup(strptr)
-		    );
+		    g_free(item_data_ptr->header_name);
+		    item_data_ptr->header_name = (strptr != NULL) ?
+			g_strdup(strptr) : NULL;
 		} 
 	    }
 
-	    /* Header section number entry. */
+	    /* Header section number entry */
 	    w = editor->header_section_number_entry;  
 	    if(w != NULL)
 	    {
 		strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		if(item_data_ptr != NULL)
 		{
-		    free(item_data_ptr->header_section_number);
-		    item_data_ptr->header_section_number = ((strptr == NULL) ?
-			NULL : strdup(strptr)
-		    );
+		    g_free(item_data_ptr->header_section_number);
+		    item_data_ptr->header_section_number = (strptr != NULL) ?
+			g_strdup(strptr) : NULL;
 		}
 	    }
 
-	    /* Header version entry. */
+	    /* Header version entry */
 	    w = editor->header_version_entry;
 	    if(w != NULL)
 	    {
 		strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		if(item_data_ptr != NULL)
 		{
-		    free(item_data_ptr->header_version);
-		    item_data_ptr->header_version = ((strptr == NULL) ?
-			NULL : strdup(strptr)
-		    );
+		    g_free(item_data_ptr->header_version);
+		    item_data_ptr->header_version = (strptr != NULL) ?
+			g_strdup(strptr) : NULL;
 		}
 	    }
 
-	    /* Header author entry. */
+	    /* Header author entry */
 	    w = editor->header_author_entry;
 	    if(w != NULL)
 	    {
 		strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		if(item_data_ptr != NULL)
 		{
-		    free(item_data_ptr->header_author);
-		    item_data_ptr->header_author = ((strptr == NULL) ?
-			NULL : strdup(strptr)
-		    );
+		    g_free(item_data_ptr->header_author);
+		    item_data_ptr->header_author = (strptr != NULL) ?
+			g_strdup(strptr) : NULL;
 		}
 	    }
 
-	    /* Header catagory entry. */
+	    /* Header catagory entry */
 	    w = editor->header_catagory_entry;
 	    if(w != NULL)
 	    {
 		strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		if(item_data_ptr != NULL)
 		{
-		    free(item_data_ptr->header_catagory); 
-		    item_data_ptr->header_catagory = ((strptr == NULL) ?
-			NULL : strdup(strptr)
-		    );
+		    g_free(item_data_ptr->header_catagory); 
+		    item_data_ptr->header_catagory = (strptr != NULL) ?
+			g_strdup(strptr) : NULL;
 		}
 	    }
 
-	    /* Header text. */
+	    /* Header text */
 	    w = editor->header_text;
 	    if(w != NULL)
 	    {
 		gchar *text_buf;
 
-		/* Unload existing lines. */
+		/* Unload existing lines */
 		strlistfree(item_data_ptr->line, item_data_ptr->total_lines);
 		item_data_ptr->line = NULL;
 		item_data_ptr->total_lines = 0;
 
-		/* Load new lines from widget. */
+		/* Load new lines from widget */
 		text_buf = gtk_editable_get_chars(
 		    GTK_EDITABLE(w), 0, -1
 		);
@@ -921,24 +909,23 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	    break;
 
 	  case EditorItemTypeSection:
-	    /* Section name entry. */
+	    /* Section name entry */
 	    w = editor->section_name_entry;
 	    if(w != NULL)
 	    {
 		strptr = gtk_entry_get_text(GTK_ENTRY(w));
 		if(item_data_ptr != NULL)
 		{
-		    free(item_data_ptr->section_name);
-		    item_data_ptr->section_name = ((strptr == NULL) ?
-			NULL : strdup(strptr)
-		    );
+		    g_free(item_data_ptr->section_name);
+		    item_data_ptr->section_name = (strptr != NULL) ?
+			g_strdup(strptr) : NULL;
 		}
 		if(strptr != NULL)
 		{
 		    gtk_ctree_node_set_pixtext(
 			(GtkCTree *)editor->layout_ctree,
-			branch,		/* Branch node. */
-			0,		/* Column. */
+			branch,		/* Branch node */
+			0,		/* Column */
 			strptr,
 			MEDIT_LIST_ICON_TEXT_SPACING,
 			pixmaps_list->manpage_section_20x20,
@@ -947,18 +934,18 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 		}
 	    }
 
-	    /* Section text. */
+	    /* Section text */
 	    w = editor->section_text;
 	    if(w != NULL)
 	    {
 		gchar *text_buf;
 
-		/* Unload existing lines. */
+		/* Unload existing lines */
 		strlistfree(item_data_ptr->line, item_data_ptr->total_lines);
 		item_data_ptr->line = NULL;
 		item_data_ptr->total_lines = 0;
 
-		/* Load new lines from widget. */
+		/* Load new lines from widget */
 		text_buf = gtk_editable_get_chars(
 		    GTK_EDITABLE(w), 0, -1
 		);
@@ -970,10 +957,8 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	    break;
 	}
 
-	/* Update menus. */
+	/* Update menus */
 	EditorUpdateMenus(editor);
-
-	return;
 }
 
 /*
@@ -984,20 +969,19 @@ void EditorDoClearValues(editor_struct *editor)
 {
 	GtkWidget *w;
 
-
 	if(editor == NULL)
 	    return;
 
 	if(!editor->initialized)
 	    return;
 
-	/* Check if already processing. */
+	/* Check if already processing */
 	if(editor->processing)
 	    return;
 
-	/* Clear file branch item data widgets. */
+	/* Clear file branch item data widgets */
 
-	/* Header entry widgets. */
+	/* Header entry widgets */
 	w = editor->header_name_entry;
 	if(w != NULL)
 	    gtk_entry_set_text(GTK_ENTRY(w), "");
@@ -1018,13 +1002,13 @@ void EditorDoClearValues(editor_struct *editor)
 	if(w != NULL)
 	    gtk_entry_set_text(GTK_ENTRY(w), "");
 
-	/* Header text. */
+	/* Header text */
 	w = editor->header_text;
 	if(w != NULL)
 	{
-	    int text_len;
+	    gint text_len;
 
-	    /* Remove all text. */
+	    /* Remove all text */
 	    text_len = gtk_text_get_length(GTK_TEXT(w));
 	    gtk_text_set_point(GTK_TEXT(w), 0);
 	    gtk_text_freeze(GTK_TEXT(w));
@@ -1033,26 +1017,24 @@ void EditorDoClearValues(editor_struct *editor)
 	}
 
 
-	/* Section name entry. */
+	/* Section name entry */
 	w = editor->section_name_entry;
 	if(w != NULL)
 	    gtk_entry_set_text(GTK_ENTRY(w), "");
 
-	/* Section text. */
+	/* Section text */
 	w = editor->section_text;
 	if(w != NULL)
 	{
-	    int text_len;
+	    gint text_len;
 
-	    /* Remove all text. */
+	    /* Remove all text */
 	    text_len = gtk_text_get_length(GTK_TEXT(w));
 	    gtk_text_set_point(GTK_TEXT(w), 0);
 	    gtk_text_freeze(GTK_TEXT(w));
 	    gtk_text_forward_delete(GTK_TEXT(w), text_len);
 	    gtk_text_thaw(GTK_TEXT(w));
 	}
-
-	return;
 }
 
 
@@ -1062,16 +1044,16 @@ void EditorDoClearValues(editor_struct *editor)
  */
 void EditorDoPreview(
 	editor_struct *editor, GtkCTreeNode *branch,  
-	int viewer_num
+	gint viewer_num
 )
 {
-	int i, status, editor_num;
+	gint i, status, editor_num;
 	viewer_struct *v;
 	medit_core_struct *core_ptr;
 	GtkCTreeNode *trunk;
 	editor_item_struct *item_ptr;
 	GtkCTree *ctree;
-	char *orig_file_name_full, *tmp_path, *prog_tmp_path;
+	gchar *orig_file_name_full, *tmp_path, *prog_tmp_path;
 
 
 	if(editor == NULL)
@@ -1080,7 +1062,7 @@ void EditorDoPreview(
 	if(!editor->initialized)
 	    return;
 
-	/* Check if processing. */
+	/* Check if processing */
 	if(editor->processing)   
 	    return;
 
@@ -1093,7 +1075,7 @@ void EditorDoPreview(
 	    return;
 
 
-	/* Find our editor pointer on core. */
+	/* Find our editor pointer on core */
 	for(i = 0; i < core_ptr->total_editors; i++)
 	{
 	    if(core_ptr->editor[i] == editor)
@@ -1104,7 +1086,7 @@ void EditorDoPreview(
 	else
 	    editor_num = -1;
 
-	/* Check if viewer_num is valid on the core structure. */
+	/* Check if viewer_num is valid on the core structure */
 	if((viewer_num < 0) || (viewer_num >= core_ptr->total_viewers))
 	    v = NULL;
 	else
@@ -1112,34 +1094,33 @@ void EditorDoPreview(
 
 	if(v == NULL)
 	{
-	    char text[256];
-
-	    sprintf(text,
+	    gchar *s = g_strdup_printf(
 "EditorDoPreview(): Viewer number %i is invalid.",
 		viewer_num
 	    );
 	    CDialogGetResponse(
 "Non-critical internal error!",
-text,
+		s,
 "The viewer number given to this function is\n\
 invalid. Cannot continue with preview.",
 		CDIALOG_ICON_ERROR,
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
+	    g_free(s);
 	    return;
 	}
 
 	/* Got viewer pointer, now check if the viewer is mapped and
-	 * initialized.
+	 * initialized
 	 */
 	if(!v->initialized || !v->map_state)
 	    return;
 
-	/* Set up viewer's values. */
+	/* Set up viewer's values */
 	v->editor_num = editor_num;
 
-	/* Get given branch's trunk. */
+	/* Get given branch's trunk */
 	trunk = EditorItemGetToplevel(editor, branch);
 	if(trunk == NULL)
 	{
@@ -1156,7 +1137,7 @@ Cannot continue with preview.",
 	    return;
 	}
 
-	/* Get trunk item pointer. */
+	/* Get trunk item pointer */
 	item_ptr = EditorBranchGetData(ctree, trunk);
 	if(item_ptr == NULL)
 	{
@@ -1195,22 +1176,25 @@ Cannot continue with preview.",
 	    return;
 	}
 
-	/* Create a tempory file to save trunk to it. */
-	tmp_path = tempnam(prog_tmp_path, "pv");
+	/* Create a tempory file to save trunk to it */
+	tmp_path = g_strdup(PrefixPaths(
+	    prog_tmp_path, "previewXXXXXX"
+	));
+	mkstemp(tmp_path);
 
 	/* Here we play a trick, first record the full path name
 	 * on the item data and replace it with our tempory file path
 	 * so that it gets saved to that. After saving we set back
-	 * the file path name on the item data to what it was.
+	 * the file path name on the item data to what it was
 	 */
 	orig_file_name_full = item_ptr->file_name_full;
 	item_ptr->file_name_full = tmp_path;
 	tmp_path = NULL;
 
-	/* Save branch with an updated filename to the tempory file. */
+	/* Save branch with an updated filename to the tempory file */
 	EditorFileSave(editor, branch);
 
-	/* Clear viewer and load new manual page file. */
+	/* Clear viewer and load new manual page file */
 	ViewerViewTextRecordScrollPositions(v);
 	ViewerTextDelete(v, 0, -1);
 	ViewerTextInsertPosition(v, 0);
@@ -1218,24 +1202,22 @@ Cannot continue with preview.",
 	    v, item_ptr->file_name_full, orig_file_name_full
 	);
 
-	/* Remove tempory saved manual page. */
+	/* Remove tempory saved manual page */
 	if(item_ptr->file_name_full != NULL)
 	    unlink(item_ptr->file_name_full);
 
 
-	/* Free tempory path (this was our tmp_path). */
-	free(item_ptr->file_name_full);
+	/* Free tempory path (this was our tmp_path) */
+	g_free(item_ptr->file_name_full);
 
-	/* Set back original full file name on item. */
+	/* Set back original full file name on item */
 	item_ptr->file_name_full = orig_file_name_full;
 	orig_file_name_full = NULL;
 
 
-	/* Free program tempory files directory path. */
-	free(prog_tmp_path);
+	/* Free program tempory files directory path */
+	g_free(prog_tmp_path);
 	prog_tmp_path = NULL;
-
-	return;
 }
 
 
@@ -1261,19 +1243,19 @@ Cannot continue with preview.",
  *	Pointer to search_wrapped will be set to TRUE if a match
  *	was made after a search wrapped through the entire buffer.
  */
-gbool EditorDoFind(  
+gboolean EditorDoFind(  
 	editor_struct *editor, GtkText *text,
-	char *haystack, char *needle,
-	int haystack_len, int start_pos,
-	gbool case_sensitive,
-	gbool move_to,
-	gbool *search_wrapped
+	gchar *haystack, gchar *needle,
+	gint haystack_len, gint start_pos,
+	gboolean case_sensitive,
+	gboolean move_to,
+	gboolean *search_wrapped
 )
 {
-	char *bp, *match_ptr;
+	gchar *bp, *match_ptr;
 
 
-	/* Reset search wrapped. */
+	/* Reset search wrapped */
 	if(search_wrapped != NULL)
 	    (*search_wrapped) = FALSE;
 
@@ -1297,7 +1279,7 @@ gbool EditorDoFind(
 
 	EditorSetStatusMessage(editor, "Finding...");
 
-	/* Sanitize starting position. */
+	/* Sanitize starting position */
 	if(start_pos >= haystack_len)
 	    start_pos = 0;
 	else if(start_pos < 0)
@@ -1307,17 +1289,17 @@ gbool EditorDoFind(
 	/* Case insensitive search? */
 	if(!case_sensitive)
 	{
-	    /* Need to modify buffers to upper case. */
+	    /* Need to modify buffers to upper case */
 
-	    /* Modify ending portion of haystack. */
-	    bp = (char *)(haystack + start_pos);
+	    /* Modify ending portion of haystack */
+	    bp = (gchar *)(haystack + start_pos);
 	    while((*bp) != '\0')
 	    {
 		(*bp) = toupper(*bp);
 		bp++;
 	    }
 
-	    /* Modify needle. */
+	    /* Modify needle */
 	    bp = needle;
 	    while((*bp) != '\0')
 	    {
@@ -1327,9 +1309,9 @@ gbool EditorDoFind(
 	}
 
 
-	/* Begin search from starting position. */
+	/* Begin search from starting position */
 	match_ptr = strstr(
-	    (char *)(haystack + start_pos),
+	    (gchar *)(haystack + start_pos),
 	    needle
 	);
 	if(match_ptr == NULL)
@@ -1339,9 +1321,9 @@ gbool EditorDoFind(
 	     */
 	    if(!case_sensitive)
 	    {
-		/* Toupper the beginning portion of the buffer. */
+		/* Toupper the beginning portion of the buffer */
 		bp = haystack;
-		while(bp < (char *)(haystack + start_pos))
+		while(bp < (gchar *)(haystack + start_pos))
 		{
 		    (*bp) = toupper(*bp);
 		    bp++;
@@ -1351,7 +1333,7 @@ gbool EditorDoFind(
 	     * beginning.
 	     */
 	    match_ptr = strstr(
-		(char *)(haystack + 0),
+		(gchar *)(haystack + 0),
 		needle
 	    );
 	    if(match_ptr != NULL)
@@ -1369,14 +1351,14 @@ gbool EditorDoFind(
 	/* Did we get a match? */
 	if(match_ptr == NULL)
 	{
-	    /* Sorry, no match made. */
+	    /* Sorry, no match made */
 	    return(FALSE);
 	}
 	else
 	{
-	    /* Got match. */
-	    int match_start_pos = (int)(match_ptr - haystack);
-	    int needle_len = strlen(needle);
+	    /* Got match */
+	    gint match_start_pos = (gint)(match_ptr - haystack);
+	    gint needle_len = strlen(needle);
 
 	    if(match_start_pos < 0)
 		match_start_pos = 0;
@@ -1384,7 +1366,7 @@ gbool EditorDoFind(
 	    /* Now modify the text widget, set new cursor position and
 	     * select the matched string.
 	     */
-	    if(1)
+	    if(TRUE)
 	    {
 		GtkEditable *editable = (GtkEditable *)text;
 
@@ -1429,15 +1411,15 @@ gbool EditorDoFind(
  *	Returns TRUE if a replace was done and FALSE if no replace
  *	was made or error.
  */
-gbool EditorDoReplace(
+gboolean EditorDoReplace(
 	editor_struct *editor, GtkText *text,
-	char *haystack, char *needle, const char *replacement,
-	int haystack_len, int start_pos,
-	gbool case_sensitive
+	gchar *haystack, gchar *needle, const gchar *replacement,
+	gint haystack_len, gint start_pos,
+	gboolean case_sensitive
 )
 {
 	GtkEditable *editable;
-	int delete_len, replacement_len;
+	gint delete_len, replacement_len;
 	medit_core_struct *core_ptr;
 	medit_styles_list_struct *styles_list;
 	GtkStyle *style_ptr;
@@ -1449,33 +1431,33 @@ gbool EditorDoReplace(
 	)
 	    return(FALSE);
 
-	/* Get core structure pointer. */
+	/* Get core structure pointer */
 	core_ptr = (medit_core_struct *)editor->core_ptr;
 	if(core_ptr == NULL)
 	    return(FALSE);
 
 
-	/* Get pointer to styles list structure on core structure. */
+	/* Get pointer to styles list structure on core structure */
 	styles_list = &core_ptr->styles_list;
 
 
 	editable = GTK_EDITABLE(text);
 
-	/* Get length of replacement string. */
+	/* Get length of replacement string */
 	replacement_len = strlen(replacement);
 
 
 	/* GtkText already has selection? */
 	if(editable->has_selection)
 	{
-	    /* Text already selected. */
+	    /* Text already selected */
 
 	    EditorSetStatusMessage(editor, "Replacing...");
 
-	    /* Set new starting position, overriding the given one. */
+	    /* Set new starting position, overriding the given one */
 	    start_pos = editable->selection_start_pos;
 
-	    /* Get length of text to delete, can be 0. */
+	    /* Get length of text to delete, can be 0 */
 	    delete_len = MAX(
 		editable->selection_end_pos - editable->selection_start_pos,
 		0
@@ -1483,14 +1465,14 @@ gbool EditorDoReplace(
 	}
 	else
 	{
-	    /* Text not selected, so we need to find first. */
-	    gbool search_wrapped;
-	    gbool got_match = EditorDoFind(
+	    /* Text not selected, so we need to find first */
+	    gboolean search_wrapped;
+	    gboolean got_match = EditorDoFind(
 		editor, text,
 		haystack, needle,
 		haystack_len, start_pos,
 		case_sensitive,
-		TRUE,			/* Scroll to matched position. */
+		TRUE,			/* Scroll to matched position */
 		&search_wrapped
 	    );
 
@@ -1499,12 +1481,12 @@ gbool EditorDoReplace(
 	    /* Didn't get match? */
 	    if(!got_match)
 	    {
-		/* No match, then that means we have nothing to replace. */
+		/* No match, then that means we have nothing to replace */
 		EditorSetStatusMessage(editor, "Replace done");
 		return(FALSE);
 	    }
 
-	    /* Now hopefully the text widget has its selection and marked. */
+	    /* Now hopefully the text widget has its selection and marked */
 	    if(!editable->has_selection)
 	    {
 		/* Something went wrong, supposedly got match but GtkText
@@ -1514,10 +1496,10 @@ gbool EditorDoReplace(
 		return(FALSE);
 	    }
 
-	    /* Set new starting position, overriding the given one. */
+	    /* Set new starting position, overriding the given one */
 	    start_pos = editable->selection_start_pos;
 
-	    /* Get length of text to delete, can be 0. */
+	    /* Get length of text to delete, can be 0 */
 	    delete_len = MAX(
 		editable->selection_end_pos - editable->selection_start_pos,
 		0
@@ -1559,11 +1541,11 @@ gbool EditorDoReplace(
 	    gint position;
 
 
-	    /* Select GdkFont from styles list (can be NULL). */
+	    /* Select GdkFont from styles list (can be NULL) */
 	    style_ptr = styles_list->edit_text_standard;
 	    font = ((style_ptr == NULL) ? NULL : style_ptr->font);
 
-	    /* Set insert point and insert replacement text. */
+	    /* Set insert point and insert replacement text */
 	    gtk_text_set_point(text, start_pos);
 	    gtk_text_freeze(text);
 	    gtk_text_insert(
@@ -1575,7 +1557,7 @@ gbool EditorDoReplace(
 	    );
 	    gtk_text_thaw(text);
 
-	    /* Call insert callback after inserting text. */
+	    /* Call insert callback after inserting text */
 	    position = start_pos;
 	    EditorTextInsertCB(
 		editable, (const gchar *)replacement,
@@ -1583,13 +1565,13 @@ gbool EditorDoReplace(
 		(gpointer)editor
 	    );
 
-	    /* Move cursor position after replacement. */
+	    /* Move cursor position after replacement */
 	    gtk_text_set_point(text, start_pos + replacement_len);
 	    gtk_editable_set_position(
 		editable, start_pos + replacement_len
 	    );
 
-	    /* Do not select replacement. */
+	    /* Do not select replacement */
 	}
 
 
@@ -1612,19 +1594,19 @@ gbool EditorDoReplace(
  *	Returns the number of replacements made or 0 on error or no
  *	matches.
  */
-int EditorDoReplaceAll(
+gint EditorDoReplaceAll(
 	editor_struct *editor, GtkText *text,
-	char *needle, const char *replacement,
-	gbool case_sensitive
+	gchar *needle, const gchar *replacement,
+	gboolean case_sensitive
 )
 {
 	GtkEditable *editable;
-	int delete_len, replacement_len;
+	gint delete_len, replacement_len;
 	medit_core_struct *core_ptr;
 	medit_styles_list_struct *styles_list;
 	GtkStyle *style_ptr;
-	int orig_pos;
-	int replace_count = 0;
+	gint orig_pos;
+	gint replace_count = 0;
 
 
 	/* Inputs valid? */
@@ -1633,47 +1615,47 @@ int EditorDoReplaceAll(
 	)
 	    return(replace_count);
 
-	/* Get core structure pointer. */
+	/* Get core structure pointer */
 	core_ptr = (medit_core_struct *)editor->core_ptr;
 	if(core_ptr == NULL)
 	    return(replace_count);
 
-	/* Get pointer to styles list structure on core structure. */
+	/* Get pointer to styles list structure on core structure */
 	styles_list = &core_ptr->styles_list;
 
 
 	editable = GTK_EDITABLE(text);
 
-	/* Get length of replacement string. */
+	/* Get length of replacement string */
 	replacement_len = strlen(replacement);
 
-	/* Record initial position. */
-	orig_pos = (int)gtk_editable_get_position(editable);
+	/* Record initial position */
+	orig_pos = (gint)gtk_editable_get_position(editable);
 
 
-	if(1)
+	if(TRUE)
 	{
 	    /* Seek back to beginning and do a through search, for each
 	     * matched find, replace it with replacement.
 	     */
-	    gbool search_wrapped;
-	    gbool got_match;
-	    int start_pos, next_pos = 0;
-	    char *haystack = NULL;
+	    gboolean search_wrapped;
+	    gboolean got_match;
+	    gint start_pos, next_pos = 0;
+	    gchar *haystack = NULL;
 
 	    do
 	    {
-		/* Get latest haystack from text widget. */
+		/* Get latest haystack from text widget */
 		g_free((gpointer)haystack);
 		haystack = gtk_editable_get_chars(editable, 0, -1);
 
-		/* Do find. */
+		/* Do find */
 		got_match = EditorDoFind(
 		    editor, text,
 		    haystack, needle,
 		    -1, next_pos,
 		    case_sensitive,
-		    FALSE,		/* No scroll to matched position. */
+		    FALSE,		/* No scroll to matched position */
 		    &search_wrapped
 		);
 		if(!got_match)
@@ -1698,7 +1680,7 @@ int EditorDoReplaceAll(
 		    break;
 		}
 
-		/* Get start of selection as start position. */
+		/* Get start of selection as start position */
 		start_pos = editable->selection_start_pos;
 
 		/* Set next starting position, being past the current
@@ -1707,7 +1689,7 @@ int EditorDoReplaceAll(
 		 */
 		next_pos = start_pos + replacement_len;
 
-		/* Get length of text to delete, can be 0. */
+		/* Get length of text to delete, can be 0 */
 		delete_len = MAX(
 		    editable->selection_end_pos -
 			editable->selection_start_pos,
@@ -1745,11 +1727,11 @@ int EditorDoReplaceAll(
 		    gint position;
 
 
-		    /* Select GdkFont from styles list (can be NULL). */
+		    /* Select GdkFont from styles list (can be NULL) */
 		    style_ptr = styles_list->edit_text_standard;
 		    font = ((style_ptr == NULL) ? NULL : style_ptr->font);
 
-		    /* Set insert point and insert replacement text. */
+		    /* Set insert point and insert replacement text */
 		    gtk_text_set_point(text, start_pos);
 		    gtk_text_freeze(text);
 		    gtk_text_insert(
@@ -1761,7 +1743,7 @@ int EditorDoReplaceAll(
 		    );
 		    gtk_text_thaw(text);
 
-		    /* Call insert callback after inserting text. */
+		    /* Call insert callback after inserting text */
 		    position = start_pos;
 		    EditorTextInsertCB(
 			editable, (const gchar *)replacement,
@@ -1769,28 +1751,28 @@ int EditorDoReplaceAll(
 			(gpointer)editor
 		    );
 
-		    /* Move cursor position after replacement. */
+		    /* Move cursor position after replacement */
 		    gtk_text_set_point(text, start_pos + replacement_len);
-/*
+#if 0
 		    gtk_editable_set_position(
 			editable, start_pos + replacement_len
 		    );
- */
-		    /* Do not select replacement. */
+#endif
+		    /* Do not select replacement */
 		}
 
 		replace_count++;
 
 	    } while(1);
 
-	    /* Deallocate haystack as needed. */
+	    /* Deallocate haystack as needed */
 	    g_free((gpointer)haystack);
 	    haystack = NULL;
 	}
 
-	/* Set back original position. */
-	if(orig_pos > (int)gtk_text_get_length(text))
-	    orig_pos = (int)gtk_text_get_length(text);
+	/* Set back original position */
+	if(orig_pos > (gint)gtk_text_get_length(text))
+	    orig_pos = (gint)gtk_text_get_length(text);
 	gtk_text_set_point(text, orig_pos);
 /*	gtk_editable_set_position(editable, orig_pos); */
 
