@@ -11,7 +11,7 @@
 
 extern void EditorSyntaxHighlight(
         editor_struct *editor, GtkWidget *w,
-        int cursor_pos, int start_pos, int end_pos
+        gint cursor_pos, gint start_pos, gint end_pos
 );
 
 extern void EditorDoFetchValues(
@@ -24,27 +24,27 @@ extern void EditorDoClearValues(editor_struct *editor);
 
 extern void EditorDoPreview(
         editor_struct *editor, GtkCTreeNode *branch,
-        int viewer_num
+        gint viewer_num
 );
 
-extern gbool EditorDoFind(
+extern gboolean EditorDoFind(
         editor_struct *editor, GtkText *text,
-        char *haystack, char *needle,
-        int haystack_len, int start_pos,
-        gbool case_sensitive,
-	gbool move_to,
-        gbool *search_wrapped
+        gchar *haystack, gchar *needle,
+        gint haystack_len, gint start_pos,
+        gboolean case_sensitive,
+	gboolean move_to,
+        gboolean *search_wrapped
 );
-extern gbool EditorDoReplace(
+extern gboolean EditorDoReplace(
         editor_struct *editor, GtkText *text,
-        char *haystack, char *needle, const char *replacement,
-        int haystack_len, int start_pos,
-        gbool case_sensitive
+        gchar *haystack, gchar *needle, const gchar *replacement,
+        gint haystack_len, gint start_pos,
+        gboolean case_sensitive
 );
-extern int EditorDoReplaceAll(
+extern gint EditorDoReplaceAll(
         editor_struct *editor, GtkText *text,
-        char *needle, const char *replacement,
-        gbool case_sensitive
+        gchar *needle, const gchar *replacement,
+        gboolean case_sensitive
 );
 
 #endif	/* EDITOROP_H */
