@@ -1,8 +1,5 @@
-#include <stdlib.h>
-#include <string.h>
 #include <signal.h>
 #include <locale.h>
-
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
@@ -42,7 +39,7 @@ static void MEditSignalCB(int s);
 
 static gboolean load_font_to_style(GtkStyle *style_ptr, const gchar *font_name);
 
-int MEditInit(medit_core_struct *core_ptr, int argc, char **argv);
+gint MEditInit(medit_core_struct *core_ptr, int argc, char **argv);
 gint MEditManage(gpointer data);
 void MEditShutdown(medit_core_struct *core_ptr);
 
@@ -83,9 +80,9 @@ void MEditSignalCB(int s)
 	    break;
 
 	  case SIGSEGV:
-	    signal(SIGSEGV, MEditSignalCB);	/* Watch for SIGSEGV again. */
-	    segfault_count++;			/* Increment SIGSEGV count. */
-	    /* Print warning of segmentation fault. */
+	    signal(SIGSEGV, MEditSignalCB);	/* Watch for SIGSEGV again */
+	    segfault_count++;			/* Increment SIGSEGV count */
+	    /* Print warning of segmentation fault */
 	    g_printerr(
 		"%s triggered a segmentation fault (%i times)\n",
 		PROG_NAME,
@@ -98,7 +95,7 @@ void MEditSignalCB(int s)
 	    }
 	    else
 	    {
-		/* Mark and perform emergency save procedure. */
+		/* Mark and perform emergency save procedure */
 		doing_crash_save = TRUE;
 		MEditDoEmergencySave(context_core_ptr);
 	    }
@@ -138,11 +135,11 @@ static gboolean load_font_to_style(GtkStyle *style_ptr, const gchar *font_name)
 	if(new_font == NULL)
 	    return(TRUE);
 
-	/* Unref current font on style structure. */
+	/* Unref current font on style structure */
 	if(style_ptr->font != NULL)
 	    gdk_font_unref(style_ptr->font);
 
-	/* Set newly loaded font to style. */
+	/* Set newly loaded font to style */
 	style_ptr->font = new_font;
 
 	return(FALSE);  
@@ -152,10 +149,10 @@ static gboolean load_font_to_style(GtkStyle *style_ptr, const gchar *font_name)
 /*
  *	Initializes all resources for the core structure.
  */
-int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
+gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 {
 	gint i, status;
-	const gchar *cstrptr, *arg;
+	const gchar *s, *arg;
 	gboolean startup_viewer = FALSE;
 	gint editor_num = -1;
 	gint viewer_num = -1;
@@ -175,17 +172,17 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	if(core_ptr == NULL)
 	    return(-1);
 
-	/* Set path to default rcfile, coppied value. */
-	cstrptr = getenv("HOME");
-	if(cstrptr == NULL)
-	    cstrptr = "/";
-	cstrptr = PrefixPaths(cstrptr, MEDIT_RCFILE_LOCAL);
-	if(cstrptr == NULL)
-	    cstrptr = MEDIT_RCFILE_LOCAL;
-	rcfile = STRDUP(cstrptr);
+	/* Set path to default rcfile, coppied value */
+	s = g_getenv("HOME");
+	if(s == NULL)
+	    s = "/";
+	s = PrefixPaths(s, MEDIT_RCFILE_LOCAL);
+	if(s == NULL)
+	    s = MEDIT_RCFILE_LOCAL;
+	rcfile = STRDUP(s);
 
 
-	/* Reset values on core. */
+	/* Reset values on core */
 	core_ptr->untitled_count = 0;
 
 	core_ptr->alt_key_state = FALSE;
@@ -193,7 +190,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	core_ptr->shift_key_state = FALSE;
 
 
-	/* Parse arguments. */
+	/* Parse arguments */
 	for(i = 1; i < argc; i++)
 	{
 	    arg = argv[i];
@@ -223,7 +220,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 		arg = (i < argc) ? argv[i] : NULL;
 		if(arg != NULL)
 		{
-		    free(rcfile);
+		    g_free(rcfile);
 		    rcfile = STRDUP(arg);
 		}
 		else
@@ -244,11 +241,11 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	}
 
 
-	/* Get default gtk style. */
+	/* Get default gtk style */
 	style_standard = gtk_widget_get_default_style();
 
 
-	/* Load cursors. */
+	/* Load cursors */
 	cursors_list = &core_ptr->cursors_list;
 	if(TRUE)
 	{
@@ -257,7 +254,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	}
 
 
-	/* Load styles. */
+	/* Load styles */
 	styles_list = &core_ptr->styles_list;
 	colormap = gdk_colormap_get_system();
 	if((window != NULL) && (style_standard != NULL) &&
@@ -271,7 +268,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	     * allocated GdkColors.
 	     */
 
-	    /* Heading 1. */
+	    /* Heading 1 */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -279,7 +276,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->heading1_text = style_ptr;
 
-	    /* Heading 2. */
+	    /* Heading 2 */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -288,7 +285,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->heading2_text = style_ptr;
 
-	    /* Heading 3. */
+	    /* Heading 3 */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -296,7 +293,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->heading3_text = style_ptr;
 
-	    /* Heading 4. */
+	    /* Heading 4 */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -305,7 +302,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->heading4_text = style_ptr;
 
-	    /* Heading 5. */
+	    /* Heading 5 */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -313,7 +310,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->heading5_text = style_ptr;
 
-	    /* Heading 6. */
+	    /* Heading 6 */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -322,7 +319,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    styles_list->heading6_text = style_ptr;
 
 
-	    /* Heading 1 reverse. */
+	    /* Heading 1 reverse */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -338,7 +335,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->heading1_rev_text = style_ptr;
 
-	    /* Heading 2 reverse. */
+	    /* Heading 2 reverse */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {       
@@ -355,7 +352,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->heading2_rev_text = style_ptr;
 
-	    /* Heading 3 reverse. */
+	    /* Heading 3 reverse */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -371,7 +368,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->heading3_rev_text = style_ptr;
 
-	    /* Heading 4 reverse. */
+	    /* Heading 4 reverse */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -388,7 +385,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    styles_list->heading4_rev_text = style_ptr;
 
 
-	    /* Editing text standard. */
+	    /* Editing text standard */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -399,7 +396,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->edit_text_standard = style_ptr;
 
-	    /* Editing text background. */
+	    /* Editing text background */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -410,7 +407,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->edit_text_background = style_ptr;
 
-	    /* Editing text tag deliminator. */
+	    /* Editing text tag deliminator */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -421,7 +418,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->edit_text_tag_deliminator = style_ptr;
 
-	    /* Editing text XML tag text. */
+	    /* Editing text XML tag text */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -432,7 +429,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->edit_text_tag_text = style_ptr;
 
-	    /* Editing text XML symbol representations text. */
+	    /* Editing text XML symbol representations text */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -444,7 +441,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    styles_list->edit_text_tag_symrep = style_ptr;
 
 
-	    /* Manpage output text standard. */
+	    /* Manpage output text standard */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -455,7 +452,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->manpage_text_standard = style_ptr;
 
-	    /* Manpage output text background. */
+	    /* Manpage output text background */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -466,7 +463,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	    }
 	    styles_list->manpage_text_background = style_ptr;
 
-	    /* Manpage output text bold. */
+	    /* Manpage output text bold */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
 	    {
@@ -492,7 +489,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	}
 
 
-	/* Load pixmaps list. */
+	/* Load pixmaps list */
 	pixmaps_list = &core_ptr->pixmaps_list;
 	if((window != NULL) && (style_standard != NULL))
 	{
@@ -544,7 +541,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	}
 
 
-	/* Load file extension types list. */
+	/* Load file extension types list */
 	fetype_list = &core_ptr->fetype_list;
 	if(TRUE)
 	{
@@ -572,10 +569,10 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	}
 
 
-	/* Create Preferences & Options window. */
+	/* Create Preferences & Options window */
 	core_ptr->pref = PrefNew(core_ptr);
 
-	/* Load preferences from file. */
+	/* Load preferences from file */
 	if(rcfile != NULL)
 	{
 	    status = PrefLoadFromFile(core_ptr->pref, rcfile);
@@ -619,7 +616,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 
 	    editor_num = core_ptr->total_editors;
 	    core_ptr->total_editors++;
-	    core_ptr->editor = (editor_struct **)realloc(
+	    core_ptr->editor = (editor_struct **)g_realloc(
 		core_ptr->editor,
 		core_ptr->total_editors * sizeof(editor_struct *)
 	    );
@@ -659,7 +656,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	      
 	    viewer_num = core_ptr->total_viewers;
 	    core_ptr->total_viewers++;
-	    core_ptr->viewer = (viewer_struct **)realloc(  
+	    core_ptr->viewer = (viewer_struct **)g_realloc(  
 		core_ptr->viewer,
 		core_ptr->total_viewers * sizeof(viewer_struct *)
 	    );
@@ -694,8 +691,8 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 	MEditDoCrashRecovery(core_ptr);
 
 
-	/* Deallocate coppied rcfile path. */
-	free(rcfile);
+	/* Delete coppied rcfile path */
+	g_free(rcfile);
 	rcfile = NULL;
 
 	return(0);
@@ -707,8 +704,7 @@ int MEditInit(medit_core_struct *core_ptr, int argc, char **argv)
 gint MEditManage(gpointer data)
 {
 	static gboolean reenterant = FALSE;
-	gboolean need_break;
-	gboolean still_processing;
+	gboolean need_break, still_processing;
 	gint i, status;
 	editor_struct *editor;
 	viewer_struct *viewer;
@@ -730,7 +726,7 @@ gint MEditManage(gpointer data)
 	{
 	    /* Check if any dialogs are in query, break query as needed
 	     * and return. Let next call to this function handle rest of
-	     * closing all windows.
+	     * closing all windows
 	     */
 	    if(CDialogIsQuery())
 	    {
@@ -762,7 +758,7 @@ gint MEditManage(gpointer data)
 		reenterant = FALSE;  
 		return(TRUE);
 	    }
-	    /* All dialogs not in query. */
+	    /* All dialogs not in query */
 
 
 	    /* Reset need_close_all_windows back to FALSE and then check
@@ -770,10 +766,10 @@ gint MEditManage(gpointer data)
 	     */
 	    need_close_all_windows = FALSE;
 
-	    /* Check if any windows are processing. */
+	    /* Check if any windows are processing */
 	    still_processing = FALSE;
 
-	    /* Check each editor to see if any are still processing. */
+	    /* Check each editor to see if any are still processing */
 	    for(i = 0; i < core_ptr->total_editors; i++)
 	    {
 		editor = core_ptr->editor[i];
@@ -786,7 +782,7 @@ gint MEditManage(gpointer data)
 		    break;
 		}
 	    }
-	    /* Check each viewer to see if any are still processing. */
+	    /* Check each viewer to see if any are still processing */
 	    for(i = 0; i < core_ptr->total_viewers; i++)
 	    {
 		viewer = core_ptr->viewer[i];
@@ -810,7 +806,7 @@ gint MEditManage(gpointer data)
 	    }
 
 
-	    /* Go through each editor and check for changes. */
+	    /* Go through each editor and check for changes */
 	    for(i = 0; i < core_ptr->total_editors; i++)
 	    {
 		editor = core_ptr->editor[i];
@@ -845,7 +841,7 @@ gint MEditManage(gpointer data)
 	    }
 	    if(i < core_ptr->total_editors)
 	    {
-		/* Found some changed data that was not saved. */
+		/* Found some changed data that was not saved */
 		status = CDialogGetResponse(
 "Changes detected!",
 "There are changes to one or more of the editors\n\
@@ -898,7 +894,7 @@ you can say yes to exit and discard those changes.",
 		    EditorRecordPositions(editor);
 		    EditorReset(editor, editor->map_state);
 		}
-		/* Viewer windows. */
+		/* Viewer windows */
 		for(i = 0; i < core_ptr->total_viewers; i++)
 		{
 		    viewer = core_ptr->viewer[i];
@@ -937,13 +933,13 @@ you can say yes to exit and discard those changes.",
 	/* Atleast one editor was initialized and mapped? */
 	if(i < core_ptr->total_editors)
 	{
-	    /* Atleast one editor is still in use, keep running... */
+	    /* Atleast one editor is still in use, keep running */
 	}
 	else
 	{
-	    /* All editors were uninitialized and/or unmapped. */
+	    /* All editors were uninitialized and/or unmapped */
 
-	    /* Check if any viewers are initialized and mapped. */
+	    /* Check if any viewers are initialized and mapped */
 	    for(i = 0; i < core_ptr->total_viewers; i++)
 	    {
 		viewer = core_ptr->viewer[i];
@@ -957,27 +953,27 @@ you can say yes to exit and discard those changes.",
 	    /* Atleast one viewer was initialized and mapped? */
 	    if(i < core_ptr->total_viewers)
 	    {
-		/* Atleast one viewer is still in use, keep running... */
+		/* Atleast one viewer is still in use, keep running */
 	    }
 	    else
 	    {
-		/* All viewers were uninitialized and/or unmapped. */
+		/* All viewers were uninitialized and/or unmapped */
 
-		/* Break out of main GUI loop. */
+		/* Break out of main GUI loop */
 		gtk_main_quit();
 
-		/* Remove callback to this function. */
+		/* Remove callback to this function */
 		if(manage_timeout_cb_id != (guint)(-1))
 		{
 		    gtk_timeout_remove(manage_timeout_cb_id);
 		    manage_timeout_cb_id = (guint)(-1);
 		}
 
-		/* Flush events. */
+		/* Flush events */
 		while(gtk_events_pending() > 0)
 		    gtk_main_iteration();
 
-		/* Return false so this timeout is not called again. */
+		/* Return false so this timeout is not called again */
 		reenterant = FALSE;
 		return(FALSE);
 	    }
@@ -988,43 +984,42 @@ you can say yes to exit and discard those changes.",
 }
 
 /*
- *	Deallocates all resources on the core structure but does not
- *	deallocate the structure itself.
+ *	Deletes all resources on the core structure but does not
+ *	delete the structure itself.
  */
 void MEditShutdown(medit_core_struct *core_ptr)
 {
-	int i;
-	char *rcfile;
+	gint i;
+	gchar *rcfile;
 	medit_cursors_list_struct *cursors_list;
 	medit_pixmaps_list_struct *pixmaps_list;
 	medit_styles_list_struct *styles_list;
 	medit_fetype_list_struct *fetype_list;
 
-
 	if(core_ptr == NULL)
 	    return;
 
-	/* Delete all editors. */
+	/* Delete all editors */
 	for(i = 0; i < core_ptr->total_editors; i++)
 	{
 	    EditorDelete(core_ptr->editor[i]);
 	    core_ptr->editor[i] = NULL;
 	}
-	free(core_ptr->editor);
+	g_free(core_ptr->editor);
 	core_ptr->editor = NULL;
 	core_ptr->total_editors = 0;
 
-	/* Delete all viewers. */
+	/* Delete all viewers */
 	for(i = 0; i < core_ptr->total_viewers; i++)
 	{
 	    ViewerDelete(core_ptr->viewer[i]);
 	    core_ptr->viewer[i] = NULL;
 	}
-	free(core_ptr->viewer);
+	g_free(core_ptr->viewer);
 	core_ptr->viewer = NULL;
 	core_ptr->total_viewers = 0;
 
-	/* Get path to rcfile and save preferences. */
+	/* Get path to rcfile and save preferences */
 	rcfile = (char *)PrefParmGetValueP(
 	    core_ptr->pref, MEDIT_PREF_PARM_LOCATIONS_RCFILE
 	);
@@ -1032,33 +1027,30 @@ void MEditShutdown(medit_core_struct *core_ptr)
 	    rcfile = STRDUP(rcfile);
 	if(rcfile != NULL)
 	    PrefSaveToFile(core_ptr->pref, rcfile);
-	free(rcfile);
+	g_free(rcfile);
 	rcfile = NULL;
 
-	/* Delete Preferences & Options window. */
+	/* Delete Preferences & Options window */
 	PrefDelete(core_ptr->pref);
 	core_ptr->pref = NULL;
 
-	/* Delete about dialog. */
+	/* Delete about dialog */
 	AboutDialogDelete(core_ptr->about);
 	core_ptr->about = NULL;
 
 
 
-	/* Unref all cursors. */
+	/* Unref all cursors */
 	cursors_list = &core_ptr->cursors_list;
-	if(1)
+	if(TRUE)
 	{
 	    GdkCursor **cursor;
 
-#define UNREF_CURSOR	\
-{ \
- if((*cursor) != NULL) \
- { \
-  gdk_cursor_destroy(*cursor); \
-  (*cursor) = NULL; \
- } \
-}
+#define UNREF_CURSOR	{	\
+ if((*cursor) != NULL) {	\
+  gdk_cursor_destroy(*cursor);	\
+  (*cursor) = NULL;		\
+} }
 	    cursor = &cursors_list->busy;
 	    UNREF_CURSOR
 
@@ -1069,25 +1061,22 @@ void MEditShutdown(medit_core_struct *core_ptr)
 	}
 
 
-	/* Unref all pixmaps. */
+	/* Unref all pixmaps */
 	pixmaps_list = &core_ptr->pixmaps_list;
-	if(1)
+	if(TRUE)
 	{
 	    GdkPixmap **pixmap;
 	    GdkBitmap **mask;
 
-#define UNREF_PIXMAP	\
-{ \
- if((*pixmap) != NULL) \
- { \
-  gdk_pixmap_unref(*pixmap); \
-  (*pixmap) = NULL; \
- } \
- if((*mask) != NULL) \
- { \
-  gdk_bitmap_unref(*mask); \
-  (*mask) = NULL; \
- } \
+#define UNREF_PIXMAP	{	\
+ if(*pixmap != NULL) {		\
+  gdk_pixmap_unref(*pixmap);	\
+  *pixmap = NULL;		\
+ }				\
+ if((*mask) != NULL) {		\
+  gdk_bitmap_unref(*mask);	\
+  *mask = NULL;			\
+ }				\
 }
 	    pixmap = &pixmaps_list->medit_icon_48x48;
 	    mask = &pixmaps_list->medit_icon_48x48_mask;
@@ -1124,82 +1113,55 @@ void MEditShutdown(medit_core_struct *core_ptr)
 	}
 
 
-	/* Unref all styles. */
+	/* Unref all styles */
 	styles_list = &core_ptr->styles_list;
-	if(1)
+	if(TRUE)
 	{
-	    GtkStyle **style_ptr;
-#define UNREF_STYLE     \
-{ \
- if((*style_ptr) != NULL) \
- { \
-  gtk_style_unref(*style_ptr); \
-  (*style_ptr) = NULL; \
- } \
-}
+#define UNREF_STYLE(p)	{	\
+if(*(p) != NULL) {		\
+ gtk_style_unref(*(p));		\
+ *(p) = NULL;			\
+} }
 	    styles_list->standard = NULL;	/* Came from GTK internal, do
-						 * not unref it.
-						 */
+						 * not unref it */
 
-	    style_ptr = &styles_list->heading1_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->heading2_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->heading3_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->heading4_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->heading5_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->heading6_text;
-	    UNREF_STYLE
+	    UNREF_STYLE(&styles_list->heading1_text);
+	    UNREF_STYLE(&styles_list->heading2_text);
+	    UNREF_STYLE(&styles_list->heading3_text);
+	    UNREF_STYLE(&styles_list->heading4_text);
+	    UNREF_STYLE(&styles_list->heading5_text);
+	    UNREF_STYLE(&styles_list->heading6_text);
 
-	    style_ptr = &styles_list->heading1_rev_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->heading2_rev_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->heading3_rev_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->heading4_rev_text;
-	    UNREF_STYLE
-
-	    style_ptr = &styles_list->edit_text_standard;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->edit_text_background;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->edit_text_tag_deliminator;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->edit_text_tag_text;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->edit_text_tag_symrep;
-	    UNREF_STYLE
-
-	    style_ptr = &styles_list->manpage_text_standard;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->manpage_text_background;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->manpage_text_bold;
-	    UNREF_STYLE
-	    style_ptr = &styles_list->manpage_text_underline;
-	    UNREF_STYLE
+	    UNREF_STYLE(&styles_list->heading1_rev_text);
+	    UNREF_STYLE(&styles_list->heading2_rev_text);
+	    UNREF_STYLE(&styles_list->heading3_rev_text);
+	    UNREF_STYLE(&styles_list->heading4_rev_text);
 
+	    UNREF_STYLE(&styles_list->edit_text_standard);
+	    UNREF_STYLE(&styles_list->edit_text_background);
+	    UNREF_STYLE(&styles_list->edit_text_tag_deliminator);
+	    UNREF_STYLE(&styles_list->edit_text_tag_text);
+	    UNREF_STYLE(&styles_list->edit_text_tag_symrep);
 
+	    UNREF_STYLE(&styles_list->manpage_text_standard);
+	    UNREF_STYLE(&styles_list->manpage_text_background);
+	    UNREF_STYLE(&styles_list->manpage_text_bold);
+	    UNREF_STYLE(&styles_list->manpage_text_underline);
 #undef UNREF_STYLE
 	}
 
 
-	/* Delete all file extension types list. */
+	/* Delete all file extension types list */
 	fetype_list = &core_ptr->fetype_list;
 	if(fetype_list != NULL)
 	{
 	    fb_type_struct ***fb_type;
 	    int *total_fb_types;
 
-#define DELETE_FETYPE_LIST	\
-{ \
- FileBrowserDeleteTypeList(*fb_type, *total_fb_types); \
- (*fb_type) = NULL; \
- (*total_fb_types) = 0; \
+#define DELETE_FETYPE_LIST	{			\
+ FileBrowserDeleteTypeList(*fb_type, *total_fb_types);	\
+ *fb_type = NULL;					\
+ *total_fb_types = 0;					\
 }
 
 	    fb_type = &fetype_list->manual_page;
@@ -1208,42 +1170,33 @@ void MEditShutdown(medit_core_struct *core_ptr)
 #undef DELETE_FETYPE_LIST
 	}
 
-
 	memset(core_ptr, 0x00, sizeof(medit_core_struct));
-
-	return;
 }
 
 
 int main(int argc, char **argv)
 {
-	int i, status;
-	char *strptr;
-	medit_core_struct *core_ptr = (medit_core_struct *)calloc(
-	    1,
+	gint i, status;
+	const gchar *arg;
+	medit_core_struct *core_ptr = MEDIT_CORE(g_malloc0(
 	    sizeof(medit_core_struct)
-	);
+	));
 	if(core_ptr == NULL)
 	    return(1);
 
 
-	/* Reset local global `segfault counter'. */
+	/* Reset globals */
 	segfault_count = 0;
-
-	/* Reset manage function callback id code. */
 	manage_timeout_cb_id = (guint)(-1);
-
-
-	/* Reset global `need to close all windows'. */
 	need_close_all_windows = FALSE;
 
-	/* Reset in context core pointer. */
+	/* Set global core pointer */
 	context_core_ptr = core_ptr;
 
 use_text_delete = TRUE;
 
 
-	/* Set up signals. */
+	/* Set up signals */
 	signal(SIGINT, MEditSignalCB);
 	signal(SIGTERM, MEditSignalCB);
 	signal(SIGSEGV, MEditSignalCB);
@@ -1251,31 +1204,31 @@ use_text_delete = TRUE;
 	signal(SIGPIPE, MEditSignalCB);
 
 
-	/* Parse basic arguments. */
+	/* Parse basic arguments */
 	for(i = 1; i < argc; i++)
 	{
-	    strptr = argv[i];
-	    if(strptr == NULL)
+	    arg = argv[i];
+	    if(arg == NULL)
 		continue;
 
-	    /* Help. */
-	    if(strcasepfx(strptr, "-h") ||
-	       strcasepfx(strptr, "--h") ||
-	       strcasepfx(strptr, "-?") ||
-	       strcasepfx(strptr, "/?")
+	    /* Help */
+	    if(g_strcasepfx(arg, "-h") ||
+	       g_strcasepfx(arg, "--h") ||
+	       g_strcasepfx(arg, "-?") ||
+	       g_strcasepfx(arg, "/?")
 	    )
 	    {
 		g_print(PROG_USAGE_MESG);
 		return(0);
 	    }
-	    /* Version. */
-	    else if(strcasepfx(strptr, "-ver") ||
-		    strcasepfx(strptr, "--ver")
+	    /* Version */
+	    else if(g_strcasepfx(arg, "-ver") ||
+		    g_strcasepfx(arg, "--ver")
 	    )
 	    {
 		g_print(
 		    "%s Version %s\n%s\n",
-		    PROG_NAME, PROG_VERSION,
+		    PROG_NAME_FULL, PROG_VERSION,
 		    PROG_COPYRIGHT
 		);
 		return(0);
@@ -1283,7 +1236,7 @@ use_text_delete = TRUE;
 	    else
 	    {
 		/* Leave other arguments alone, they will be handled
-		 * later.
+		 * later
 		 */
 	    }
 	}
@@ -1294,10 +1247,10 @@ use_text_delete = TRUE;
 
 	gtk_set_locale();
 
-	/* Initialize GTK. */
+	/* Initialize GTK */
 	gtk_init(&argc, &argv);
 
-	/* Initialize dialogs resources. */
+	/* Initialize dialogs resources */
 	CDialogInit();
 	FPromptInit();
 	ClipboardBrowserInit();
@@ -1306,7 +1259,7 @@ use_text_delete = TRUE;
 	FSDInit();
 	PDialogInit();
 
-	/* Initialize Manual Page Editor's resources. */
+	/* Initialize Manual Page Editor's resources */
 	status = MEditInit(core_ptr, argc, argv);
 	if(status)
 	{
@@ -1314,24 +1267,23 @@ use_text_delete = TRUE;
 	    return(1);
 	}
 
-	/* Set timeout to management function. */
+	/* Set timeout to management function */
 	manage_timeout_cb_id = gtk_timeout_add(
-	    250,
-	    (GtkFunction)MEditManage,
-	    (gpointer)core_ptr
+	    250l,
+	    MEditManage, core_ptr
 	);
 
-	/* Enter main GTK loop. */
+	/* Enter main GTK loop */
 	gtk_main();
 
 
-	/* Shutdown Manual Page Editor's resources. */
+	/* Shutdown Manual Page Editor's resources */
 	MEditShutdown(core_ptr);
-	context_core_ptr = NULL;	/* Reset global context core ptr. */
-	free(core_ptr);			/* Now deallocate core structure. */
+	context_core_ptr = NULL;
+	g_free(core_ptr);
 	core_ptr = NULL;
 
-	/* Shutdown dialogs' resources. */
+	/* Shutdown dialogs */
 	CDialogShutdown();
 	FPromptShutdown();
 	ClipboardBrowserShutdown();
