@@ -1,12 +1,8 @@
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdlib.h>
-#include <unistd.h>
-
 #include <sys/stat.h>
-#include <sys/types.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "../include/disk.h"
 #include "../include/fio.h"
@@ -28,23 +24,23 @@
 
 
 GtkWidget *MEditCreateHelpMenu(
-        medit_core_struct *core_ptr, void *accel_group
+	medit_core_struct *core_ptr, void *accel_group
 );
-char *MEditCreateTempDir(medit_core_struct *core_ptr);
-int MEditExecuteFmtBlock(
-        medit_core_struct *core_ptr,
-        const char *cmd,
-        const char *filename,
-        const char *options,
-        const char *stdout_path,
-        const char *stderr_path
+gchar *MEditCreateTempDir(medit_core_struct *core_ptr);
+gint MEditExecuteFmtBlock(
+	medit_core_struct *core_ptr,
+	const gchar *cmd,
+	const gchar *filename,
+	const gchar *options,
+	const gchar *stdout_path,
+	const gchar *stderr_path
 );
-int MEditDialogFromFile(
-        medit_core_struct *core_ptr,
-        const char *path
+gint MEditDialogFromFile(
+	medit_core_struct *core_ptr,
+	const gchar *path
 );
-int MEditDoEmergencySave(medit_core_struct *core_ptr);
-int MEditDoCrashRecovery(medit_core_struct *core_ptr);
+gint MEditDoEmergencySave(medit_core_struct *core_ptr);
+gint MEditDoCrashRecovery(medit_core_struct *core_ptr);
 
 
 #define MAX(a,b)	(((a) > (b)) ? (a) : (b))
@@ -61,17 +57,15 @@ int MEditDoCrashRecovery(medit_core_struct *core_ptr);
  *	to add this menu to the menu bar.
  */
 GtkWidget *MEditCreateHelpMenu(
-	medit_core_struct *core_ptr, void *accel_group
+	medit_core_struct *core_ptr, gpointer accel_group
 )
 {
-	GtkWidget *w, *fw, *menu;
-	gint accel_key;
-        guint accel_mods;
-        gpointer client_data = (void *)core_ptr;
-        u_int8_t **icon;
-        const gchar *label = NULL;
-        void (*func_cb)(GtkWidget *w, void *);
-
+	guint accel_key, accel_mods;
+	gpointer client_data = core_ptr;
+	guint8 **icon;
+	const gchar *label = NULL;
+	GtkWidget *w, *menu;
+	void (*func_cb)(GtkWidget *w, gpointer);
 
 	if(core_ptr == NULL)
 	    return(NULL);
@@ -80,7 +74,7 @@ GtkWidget *MEditCreateHelpMenu(
 { \
  w = GUIMenuItemCreate( \
   menu, GUI_MENU_ITEM_TYPE_LABEL, accel_group, \
-  icon, label, accel_key, accel_mods, (void **)&fw, \
+  icon, label, accel_key, accel_mods, NULL, \
   client_data, func_cb \
  ); \
 }
@@ -89,7 +83,7 @@ GtkWidget *MEditCreateHelpMenu(
 { \
  w = GUIMenuItemCreate( \
   menu, GUI_MENU_ITEM_TYPE_SUBMENU, accel_group, \
-  icon, label, accel_key, accel_mods, (void **)&fw, \
+  icon, label, accel_key, accel_mods, NULL, \
   client_data, func_cb \
  ); \
  if(w != NULL) \
@@ -100,7 +94,7 @@ GtkWidget *MEditCreateHelpMenu(
 { \
  w = GUIMenuItemCreate( \
   menu, GUI_MENU_ITEM_TYPE_CHECK, accel_group, \
-  icon, label, accel_key, accel_mods, (void **)&fw, \
+  icon, label, accel_key, accel_mods, NULL, \
   client_data, func_cb \
  ); \
 }
@@ -114,41 +108,41 @@ GtkWidget *MEditCreateHelpMenu(
  ); \
 }
 
-	/* Create help menu. */
-        menu = GUIMenuCreate();
-        if(menu != NULL)
-        {
-            icon = NULL;
-            label = "Manual Page...";
-            accel_key = 0;
-            accel_mods = 0;
-            func_cb = MEditHelpManualCB;
-            DO_ADD_MENU_ITEM_LABEL
-
-            DO_ADD_MENU_SEP
-
-            icon = NULL;
-            label = "How To Write ManPages...";
-            accel_key = 0; 
-            accel_mods = 0;
-            func_cb = MEditHelpManPageProceduresCB;
-            DO_ADD_MENU_ITEM_LABEL
-
-            icon = NULL;
-            label = "ManPage XML Format Referance...";
-            accel_key = 0;
-            accel_mods = 0;
-            func_cb = MEditHelpManPageXMLRefCB;
-            DO_ADD_MENU_ITEM_LABEL
+	/* Create help menu */
+	menu = GUIMenuCreate();
+	if(menu != NULL)
+	{
+	    icon = NULL;
+	    label = "Manual Page...";
+	    accel_key = 0;
+	    accel_mods = 0;
+	    func_cb = MEditHelpManualCB;
+	    DO_ADD_MENU_ITEM_LABEL
 
 	    DO_ADD_MENU_SEP
 
-            icon = (u_int8_t **)icon_about_20x20_xpm;
-            label = "About...";
-            accel_key = 0;
-            accel_mods = 0;
-            func_cb = MEditAboutDialogMapCB;
-            DO_ADD_MENU_ITEM_LABEL
+	    icon = NULL;
+	    label = "How To Write ManPages...";
+	    accel_key = 0; 
+	    accel_mods = 0;
+	    func_cb = MEditHelpManPageProceduresCB;
+	    DO_ADD_MENU_ITEM_LABEL
+
+	    icon = NULL;
+	    label = "ManPage XML Format Reference...";
+	    accel_key = 0;
+	    accel_mods = 0;
+	    func_cb = MEditHelpManPageXMLRefCB;
+	    DO_ADD_MENU_ITEM_LABEL
+
+	    DO_ADD_MENU_SEP
+
+	    icon = (guint8 **)icon_about_20x20_xpm;
+	    label = "About...";
+	    accel_key = 0;
+	    accel_mods = 0;
+	    func_cb = MEditAboutDialogMapCB;
+	    DO_ADD_MENU_ITEM_LABEL
 	}
 
 #undef DO_ADD_MENU_ITEM_LABEL
@@ -168,63 +162,61 @@ GtkWidget *MEditCreateHelpMenu(
  *	but everything else will run the same way, returning the pointer
  *	to an allocated string containing the tempory directory.
  *
- *	The returned pointer needs to be free()'ed by the calling
+ *	The returned pointer needs to be deleted by the calling
  *	function.
  */
-char *MEditCreateTempDir(medit_core_struct *core_ptr)
+gchar *MEditCreateTempDir(medit_core_struct *core_ptr)
 {
-	int len;
-	const char *cstrptr;
-	char *tmp_dir_rtn;
+	const gchar *s;
+	gchar *tmp_dir_rtn;
 	pref_struct *pref;
 
 
-	/* Get pointer to pref window, may be NULL. */
+	/* Get pointer to pref window, may be NULL */
 	pref = core_ptr->pref;
 
-	/* Allocate and reset tempory directory return to empty. */
-	tmp_dir_rtn = strdup("");
+	/* Allocate and reset tempory directory return to empty */
+	tmp_dir_rtn = g_strdup("");
 
-	/* Get tempory directory prefix. */
-	cstrptr = (const char *)PrefParmGetValueP(
+	/* Get tempory directory prefix */
+	s = PrefParmGetValueP(
 	    pref, MEDIT_PREF_PARM_LOCATIONS_TMP_DIR
 	);
-	if(cstrptr == NULL)
-	    cstrptr = getenv("TMPDIR");
-	if(cstrptr == NULL)
+	if(s == NULL)
+	    s = g_getenv("TMPDIR");
+	if(s == NULL)
 #ifdef P_tmpdir
-	    cstrptr = P_tmpdir;
+	    s = P_tmpdir;
 #else
-	    cstrptr = "/tmp";
+	    s = "/tmp";
 #endif
 
-	/* Cat tempory dir prefix. */
-	tmp_dir_rtn = strcatalloc(tmp_dir_rtn, cstrptr);
+	/* Cat tempory dir prefix */
+	tmp_dir_rtn = strcatalloc(tmp_dir_rtn, s);
 
-	/* Put deliminator on end as needed. */
+	/* Append deliminator to tmp_dir_rtn as needed */
 	if(tmp_dir_rtn != NULL)
 	{
-	    len = strlen(tmp_dir_rtn);
-	    if(len > 0)
-	    {
-		if(tmp_dir_rtn[len - 1] != DIR_DELIMINATOR)
-		    tmp_dir_rtn = strcatalloc(tmp_dir_rtn, "/");
-	    }
+	    const gint len = strlen(tmp_dir_rtn);
+	    if((len > 0) ?
+		(tmp_dir_rtn[len - 1] != G_DIR_SEPARATOR) : FALSE
+	    )
+		tmp_dir_rtn = strcatalloc(tmp_dir_rtn, "/");
 	}
 
-	/* Cat program's name. */
+	/* Cat program's name */
 	tmp_dir_rtn = strcatalloc(tmp_dir_rtn, "manedit-");
 
-	/* Get user's name. */
-	cstrptr = getenv("USERNAME");
-	if(cstrptr == NULL)
-	    cstrptr = getenv("USER");
-	/* All else assume anonymous. */
-	if(cstrptr == NULL)
-	    cstrptr = "anon";
+	/* Get user's name */
+	s = g_getenv("USERNAME");
+	if(s == NULL)
+	    s = g_getenv("USER");
+	/* All else assume anonymous */
+	if(s == NULL)
+	    s = "anon";
 
-	/* Cat user's name. */
-	tmp_dir_rtn = strcatalloc(tmp_dir_rtn, cstrptr);
+	/* Cat user's name */
+	tmp_dir_rtn = strcatalloc(tmp_dir_rtn, s);
 
 
 	/* Value of tmp_dir_rtn should be set properly now or may be
@@ -238,14 +230,14 @@ char *MEditCreateTempDir(medit_core_struct *core_ptr)
 	    struct stat stat_buf;
 
 
-	    /* Check if tempory directory exists. */
+	    /* Check if tempory directory exists */
 	    if(stat(tmp_dir_rtn, &stat_buf))
 	    {
-		/* Not exist, so need to create a new one. */
+		/* Not exist, so need to create a new one */
 		rmkdir(
 		    tmp_dir_rtn,
 		    S_IRUSR | S_IWUSR | S_IXUSR |
-                    S_IRGRP | S_IXGRP |
+		    S_IRGRP | S_IXGRP |
 		    S_IROTH | S_IXOTH
 		);
 	    }
@@ -266,24 +258,24 @@ char *MEditCreateTempDir(medit_core_struct *core_ptr)
  *
  *	Returns non-zero on failure or error.
  */
-int MEditExecuteFmtBlock(
-        medit_core_struct *core_ptr,
-        const char *cmd,
-        const char *filename,
-        const char *options,
-	const char *stdout_path,
-	const char *stderr_path
+gint MEditExecuteFmtBlock(
+	medit_core_struct *core_ptr,
+	const gchar *cmd,
+	const gchar *filename,
+	const gchar *options,
+	const gchar *stdout_path,
+	const gchar *stderr_path
 )
 {
 	pid_t pid;
-	int fn_cnt, fn_value_len, opt_cnt, opt_value_len;
-	const char *cstrptr;
-	const char *fn_token = "%f";
-	int fn_token_len;
-	const char *opt_token = "%p";
-	int opt_token_len;
-	int buf_len;
-	char *buf;
+	gint fn_cnt, fn_value_len, opt_cnt, opt_value_len;
+	const gchar *s;
+	const gchar *fn_token = "%f";
+	gint fn_token_len;
+	const gchar *opt_token = "%p";
+	gint opt_token_len;
+	gint buf_len;
+	gchar *buf;
 
 
 	if(core_ptr == NULL)
@@ -292,57 +284,57 @@ int MEditExecuteFmtBlock(
 	if(cmd == NULL)
 	    return(-1);
 
-	/* Count number of file name subs. */
+	/* Count number of file name subs */
 	fn_cnt = 0;
 	fn_token_len = strlen(fn_token);
-        fn_value_len = ((filename == NULL) ? 0 : strlen(filename));
-	cstrptr = (const char *)strstr(cmd, fn_token);
-	while(cstrptr != NULL)
+	fn_value_len = ((filename == NULL) ? 0 : strlen(filename));
+	s = (const gchar *)strstr(cmd, fn_token);
+	while(s != NULL)
 	{
 	    fn_cnt++;
-	    cstrptr = (const char *)strstr(
-		cstrptr + fn_token_len,
+	    s = (const gchar *)strstr(
+		s + fn_token_len,
 		fn_token
 	    );
 	}
 
-        /* Count number of options subs. */
-        opt_cnt = 0;
-        opt_token_len = strlen(opt_token);
+	/* Count number of options subs */
+	opt_cnt = 0;
+	opt_token_len = strlen(opt_token);
 	opt_value_len = ((options == NULL) ? 0 : strlen(options));
-        cstrptr = (const char *)strstr(cmd, opt_token);
-        while(cstrptr != NULL)
-        {
-            opt_cnt++;
-            cstrptr = (const char *)strstr(
-                cstrptr + opt_token_len,
-                opt_token  
-            );
-        }
+	s = (const gchar *)strstr(cmd, opt_token);
+	while(s != NULL)
+	{
+	    opt_cnt++;
+	    s = (const gchar *)strstr(
+		s + opt_token_len,
+		opt_token  
+	    );
+	}
 
 
 	/* ********************************************************** */
 
-	/* Allocate execution command buffer buf. */
+	/* Allocate execution command buffer buf */
 	buf_len = strlen(cmd) +
 	    (MAX(fn_value_len - fn_token_len, fn_token_len) * fn_cnt) +
-            (MAX(opt_value_len - opt_token_len, opt_token_len) * opt_cnt);
-	buf = (char *)malloc((buf_len + 1) * sizeof(char));
+	    (MAX(opt_value_len - opt_token_len, opt_token_len) * opt_cnt);
+	buf = (gchar *)g_malloc((buf_len + 1) * sizeof(char));
 	if(buf == NULL)
 	    return(-1);
 
-	/* Copy given command format to allocated command buffer. */
+	/* Copy given command format to allocated command buffer */
 	strcpy(buf, cmd);
 
-	/* Make substitutions. */
+	/* Make substitutions */
 	substr(buf, fn_token, (filename == NULL) ? "" : filename);
-        substr(buf, opt_token, (options == NULL) ? "" : options);
+	substr(buf, opt_token, (options == NULL) ? "" : options);
 
-	/* Execute command buffer. */
+	/* Execute command buffer */
 	pid = ExecBAOE(buf, stdout_path, stderr_path);
 
-        /* Deallocate execute buffer. */
-        free(buf);
+	/* Delete execute buffer */
+	g_free(buf);
 
 	return((pid == 0) ? -1 : 0);
 }
@@ -359,18 +351,18 @@ int MEditExecuteFmtBlock(
  *	exist or the file size is 0. Also will return
  *	CDIALOG_RESPONSE_NOT_AVAILABLE on error.
  */
-int MEditDialogFromFile(
-        medit_core_struct *core_ptr,
-        const char *path 
+gint MEditDialogFromFile(
+	medit_core_struct *core_ptr,
+	const gchar *path 
 )
 {
-	int column, max_columns;
-	int row, max_rows;
-	char *buf;
-	int c, buf_pos, buf_len;
+	gint column, max_columns;
+	gint row, max_rows;
+	gchar *buf;
+	gint c, buf_pos, buf_len;
 
 	FILE *fp;
-	int status = CDIALOG_RESPONSE_NOT_AVAILABLE;
+	gint status = CDIALOG_RESPONSE_NOT_AVAILABLE;
 	struct stat stat_buf;
 
 
@@ -381,27 +373,27 @@ int MEditDialogFromFile(
 	if(CDialogIsQuery())
 	    return(status);
 
-	/* Check if file exists. */
+	/* Check if file exists */
 	if(stat(path, &stat_buf))
 	{
-	    /* File does not exist. */
+	    /* File does not exist */
 	    return(status);
 	}
 	if(stat_buf.st_size <= 0)
 	{
-            /* File size is 0 bytes. */
-            return(status);
-        }
+	    /* File size is 0 bytes */
+	    return(status);
+	}
 
-	/* Open file. */
+	/* Open file */
 	fp = FOpen(path, "rb");
 	if(fp == NULL)
 	{
-            /* Cannot open file. */
-            return(status);
-        }
+	    /* Cannot open file */
+	    return(status);
+	}
 
-	/* Begin reading file. */
+	/* Begin reading file */
 	max_columns = 80;
 	column = 0;
 
@@ -429,11 +421,11 @@ int MEditDialogFromFile(
 		column++;
 	    }
 
-	    /* Increase buffer allocation as needed. */
+	    /* Increase buffer allocation as needed */
 	    if(buf_pos >= buf_len)
 	    {
 		buf_len = buf_pos + 8;
-		buf = (char *)realloc(buf, (buf_len + 1) * sizeof(char));
+		buf = (gchar *)realloc(buf, (buf_len + 1) * sizeof(char));
 		if(buf == NULL)
 		{
 		    buf_len = 0;
@@ -442,54 +434,54 @@ int MEditDialogFromFile(
 		}
 	    }
 
-	    /* Set new character and increment buffer position. */
+	    /* Set new character and increment buffer position */
 	    buf[buf_pos] = (char)c;
 	    buf_pos++;
 
 	    /* Has column exceeded max_columns? */
 	    if(column >= max_columns)
 	    {
-		/* Increase buffer allocation as needed. */
-                if(buf_pos >= buf_len)
-                {
-                    buf_len = buf_pos + 8;
-                    buf = (char *)realloc(buf, (buf_len + 1) * sizeof(char));
-                    if(buf == NULL)
-                    {
-                        buf_len = 0;
-                        buf_pos = 0;
-                        break;
-                    }
+		/* Increase buffer allocation as needed */
+		if(buf_pos >= buf_len)
+		{
+		    buf_len = buf_pos + 8;
+		    buf = (gchar *)realloc(buf, (buf_len + 1) * sizeof(char));
+		    if(buf == NULL)
+		    {
+			buf_len = 0;
+			buf_pos = 0;
+			break;
+		    }
 		}
 
-		/* Set new character and increment buffer position. */
+		/* Set new character and increment buffer position */
 		buf[buf_pos] = '\n';
 		buf_pos++;
 
-		/* Reset column and increment row. */
-                column = 0;
-                row++;
+		/* Reset column and increment row */
+		column = 0;
+		row++;
 	    }
 	}
 
-        /* Increase buffer allocation as needed. */
-        if(buf_pos >= buf_len)
-        {
-            buf_len = buf_pos + 8;
-            buf = (char *)realloc(buf, (buf_len + 1) * sizeof(char));
-            if(buf == NULL)
-            {
-                buf_len = 0;
-                buf_pos = 0;
-            }
-        }
-	/* Add null terminating byte if possible. */
+	/* Increase buffer allocation as needed */
+	if(buf_pos >= buf_len)
+	{
+	    buf_len = buf_pos + 8;
+	    buf = (gchar *)realloc(buf, (buf_len + 1) * sizeof(char));
+	    if(buf == NULL)
+	    {
+		buf_len = 0;
+		buf_pos = 0;
+	    }
+	}
+	/* Add null terminating byte if possible */
 	if(buf_pos < buf_len)
 	    buf[buf_pos] = '\0';
 
 
 
-	/* Close file. */
+	/* Close file */
 	fclose(fp);
 	fp = NULL;
 
@@ -504,8 +496,8 @@ int MEditDialogFromFile(
 	);
 
 
-	/* Deallocate buffer. */
-	free(buf);
+	/* Delete buffer */
+	g_free(buf);
 	buf_len = 0;
 	buf_pos = 0;
 
@@ -525,20 +517,20 @@ int MEditDialogFromFile(
  *
  *	-2 cannot create tempory directory.
  */
-int MEditDoEmergencySave(medit_core_struct *core_ptr)
+gint MEditDoEmergencySave(medit_core_struct *core_ptr)
 {
-	int i;
+	gint i;
 	editor_struct *editor;
 	editor_item_struct *item_ptr;
 	GtkCTreeNode *branch;
 	GtkCTreeRow *branch_row;
-	char *prog_tmp_path;
+	gchar *prog_tmp_path;
 
 
 	if(core_ptr == NULL)
 	    return(-1);
 
-	/* Get program tempory directory. */
+	/* Get program tempory directory */
 	prog_tmp_path = MEditCreateTempDir(core_ptr);
 	if(prog_tmp_path == NULL)
 	    return(-2);
@@ -552,41 +544,42 @@ int MEditDoEmergencySave(medit_core_struct *core_ptr)
 	    if(editor == NULL)
 		continue;
 
-	    /* Get pointer to first branch on editor's layout ctree. */
+	    /* Get pointer to first branch on editor's layout ctree */
 	    branch = EditorItemGetFirstToplevel(editor);
 
-	    /* Begin saving each manual page loaded on the editor. */
+	    /* Begin saving each manual page loaded on the editor */
 	    while(branch != NULL)
 	    {
-		/* Get pointer to item data. */
+		/* Get pointer to item data */
 		item_ptr = EditorBranchGetData(
 		    (GtkCTree *)editor->layout_ctree,
 		    branch
 		);
 		if(item_ptr != NULL)
 		{
-		    /* Got item, assume it is of type EditorItemTypeFile. */
+		    /* Got item, assume it is of type EditorItemTypeFile */
 
 		    /* Change the file name full on this loaded manual
-		     * page to the path specified by tmp_dir.
+		     * page to the path specified by tmp_dir
 		     */
-		    free(item_ptr->file_name_full);
-		    item_ptr->file_name_full = tempnam(
-			prog_tmp_path, "mp"
-		    );
+		    g_free(item_ptr->file_name_full);
+		    item_ptr->file_name_full = g_strdup(PrefixPaths(
+			prog_tmp_path, "emergencyXXXXXX"
+		    ));
+		    mkstemp(item_ptr->file_name_full);
 
-		    /* Save this branch. */
+		    /* Save this branch */
 		    EditorFileSave(editor, branch);
 		}
 
-		/* Get next branch. */
+		/* Get next branch */
 		branch_row = GTK_CTREE_ROW(branch);
 		branch = ((branch_row == NULL) ? NULL : branch_row->sibling);
 	    }
 	}
 
-	/* Deallocate tempory directory. */
-	free(prog_tmp_path);
+	/* Delete tempory directory */
+	g_free(prog_tmp_path);
 	prog_tmp_path = NULL;
 
 	return(0);
@@ -612,17 +605,17 @@ int MEditDoEmergencySave(medit_core_struct *core_ptr)
  *	If there are no files found then this function performs no
  *	operation.
  */
-int MEditDoCrashRecovery(medit_core_struct *core_ptr)
+gint MEditDoCrashRecovery(medit_core_struct *core_ptr)
 {
-	gbool yes_to_all = FALSE;
-        int i, status;
-	char **path, *path_ptr;
-        char *prog_tmp_path;
+	gboolean yes_to_all = FALSE;
+	gint i, status;
+	gchar **path, *path_ptr;
+	gchar *prog_tmp_path;
 	editor_struct *editor;
 
 
-        if(core_ptr == NULL)
-            return(-1);
+	if(core_ptr == NULL)
+	    return(-1);
 
 	/* Get first editor from core structure, it must be valid and
 	 * initialized!
@@ -638,40 +631,34 @@ int MEditDoCrashRecovery(medit_core_struct *core_ptr)
 	    return(-1);
 
 
-        /* Get program tempory directory. */
-        prog_tmp_path = MEditCreateTempDir(core_ptr);
-        if(prog_tmp_path == NULL)
-            return(-2);
+	/* Get program tempory directory */
+	prog_tmp_path = MEditCreateTempDir(core_ptr);
+	if(prog_tmp_path == NULL)
+	    return(-2);
 
-	/* Get listing of objects in program's tempory directory. */
+	/* Get listing of objects in program's tempory directory */
 	path = GetDirEntNames(prog_tmp_path);
 
-	/* Check for any contents in directory, itterate through paths. */
+	/* Check for any contents in directory, itterate through paths */
 	i = 0;
 	while(path[i] != NULL)
 	{
 	    path_ptr = path[i];
 	    if(strcmp(path_ptr, ".") &&
-               strcmp(path_ptr, "..")
+	       strcmp(path_ptr, "..")
 	    )
 	    {
-		char *filename = PrefixPaths(prog_tmp_path, path_ptr);
+		gchar *filename = PrefixPaths(prog_tmp_path, path_ptr);
 
-		/* Make a copy of the file name. */
+		/* Make a copy of the file name */
 		if(filename != NULL)
-		    filename = strdup(filename);
+		    filename = g_strdup(filename);
 
 		/* Got filename and confirmation dialog is available? */
 		if((filename != NULL) && !CDialogIsQuery())
 		{
-		    gbool can_remove = FALSE;
-		    char *tmp_buf;
-		    int tmp_buf_len = strlen(filename) + 1024;
-
-		    /* Allocate message buffer. */
-		    tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-		    if(tmp_buf != NULL)
-			sprintf(tmp_buf,
+		    gboolean can_remove = FALSE;
+		    gchar *s = g_strdup_printf(
 "Found a file saved from an emergency save procedure:\n\
 `%s'\n\n\
 Do you wish to load this file? If you say `yes' then\n\
@@ -680,14 +667,14 @@ the file will be loaded otherwise it will be removed.\n\
 If you say `yes', then remember to use file->save as to\n\
 save the file under a different name before exiting!",
 			    filename
-			);
+		    );
 
 		    if(yes_to_all)
 			status = CDIALOG_RESPONSE_YES;
 		    else
 			status = CDialogGetResponse(
 "Recover File?",
-			    tmp_buf,
+			    s,
 "You are being asked if you want to load a file\n\
 that was saved during an emergency save procedure\n\
 from the last time you ran this program. This\n\
@@ -703,19 +690,16 @@ file->save as.",
 			    CDIALOG_BTNFLAG_NO | CDIALOG_BTNFLAG_HELP,
 			    CDIALOG_BTNFLAG_YES
 			);
+		    g_free(s);
 
-		    /* Free message buffer. */
-		    free(tmp_buf);
-		    tmp_buf = NULL;
-
-		    /* Handle response. */
+		    /* Handle response */
 		    switch(status)
 		    {
 		      case CDIALOG_RESPONSE_YES_TO_ALL:
 			yes_to_all = TRUE;
 		      case CDIALOG_RESPONSE_YES:
 		      case CDIALOG_RESPONSE_NOT_AVAILABLE:
-                      case CDIALOG_RESPONSE_OK:
+		      case CDIALOG_RESPONSE_OK:
 			if(EditorFileLoad(
 			    editor, filename, NULL, FALSE
 			))
@@ -735,29 +719,27 @@ file->save as.",
 			unlink(filename);
 		}
 
-
-
-		/* Free file name. */
-		free(filename);
+		/* Free file name */
+		g_free(filename);
 	    }
 
-	    /* Deallocate path. */
-	    free(path[i]);
+	    /* Delete path */
+	    g_free(path[i]);
 	    path[i] = NULL;
 
-	    /* Increment to next path. */
+	    /* Increment to next path */
 	    i++;
 	}
 
-	/* Deallocate paths pointer array. */
-	free(path);
+	/* Delete paths pointer array */
+	g_free(path);
 	path = NULL;
 
 
 
-        /* Deallocate tempory directory. */
-        free(prog_tmp_path);
-        prog_tmp_path = NULL;
+	/* Delete tempory directory */
+	g_free(prog_tmp_path);
+	prog_tmp_path = NULL;
 
 	return(0);
 }
