@@ -8,28 +8,23 @@
 #ifndef PREF_H
 #define PREF_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
-#ifndef gbool
-# define gbool	gboolean
-#endif
-
 
 /*
- *	Preferance catagory values, each value is an index to a
- *	panel_parent on the Preferences & Options window structure.
+ *	Preference catagory values, each value is an index to a
+ *	panel_parent on the Preferences & Options window structure
  */
-#define MEDIT_PREF_CAT_APPERANCE	0
-#define MEDIT_PREF_CAT_FONTS		1
-#define MEDIT_PREF_CAT_COLORS		2
+#define MEDIT_PREF_CAT_APPERANCE		0
+#define MEDIT_PREF_CAT_FONTS			1
+#define MEDIT_PREF_CAT_COLORS			2
 
-#define MEDIT_PREF_CAT_EDITOR		3
+#define MEDIT_PREF_CAT_EDITOR			3
 
-#define MEDIT_PREF_CAT_VIEWER		4
+#define MEDIT_PREF_CAT_VIEWER			4
 
-#define MEDIT_PREF_CAT_LOCATIONS	5
-#define MEDIT_PREF_CAT_CONVERTERS	6
+#define MEDIT_PREF_CAT_LOCATIONS		5
+#define MEDIT_PREF_CAT_CONVERTERS		6
 
 
 /*
@@ -42,9 +37,9 @@
 #define MEDIT_PREF_PARM_RECORD_WIN_POS		2	/* GtkCheckButton */
 #define MEDIT_PREF_PARM_TOOL_TIPS		3	/* GtkCheckButton */
 
-#define MEDIT_PREF_PARM_TOOLBAR_PT		4	/* GtkRadioButton. */
-#define MEDIT_PREF_PARM_TOOLBAR_P		5	/* GtkRadioButton. */
-#define MEDIT_PREF_PARM_TOOLBAR_T		6	/* GtkRadioButton. */
+#define MEDIT_PREF_PARM_TOOLBAR_PT		4	/* GtkRadioButton */
+#define MEDIT_PREF_PARM_TOOLBAR_P		5	/* GtkRadioButton */
+#define MEDIT_PREF_PARM_TOOLBAR_T		6	/* GtkRadioButton */
 
 #define MEDIT_PREF_PARM_FONT_EDIT_STD		10	/* GtkEntry */
 #define MEDIT_PREF_PARM_FONT_MANPAGE_STD	11	/* GtkEntry */
@@ -77,15 +72,15 @@
 
 /*
  *	Branch item structure for Preferences & Options window's
- *	layout_ctree.
+ *	layout_ctree
  */
 typedef struct {
 
-	/* One of MEDIT_PREF_CAT_* or -1 for none. */
-	int catagory;
+	/* One of MEDIT_PREF_CAT_* or -1 for none */
+	gint		catagory;
 
-	/* Pointer back to Preferences & Options window structure. */
-	void *pref_ptr;
+	/* Pointer back to Preferences & Options window structure */
+	gpointer	pref_ptr;
 
 } pref_item_struct;
 
@@ -95,30 +90,29 @@ typedef struct {
  */
 typedef struct {
 
-	gbool initialized;
-	gbool map_state;
-	gbool has_changes;
-	gbool processing;
+	gboolean	initialized,
+			map_state,
+			has_changes,
+			processing;
+	gpointer	core_ptr;
 
-	void *core_ptr;		/* Pointer back to core structure. */
+	GtkWidget	*toplevel,
+			*main_vbox;
 
-	GtkWidget *toplevel;
-	GtkWidget *main_vbox;
+	/* Main catagory ctree */
+	GtkWidget	*catagory_ctree;
+	GtkCTreeNode	*selected_branch;
 
-	/* Main catagory ctree. */
-	GtkWidget *catagory_ctree;
-	GtkCTreeNode *selected_branch;
-
-	/* Parent to all panel parent vboxes. */
-	GtkWidget *panel_toplevel;
+	/* Parent to all panel parent vboxes */
+	GtkWidget	*panel_toplevel;
 
 	/* Array of vboxes which hold various widgets depending
-	 * on which branch on the layout_ctree is selected.
+	 * on which branch on the layout_ctree is selected
 	 */
-	GtkWidget **panel_parent;
-	int total_panel_parents;
+	GtkWidget	**panel_parent;
+	gint total_panel_parents;
 
-	/* Buttons. */
+	/* Buttons */
 	GtkWidget	*ok_btn,
 			*apply_btn,
 			*save_btn,
@@ -129,55 +123,57 @@ typedef struct {
 	 * is indexed by hard coded values defined by
 	 * MEDIT_PREF_PARM_*.
 	 */
-	GtkWidget **parm_widget;
-	int total_parm_widgets;
+	GtkWidget	**parm_widget;
+	gint		total_parm_widgets;
 
 
-	/* Other values that we're not recording on widgets. */
-	int last_editor_width, last_editor_height;
-	int last_viewer_width, last_viewer_height;
+	/* Other values that we're not recording on widgets */
+	gint		last_editor_width,
+			last_editor_height;
+	gint		last_viewer_width,
+			last_viewer_height;
 
-	char *last_opened_manpage_path;
-	char *last_saved_manpage_path;
-	char *last_opened_manage_view_path;
+	gchar		*last_opened_manpage_path;
+	gchar		*last_saved_manpage_path;
+	gchar		*last_opened_manage_view_path;
 
-	/* Last selected item on MEDIT_PREF_PARM_LOCATIONS_MAN_DIRS. */
-	int selected_manpage_dirs_clist_item;
+	/* Last selected item on MEDIT_PREF_PARM_LOCATIONS_MAN_DIRS */
+	gint		selected_manpage_dirs_clist_item;
 
 } pref_struct;
 
 
-extern GtkWidget *PrefParmGetWidget(pref_struct *pref, int parameter);
-extern GtkWidget *PrefPanelGetWidget(pref_struct *pref, int catagory);
-extern char *PrefPanelGetBranchText(pref_struct *pref, GtkCTreeNode *branch);
+extern GtkWidget *PrefParmGetWidget(pref_struct *pref, gint parameter);
+extern GtkWidget *PrefPanelGetWidget(pref_struct *pref, gint catagory);
+extern gchar *PrefPanelGetBranchText(pref_struct *pref, GtkCTreeNode *branch);
 
-extern int PrefParmRecord(
+extern gint PrefParmRecord(
 	pref_struct *pref,
-	int parameter,		/* One of MEDIT_PREF_PARM_*. */
+	gint parameter,		/* One of MEDIT_PREF_PARM_* */
 	GtkWidget *w
 );
 
-extern int PrefPanelRecord(
+extern gint PrefPanelRecord(
 	pref_struct *pref,
-	int catagory,		/* One of MEDIT_PREF_CAT_. */
-	GtkWidget *w		/* A vbox. */
+	gint catagory,		/* One of MEDIT_PREF_CAT_ */
+	GtkWidget *w		/* A vbox */
 );
 
-extern void *PrefParmGetValueP(
+extern gpointer PrefParmGetValueP(
 	pref_struct *pref,
-	int parameter		/* One of MEDIT_PREF_PARM_*. */
+	gint parameter		/* One of MEDIT_PREF_PARM_* */
 );
-extern int PrefParmGetValueI(
+extern gint PrefParmGetValueI(
         pref_struct *pref,
-        int parameter           /* One of MEDIT_PREF_PARM_*. */
+        gint parameter		/* One of MEDIT_PREF_PARM_* */
 );
 extern float PrefParmGetValueF(
         pref_struct *pref,
-        int parameter           /* One of MEDIT_PREF_PARM_*. */
+        gint parameter		/* One of MEDIT_PREF_PARM_* */
 );
-extern gbool PrefParmGetValueB(
+extern gboolean PrefParmGetValueB(
         pref_struct *pref,
-        int parameter           /* One of MEDIT_PREF_PARM_*. */
+        gint parameter		/* One of MEDIT_PREF_PARM_* */
 );
 
 extern void PrefBranchSetData(
@@ -195,16 +191,14 @@ extern GtkCTreeNode *PrefAddCatagoryBranch(
         const char *catagory_name,
         GtkCTreeNode *parent,
         GtkCTreeNode *sibling,
-        gbool is_leaf,   
+        gboolean is_leaf,   
         GtkWidget *panel_vbox,
-        int catagory
+        gint catagory
 );
 
-extern pref_struct *PrefNew(
-	void *core_ptr
-);
+extern pref_struct *PrefNew(gpointer core_ptr);
 extern void PrefUpdateMenus(pref_struct *pref);
-extern void PrefReset(pref_struct *pref, gbool need_unmap);
+extern void PrefReset(pref_struct *pref, gboolean need_unmap);
 extern void PrefMap(pref_struct *pref);
 extern void PrefUnmap(pref_struct *pref);
 extern void PrefDelete(pref_struct *pref);
