@@ -1,10 +1,6 @@
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
-#include <sys/types.h>
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -67,8 +63,7 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 );
 void ViewerIndexDoLoad(  
 	viewer_struct *v,
-	const gchar **path, gint total_paths,
-	const gchar **name
+	gint total_paths, gchar **path, gchar **name
 );
 
 gboolean ViewerDoFind(
@@ -114,11 +109,11 @@ viewer_index_item_struct *ViewerIndexItemNew(
 	const gchar *file_name_full
 )
 {
-	viewer_index_item_struct *item_ptr = (viewer_index_item_struct *)calloc(
-	    1, sizeof(viewer_index_item_struct)
-	);
+	viewer_index_item_struct *item_ptr = VIEWER_INDEX_ITEM(g_malloc0(
+	    sizeof(viewer_index_item_struct)
+	));
 	if(item_ptr == NULL)
-	    return(item_ptr);
+	    return(NULL);
 
 	item_ptr->type = type;
 
@@ -272,7 +267,7 @@ void ViewerTextInsert(
 	    return;
 
 	/* Get pointer to core structure */
-	core_ptr = (medit_core_struct *)v->core_ptr;
+	core_ptr = MEDIT_CORE(v->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
@@ -302,7 +297,7 @@ void ViewerTextInsert(
 
 	gtk_text_freeze(text);
 
-	/* Itterate through buffer */
+	/* Iterate through buffer */
 	last_char = '\0';	/* Reset last character to be printed */
 	buf_ptr = buf;
 	buf_end = (const gchar *)(buf + buf_len);
@@ -310,14 +305,15 @@ void ViewerTextInsert(
 	{
 	    if(func_cb != NULL)
 	    {
-/* Do not call function callback while GtkText widget is frozen.
+#if 0
+/* Do not call function callback while GtkText widget is frozen */
 		status = func_cb(
 		    (long)MIN(buf_ptr - buf, buf_len), (long)buf_len,
 		    client_data
 		);
 		if(status)
 		    break;
- */
+#endif
 	    }
 
 	    /* Seek to next control charater if any, setting buf_next
@@ -387,7 +383,7 @@ printf("Insert one: %.8x %.8x (%.8x)\n",
 		/* Store to next control character or end of buffer */
 
 		/* Calculate this segment length */
-		gint seg_len = (int)(buf_next - buf_ptr);
+		gint seg_len = (gint)(buf_next - buf_ptr);
 
 		/* Use ManPage standard text style */
 		style_ptr = styles_list->manpage_text_standard;
@@ -466,21 +462,20 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 	const gchar *full_path, const gchar *name
 )
 {
-	gint i;
+	gint i, text_total;
+	gchar **text;
+	struct stat stat_buf;
 	GtkCTreeNode *new_branch = NULL;
 	medit_core_struct *core_ptr;
 	medit_pixmaps_list_struct *pixmaps_list;
-	gchar *strptr, **text;
 	viewer_index_item_struct *item_ptr;
-	gint text_total;
-	struct stat stat_buf;
 
 
 	/* Check for stop */
 	if(v->stop_count > 0)
 	    return(new_branch);
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
+	core_ptr = MEDIT_CORE(v->core_ptr);
 	if(core_ptr == NULL)
 	    return(new_branch);
 
@@ -499,70 +494,75 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 	    if(text != NULL)
 	    {
 		/* Allocate name cell value */
-		strptr = strrchr(full_path, DIR_DELIMINATOR);
-		if(name == NULL)
-		    text[0] = strdup((strptr == NULL) ?
-		        full_path : strptr + 1
-		    );
+		if(name != NULL)
+		{
+		    text[0] = g_strdup(name);
+		}
 		else
-		    text[0] = strdup(name);
+		{
+		    gchar *s = strrchr(full_path, G_DIR_SEPARATOR);
+		    text[0] = g_strdup(
+			(s != NULL) ? (s + 1) : full_path
+		    );
+		}
+
 		/* Substitute directory name with verbose catagory
-		 * name if possible.
+		 * name if possible
 		 */
 		if(!strcmp(text[0], "man1"))
 		{
 		    g_free(text[0]);
-		    text[0] = strdup(MEDIT_SECT_NAME_1);
+		    text[0] = g_strdup(MEDIT_SECT_NAME_1);
 		}
 		else if(!strcmp(text[0], "man2"))
 		{
 		    g_free(text[0]);
-		    text[0] = strdup(MEDIT_SECT_NAME_2);
+		    text[0] = g_strdup(MEDIT_SECT_NAME_2);
 		}
 		else if(!strcmp(text[0], "man3"))
 		{
 		    g_free(text[0]);
-		    text[0] = strdup(MEDIT_SECT_NAME_3);
+		    text[0] = g_strdup(MEDIT_SECT_NAME_3);
 		}
 		else if(!strcmp(text[0], "man4"))
 		{
 		    g_free(text[0]);
-		    text[0] = strdup(MEDIT_SECT_NAME_4);
+		    text[0] = g_strdup(MEDIT_SECT_NAME_4);
 		}
 		else if(!strcmp(text[0], "man5"))
 		{
 		    g_free(text[0]);
-		    text[0] = strdup(MEDIT_SECT_NAME_5);
+		    text[0] = g_strdup(MEDIT_SECT_NAME_5);
 		}
 		else if(!strcmp(text[0], "man6"))
 		{       
 		    g_free(text[0]);
-		    text[0] = strdup(MEDIT_SECT_NAME_6);
+		    text[0] = g_strdup(MEDIT_SECT_NAME_6);
 		}
 		else if(!strcmp(text[0], "man7"))
 		{
 		    g_free(text[0]);
-		    text[0] = strdup(MEDIT_SECT_NAME_7);
+		    text[0] = g_strdup(MEDIT_SECT_NAME_7);
 		}
 		else if(!strcmp(text[0], "man8"))
 		{ 
 		    g_free(text[0]);
-		    text[0] = strdup(MEDIT_SECT_NAME_8);
+		    text[0] = g_strdup(MEDIT_SECT_NAME_8);
 		}
 		/* Now strip .extension from name */
 		if(text[0] != NULL)
 		{
-		    strptr = strrchr(text[0], '.');
-		    if(strptr != NULL)
-			(*strptr) = '\0';
+		    gchar *s = strrchr(text[0], '.');
+		    if(s != NULL)
+			*s = '\0';
 		}
 
 		/* Allocate lines and read state cell values */
-		text[1] = strdup("");
-		text[2] = strdup("");
+		text[1] = g_strdup("");
+		text[2] = g_strdup("");
 
 		/* Allocate description value */
-		text[3] = strdup("*Directory*");
+		text[3] = g_strdup("*Directory*");
 
 		/* Create new branch */
 		new_branch = gtk_ctree_insert_node(
@@ -584,11 +584,11 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		);
 		/* Set index item structure pointer to branch row data */
 		gtk_ctree_node_set_row_data_full(
-		    ctree, new_branch, (gpointer)item_ptr,
-		    (GtkDestroyNotify)ViewerIndexBranchDestroyCB
+		    ctree, new_branch,
+		    item_ptr, ViewerIndexBranchDestroyCB
 		);
 
-		/* Deallocate cell values */
+		/* Delete cell values */
 		strlistfree(text, text_total);
 	    }
 	}
@@ -599,24 +599,24 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 	    if(text != NULL)
 	    {
 		/* Get name cell value */
-		strptr = strrchr(full_path, DIR_DELIMINATOR);
-		text[0] = strdup((strptr == NULL) ?
-		    full_path : strptr + 1
+		gchar *s = strrchr(full_path, G_DIR_SEPARATOR);
+		text[0] = g_strdup(
+		    (s != NULL) ? (s + 1) : full_path
 		);
 		/* Now strip .extension from name */
 		if(text[0] != NULL)
 		{
-		    strptr = strrchr(text[0], '.');
-		    if(strptr != NULL)
-			(*strptr) = '\0';
+		    gchar *s = strrchr(text[0], '.');
+		    if(s != NULL)
+			*s = '\0';
 		}
 
 		/* Get lines and read state cell values */
-		text[1] = strdup("");
-		text[2] = strdup("");
+		text[1] = g_strdup("");
+		text[2] = g_strdup("");
 
 		/* Get description cell value */
-		text[3] = strdup("Manual Page File");
+		text[3] = g_strdup("Manual Page File");
 
 		/* Create new branch */
 		new_branch = gtk_ctree_insert_node(
@@ -628,7 +628,7 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		    pixmaps_list->manual_opened_20x20,
 		    pixmaps_list->manual_opened_20x20_mask,
 		    TRUE,		/* Is leaf */
-		    FALSE               /* Expanded */
+		    FALSE		/* Expanded */
 		);
 
 		/* Allocate new index item structure */
@@ -638,11 +638,11 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		);
 		/* Set index item structure pointer to branch row data */
 		gtk_ctree_node_set_row_data_full(
-		    ctree, new_branch, (gpointer)item_ptr,
-		    (GtkDestroyNotify)ViewerIndexBranchDestroyCB
+		    ctree, new_branch,
+		    item_ptr, ViewerIndexBranchDestroyCB
 		);
 
-		/* Deallocate cell values */
+		/* Delete cell values */
 		strlistfree(text, text_total);
 	    }
 	}
@@ -651,24 +651,15 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 	/* If given path is a directory, recurse into it */
 	if(S_ISDIR(stat_buf.st_mode))
 	{
-	    gchar **path;
-	    gchar tmp_path[PATH_MAX + NAME_MAX];
-	    gchar *tmp_buf;
-	    gint tmp_buf_len;
-
-
-	    /* Allocate message bufferr */
-	    tmp_buf_len = strlen(full_path) + 256;
-	    tmp_buf = (gchar *)g_malloc((tmp_buf_len + 1) * sizeof(gchar));
- 	    if(tmp_buf != NULL)
-		sprintf(tmp_buf, "Scanning %s...", full_path);
-
-	    ViewerSetStatusMessage(v, tmp_buf);
-
-	    /* Delete message buffer */
-	    g_free(tmp_buf);
-	    tmp_buf = NULL;
+	    gchar *s, **path;
 
+	    /* Print status message */
+	    s = g_strdup_printf(
+		"Scanning %s...",
+		full_path
+	    );
+	    ViewerSetStatusMessage(v, s);
+	    g_free(s);
 
 	    /* Manage GTK events */
 	    while(gtk_events_pending() > 0)
@@ -694,29 +685,28 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		   strcmp(path[i], "whatis")
 		)
 		{
-		  /* Make into full path as strptr */
-		  strptr = PrefixPaths(full_path, path[i]);
-		  if(strptr != NULL)
-		  {
-		    strncpy(tmp_path, strptr, PATH_MAX + NAME_MAX);
-		    tmp_path[PATH_MAX + NAME_MAX - 1] = '\0';
-
-		    ViewerIndexDoLoadIteration(
-			v, ctree,
-			new_branch,	/* Parent */
-			NULL,		/* Sibling */
-			tmp_path, NULL
-		    );
-		  }
+		    /* Make into full path as strptr */
+		    s = PrefixPaths(full_path, path[i]);
+		    if(s != NULL)
+		    {
+			s = (s != NULL) ? g_strdup(s) : NULL;
+			ViewerIndexDoLoadIteration(
+			    v, ctree,
+			    new_branch,		/* Parent */
+			    NULL,		/* Sibling */
+			    s, NULL
+			);
+			g_free(s);
+		    }
 		}
 
-		/* Deallocate this path */
+		/* Delete this path */
 		g_free(path[i]);
 		path[i] = NULL;
 	    }
 
-	    /* Deallocate paths pointer array (note each pointed to path
-	     * was deallocated in the above loop).
+	    /* Delete paths pointer array (note each pointed to path
+	     * was deleted in the above loop)
 	     */
 	    g_free(path);
 	}
@@ -728,28 +718,23 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
  *	Loads recursivly, manual pages in the given paths array.
  *
  *	The given paths must be full paths. The given paths and names
- *	list will not be deallocated. The names will be used as the
+ *	list will not be deleted. The names will be used as the
  *	directory names placed into the index clist, each name corresponds
  *	to the path.
  */
 void ViewerIndexDoLoad(
 	viewer_struct *v,
-	const gchar **path, gint total_paths,
-	const gchar **name
+	gint total_paths, gchar **path, gchar **name
 )
 {
 	gint i;
+	gchar *s;
 	GtkCTree *ctree;
-	gchar *tmp_buf;
-	gint tmp_buf_len;
 
 	if((v == NULL) || (path == NULL) || (total_paths < 1))
 	    return;
 
-	if(!v->initialized)
-	    return;
-
-	if(v->processing)
+	if(!v->initialized || v->processing)
 	    return;
 
 	ctree = (GtkCTree *)v->index_ctree;
@@ -763,13 +748,13 @@ void ViewerIndexDoLoad(
 	/* Reset stop count */
 	v->stop_count = 0;
 
-	gtk_clist_freeze((GtkCList *)ctree);
+	gtk_clist_freeze(GTK_CLIST(ctree));
 
 	ViewerSetBusy(v);
 	ViewerUpdateMenus(v);
 
 
-	/* Itterate through each path */
+	/* Iterate through each path */
 	for(i = 0; i < total_paths; i++)
 	{
 	    if(path[i] == NULL)
@@ -783,39 +768,31 @@ void ViewerIndexDoLoad(
 	    if(v->stop_count > 0)
 		break;
 
-
-	    /* Allocate message buffer */
-	    tmp_buf_len = strlen(path[i]) + 256;
-	    tmp_buf = (gchar *)g_malloc((tmp_buf_len + 1) * sizeof(gchar));
-	    if(tmp_buf != NULL)
-		sprintf(tmp_buf, "Scanning %s...", path[i]);
-
-	    ViewerSetStatusMessage(v, tmp_buf);
-
-	    /* Deallocate message buffer */
-	    g_free(tmp_buf);
-	    tmp_buf = NULL;
-
+	    /* Print status message */
+	    s = g_strdup_printf(
+		"Scanning %s...",
+		path[i]
+	    );
+	    ViewerSetStatusMessage(v, s);
+	    g_free(s);
 
 	    /* Load this path and any subdirs */
 	    ViewerIndexDoLoadIteration(
 		v, ctree,
 		NULL,		/* Parent */
 		NULL,		/* Sibling */
-		(const gchar *)path[i], (const gchar *)name[i]
+		path[i], name[i]
 	    );
 	}
 
 	ViewerSetStatusMessage(v, "Index scan done");
 
-	gtk_clist_thaw((GtkCList *)ctree);
+	gtk_clist_thaw(GTK_CLIST(ctree));
 
 	/* Mark done processing */
 	v->processing = FALSE;
 	ViewerSetReady(v);
 	ViewerUpdateMenus(v);
-
-	return;
 }
 
 
@@ -824,7 +801,7 @@ void ViewerIndexDoLoad(
  *      the given text widget.
  *
  *      Both needle and haystack may be modified by this function,
- *      but never deallocated.
+ *      but never deleted.
  *
  *      Given GtkText widget will be updated and instructed to select
  *      the matched text if a match was made. If case_sensitive is TRUE
@@ -955,7 +932,7 @@ gboolean ViewerDoFind(
 	else
 	{
 	    /* Got match */
-	    gint match_start_pos = (int)(match_ptr - haystack);
+	    gint match_start_pos = (gint)(match_ptr - haystack);
 	    gint needle_len = strlen(needle);
 		    
 	    if(match_start_pos < 0)
@@ -1033,7 +1010,7 @@ void ViewerSetBusy(viewer_struct *v)
 	if(v == NULL)
 	    return;
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
+	core_ptr = MEDIT_CORE(v->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
@@ -1264,8 +1241,7 @@ w = GUIMenuItemCreate( \
 
 	/* Help menu */
 	menu = MEditCreateHelpMenu(
-	    (medit_core_struct *)v->core_ptr,  
-	    accel_group
+	    MEDIT_CORE(v->core_ptr), accel_group
 	);
 	GUIMenuAddToMenuBar(
 	    menu_bar, menu,
@@ -1624,10 +1600,9 @@ viewer_struct *ViewerNew(gpointer core_ptr, gint editor_num)
 {MEDIT_DND_TYPE_NAME_VIEWER_BRANCH_CMD, GTK_TARGET_SAME_APP,
 						MEDIT_DND_TYPE_INFO_VIEWER_BRANCH_CMD}
 	};
-	viewer_struct *v = (viewer_struct *)calloc(
-	    1,
+	viewer_struct *v = VIEWER(g_malloc0(
 	    sizeof(viewer_struct)
-	);
+	));
 	if(v == NULL)
 	    return(NULL);
 
@@ -1635,9 +1610,9 @@ viewer_struct *ViewerNew(gpointer core_ptr, gint editor_num)
 	/* Get pointers to resources on core structure */
 	if(core_ptr != NULL)
 	{
-	    cursors_list = &((medit_core_struct *)core_ptr)->cursors_list;
-	    styles_list = &((medit_core_struct *)core_ptr)->styles_list;
-	    pref = ((medit_core_struct *)core_ptr)->pref;
+	    cursors_list = &(MEDIT_CORE(core_ptr)->cursors_list);
+	    styles_list = &(MEDIT_CORE(core_ptr)->styles_list);
+	    pref = MEDIT_CORE(core_ptr)->pref;
 	}
 
 	/* Reset values */
@@ -2329,7 +2304,7 @@ void ViewerUpdateMenus(viewer_struct *v)
 	if(!v->initialized)
 	    return;
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
+	core_ptr = MEDIT_CORE(v->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
@@ -2550,9 +2525,8 @@ void ViewerUpdateMenus(viewer_struct *v)
  */
 void ViewerSetStatusPosition(viewer_struct *v, gint row, gint column)
 {
+	gchar *s;
 	GtkWidget *w;
-	gchar text[256];
-
 
 	if(v == NULL)
 	    return;
@@ -2560,18 +2534,16 @@ void ViewerSetStatusPosition(viewer_struct *v, gint row, gint column)
 	w = v->status_bar_cursor_label;
 	if(w == NULL)
 	    return;
-	sprintf(text, "Row: %i / Col: %i",
+
+	s = g_strdup_printf(
+	    "Row: %i / Col: %i",
 	    row, column
 	);
-	gtk_label_set_text(GTK_LABEL(w), text);
+	gtk_label_set_text(GTK_LABEL(w), s);
+	g_free(s);
 
-	/* Itterate through GTK main function until all events are handled
-	 * so that we ensure this label text is updated.
-	 */
 	while(gtk_events_pending() > 0)
 	    gtk_main_iteration();
-
-	return;
 }
 
 /*
@@ -2586,7 +2558,6 @@ void ViewerSetStatusMessage(viewer_struct *v, const gchar *mesg)
 {
 	GtkWidget *w;
 
-
 	if(v == NULL)
 	    return;
 
@@ -2596,16 +2567,11 @@ void ViewerSetStatusMessage(viewer_struct *v, const gchar *mesg)
 
 	gtk_label_set_text(
 	    GTK_LABEL(w),
-	    (mesg == NULL) ? "" : mesg
+	    (mesg != NULL) ? mesg : ""
 	);
 
-	/* Itterate through GTK main function until all events are handled
-	 * so that we ensure this label text is updated.
-	 */
 	while(gtk_events_pending() > 0)
 	    gtk_main_iteration();
-
-	return;
 }
 
 /*
@@ -2618,9 +2584,8 @@ void ViewerSetStatusMessage(viewer_struct *v, const gchar *mesg)
  */
 void ViewerSetStatusProgress(viewer_struct *v, gfloat percent)
 {
-	GtkWidget *w;
 	gfloat p;
-
+	GtkWidget *w;
 
 	if(v == NULL)
 	    return;
@@ -2635,27 +2600,22 @@ void ViewerSetStatusProgress(viewer_struct *v, gfloat percent)
 	    GtkAdjustment *adj = GTK_PROGRESS(w)->adjustment;
 	
 	    percent = gtk_progress_get_value(GTK_PROGRESS(w)) + 1;
-	 
 	    if(percent > adj->upper)
 		percent = adj->lower;
-	    
+
 	    gtk_progress_set_activity_mode(
-		GTK_PROGRESS(w), TRUE  
+		GTK_PROGRESS(w), TRUE
 	    );
 	    gtk_progress_set_value(GTK_PROGRESS(w), percent);
-	
-	    /* Itterate through GTK main function until all events are
-	     * handled so that we ensure this progress bar setting is
-	     * updated.
-	     */
+
 	    while(gtk_events_pending() > 0)
 		gtk_main_iteration();
-	
+
 	    return;
 	}
 
-	if(percent > 1.0)
-	    percent = 1.0;
+	if(percent > 1.0f)
+	    percent = 1.0f;
 
 	gtk_progress_set_format_string(
 	    GTK_PROGRESS(w), "%p%%"
@@ -2671,7 +2631,7 @@ void ViewerSetStatusProgress(viewer_struct *v, gfloat percent)
 	if(p > percent)
 	    p = percent;
 
-	while(1)
+	while(TRUE)
 	{
 	    if(p > percent)
 		p = percent;
@@ -2680,15 +2640,11 @@ void ViewerSetStatusProgress(viewer_struct *v, gfloat percent)
 		GTK_PROGRESS_BAR(w), p
 	    );
 
-	    /* Itterate through GTK main function until all events are
-	     * handled so that we ensure this progress bar setting is
-	     * updated.
-	     */
 	    while(gtk_events_pending() > 0)
 		gtk_main_iteration();
 
 	    if(p < percent)
-		p += (gfloat)0.05;
+		p += 0.05f;
 	    else
 		break;
 	}
@@ -2716,7 +2672,7 @@ void ViewerRecordPositions(viewer_struct *v)
 	if(v->processing)
 	    return;
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
+	core_ptr = MEDIT_CORE(v->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
@@ -2743,7 +2699,7 @@ void ViewerRecordPositions(viewer_struct *v)
 	    if(v->last_open_path != NULL)
 	    {
 		g_free(pref->last_opened_manage_view_path);
-		pref->last_opened_manage_view_path = strdup(
+		pref->last_opened_manage_view_path = g_strdup(
 		    v->last_open_path
 		);
 	    }
@@ -2751,7 +2707,7 @@ void ViewerRecordPositions(viewer_struct *v)
 }
 
 /*
- *	Resets all values to defaults on viewer and deallocates
+ *	Resets all values to defaults on viewer and deletes
  *	undo/redo list and all layout branches.
  */
 void ViewerReset(viewer_struct *v, gboolean need_unmap)
@@ -2775,7 +2731,7 @@ void ViewerReset(viewer_struct *v, gboolean need_unmap)
 	if(v->processing)
 	    return;
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
+	core_ptr = MEDIT_CORE(v->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
@@ -2877,7 +2833,7 @@ void ViewerReset(viewer_struct *v, gboolean need_unmap)
 	)
 	{
 	    g_free(v->last_open_path);
-	    v->last_open_path = strdup(pref->last_opened_manage_view_path);
+	    v->last_open_path = g_strdup(pref->last_opened_manage_view_path);
 	}
 
 	/* Reset status messages */
@@ -2949,7 +2905,7 @@ void ViewerUnmap(viewer_struct *v)
 /*
  *	Destroys the viewer and all its widgets and allocated resources.
  *
- *	The viewer structure itself will also be deallocated.
+ *	The viewer structure itself will also be deleted.
  */
 void ViewerDelete(viewer_struct *v)
 {
@@ -2966,7 +2922,7 @@ void ViewerDelete(viewer_struct *v)
 		return;
 
 	    /* Reset values to defaults, this will cause any loaded data
-	     * to be deallocated.
+	     * to be deleted.
 	     */
 	    ViewerReset(v, TRUE);
 
