@@ -13,75 +13,76 @@
 
 
 /*
- *	Viewer index ctree index item structure:
+ *	Viewer Index GtkCTree Item:
  */
 typedef struct {
 
-#define ViewerIndexItemTypeDirectory	0
-#define ViewerIndexItemTypeManualPage	1
-#define ViewerIndexItemTypeOtherFile	2
+#define ViewerIndexItemTypeDirectory		0
+#define ViewerIndexItemTypeManualPage		1
+#define ViewerIndexItemTypeOtherFile		2
 
-	gint type;	/* One of ViewerIndexItemType*. */
+	gint		type;	/* One of ViewerIndexItemType* */
 
-	gchar *file_name_full;
+	gchar		*file_name_full;
 
 } viewer_index_item_struct;
+#define VIEWER_INDEX_ITEM(p)	((viewer_index_item_struct *)(p))
+
 
 /*
- *	Viewer structure:
+ *	Viewer:
  */
 typedef struct {
 
 	gboolean	initialized,
 			map_state,
 			processing;
-	gint stop_count;
+	gint		stop_count;
 
-	gpointer core_ptr;	/* Pointer back to core. */
-	gint editor_num;	/* Editor number on core struct that called
-				 * this viewer, can be -1 for none.
-				 */
+	gpointer	core_ptr;	/* Pointer back to core */
+	gint		editor_num;	/* Editor number on core struct that
+					 * called this viewer, can be -1 for
+					 * none */
 
-	GtkWidget *toplevel;
-	GtkWidget *main_vbox;
-
-        GtkWidget *menu_bar_dock, *menu_bar;
-        GtkWidget *tool_bar_dock, *tool_bar;
-
-	GtkWidget *main_notebook;
+	GtkWidget	*toplevel,
+			*main_vbox,
+			*menu_bar_dock,
+			*menu_bar,
+			*tool_bar_dock,
+			*tool_bar,
+			*main_notebook;
 
 	/* Currently selected page on main_notebook, can be one of
-	 * ViewerPageNum*.
-	 */
-#define ViewerPageNumView	0
-#define ViewerPageNumIndex	1
-#define ViewerPageNumSearch	2
-	gint current_page;
+	 * ViewerPageNum* */
+#define ViewerPageNumView		0
+#define ViewerPageNumIndex		1
+#define ViewerPageNumSearch		2
+	gint		current_page;
 
-	/* GtkText widget which displays current manual page contents. */
-	GtkWidget *view_text;
+	/* GtkText widget which displays current manual page contents */
+	GtkWidget	*view_text;
 
 	/* Index listing of available manual pages, each branch has
 	 * an item data of type viewer_index_item_struct.
 	 * There are 4 columns; name, lines, read, short description
 	 */
-	GtkWidget *index_ctree;
+	GtkWidget	*index_ctree;
 
-	/* Selected branch on index_ctree, can be NULL. */
-	GtkCTreeNode *selected_index_branch;
+	/* Selected branch on index_ctree, can be NULL */
+	GtkCTreeNode	*selected_index_branch;
 
-	/* Buttons on index ctree page. */
+	/* Buttons on index ctree page */
 	GtkWidget	*index_parent_btn,
 			*index_goto_btn,
 			*index_refresh_btn,
 			*index_find_in_pages_combo;
 
-	/* Combos on manpage view panel. */
+	/* Combos on manpage view panel */
 	GtkWidget	*manpage_combo,
 			*section_combo,
 			*find_combo;
 
-	/* Important menu items. */
+	/* Important menu items */
 	GtkWidget	*file_mh,
 			*open_mi,
 			*clear_mi,
@@ -99,18 +100,18 @@ typedef struct {
 			*windows_new_editor,
 			*windows_new_viewer;
 
-	/* Tool bar buttons. */
+	/* Tool bar buttons */
 	GtkWidget	*open_btn,
 			*clear_btn,
 			*stop_btn;
 
 
-	/* Right click menu over view_text. */
+	/* Right click menu over view_text */
 	GtkWidget	*view_menu,
 			*view_open_mi,
 			*view_clear_mi;
 
-	/* Right click menu over index_ctree. */
+	/* Right click menu over index_ctree */
 	GtkWidget	*index_menu,
 			*index_expand_mi,
 			*index_parent_mi,
@@ -118,38 +119,38 @@ typedef struct {
 			*index_refresh_mi,
 			*index_stop_mi;
 
-        /* Status bar. */
+        /* Status bar */
         GtkWidget       *status_bar_dock,
-                        *status_bar_toplevel,   /* An hbox. */
+                        *status_bar_toplevel,   /* An hbox */
                         *status_bar_progress,
                         *status_bar_label,
                         *status_bar_cursor_label;
 
-	/* Last progress position value from 0.0 to 1.0. */
-	gfloat status_bar_progress_pos_last;
+	/* Last progress position value from 0.0 to 1.0 */
+	gfloat		status_bar_progress_pos_last;
 
-	/* Currently loaded manual page path (if any). */
-	gchar *cur_manpage_path;
+	/* Currently loaded manual page path (if any) */
+	gchar		*cur_manpage_path;
 
 	/* Name of current manpage, this is to match up to see if
 	 * newly loaded manpage is the same. Note that this is not
 	 * the file name, rather it should be the name from the
-	 * manual page's header.
-	 */
-	gchar *cur_manpage_name;
+	 * manual page's header */
+	gchar		*cur_manpage_name;
 
-	/* Last scroll positions. */
-	gfloat	last_scroll_hpos,	/* Not used. */
-		last_scroll_vpos;
+	/* Last scroll positions */
+	gfloat		last_scroll_hpos,	/* Not used */
+			last_scroll_vpos;
 
-	/* Last manual page output file opened path. */
-	gchar *last_open_path;
+	/* Last manual page output file opened path */
+	gchar		*last_open_path;
 
 } viewer_struct;
+#define VIEWER(p)	((viewer_struct *)(p))
 
 
 extern viewer_index_item_struct *ViewerIndexItemNew(
-	gint type,	/* One of ViewerIndexItemType*. */
+	gint type,	/* One of ViewerIndexItemType* */
 	const char *file_name_full
 );
 extern void ViewerIndexItemDelete(viewer_index_item_struct *item_ptr);
@@ -165,8 +166,7 @@ extern void ViewerTextInsert(
 extern void ViewerTextDelete(viewer_struct *v, gint start_pos, gint end_pos); 
 extern void ViewerIndexDoLoad(
         viewer_struct *v,
-        const gchar **path, gint total_paths,
-	const gchar **name
+	gint total_paths, char **path, gchar **name
 );
 
 extern gboolean ViewerDoFind(
