@@ -1,10 +1,6 @@
-#include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <ctype.h>
 
-#include <sys/types.h>
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -60,15 +56,15 @@ gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data);
 
 void ViewerManPageActivateCB(GtkWidget *widget, void *data);
 static void ViewerDoFindCB(
-	viewer_struct *v, GtkCombo *find_combo, gbool case_sensitive
+	viewer_struct *v, GtkCombo *find_combo, gboolean case_sensitive
 );
 void ViewerFindActivateCB(GtkWidget *widget, void *data);
 
-static gbool ViewerFindInPagesDoGrep(
-	const gchar *path, gchar *expression, gbool case_sensitive
+static gboolean ViewerFindInPagesDoGrep(
+	const gchar *path, gchar *expression, gboolean case_sensitive
 );
 static void ViewerDoFindInPagesCB(
-	viewer_struct *v, GtkCombo *find_combo, gbool case_sensitive
+	viewer_struct *v, GtkCombo *find_combo, gboolean case_sensitive
 );
 void ViewerFindInPagesActivateCB(GtkWidget *widget, void *data);
 
@@ -99,13 +95,11 @@ void ViewerTextChangeCB(GtkEditable *editable, gpointer data);
  */
 void ViewerIndexBranchDestroyCB(gpointer data)
 {
-	viewer_index_item_struct *item_ptr = (viewer_index_item_struct *)data;
+	viewer_index_item_struct *item_ptr = VIEWER_INDEX_ITEM(data);
 	if(item_ptr == NULL)
 	    return;
 
 	ViewerIndexItemDelete(item_ptr);
-
-	return;
 }
 
 /*
@@ -113,7 +107,7 @@ void ViewerIndexBranchDestroyCB(gpointer data)
  */
 void ViewerDestroyCB(GtkObject *object, gpointer data)
 {
-	return;
+
 }
 
 /*
@@ -121,8 +115,8 @@ void ViewerDestroyCB(GtkObject *object, gpointer data)
  */
 gint ViewerCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
-	static gbool reenterant = FALSE;
-	viewer_struct *v = (viewer_struct *)data;
+	static gboolean reenterant = FALSE;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return(TRUE);
 
@@ -134,7 +128,7 @@ gint ViewerCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 	else
 	    reenterant = TRUE;
 
-	/* Check if currently processing. */
+	/* Check if currently processing */
 	if(v->processing)
 	{
 	    reenterant = FALSE;
@@ -142,10 +136,10 @@ gint ViewerCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 	}
 
 
-	/* Revord viewer positions and sizes. */
+	/* Revord viewer positions and sizes */
 	ViewerRecordPositions(v);
 
-	/* Reset and unmap viewer. */
+	/* Reset and unmap viewer */
 	ViewerReset(v, TRUE);
 
 	reenterant = FALSE;
@@ -185,9 +179,9 @@ void ViewerSwitchPageCB(
 	gpointer data
 )
 {
-	static gbool reenterant = FALSE;
+	static gboolean reenterant = FALSE;
 	GtkWidget *w;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if((notebook == NULL) || (v == NULL))
 	    return;
 
@@ -229,9 +223,9 @@ void ViewerSwitchPageCB(
  */
 void ViewerPageToggleCB(GtkWidget *widget, gpointer data)
 {
-	static gbool reenterant = FALSE;
+	static gboolean reenterant = FALSE;
 	GtkWidget *w;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL))
 	    return;
 
@@ -275,7 +269,7 @@ void ViewerPageToggleCB(GtkWidget *widget, gpointer data)
 gint ViewerPageChangedTOCB(gpointer data)
 {
 	GtkCTree *ctree;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return(FALSE);
 
@@ -316,13 +310,13 @@ gint ViewerViewKeyEventCB(
 	GtkWidget *w;
 	GtkText *text;
 	GtkAdjustment *hadj, *vadj;
-	gbool state;
+	gboolean state;
 	guint keyval;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL) || (key == NULL))
 	    return(FALSE);
 
-	/* Get pointer to view_text widget, event widget must be it. */
+	/* Get pointer to view_text widget, event widget must be it */
 	w = v->view_text;
 	if(w != widget)
 	    return(FALSE);
@@ -331,7 +325,7 @@ gint ViewerViewKeyEventCB(
 	hadj = text->hadj;
 	vadj = text->vadj;
 	keyval = key->keyval;
-	state = (((*(int *)key) == GDK_KEY_PRESS) ? TRUE : FALSE);
+	state = (((*(gint *)key) == GDK_KEY_PRESS) ? TRUE : FALSE);
 
 	/* Important, for some obscure reason the GtkText widget
 	 * when set not editable and recieving a key event to insert
@@ -347,7 +341,7 @@ gint ViewerViewKeyEventCB(
 	else
 	    gtk_editable_set_editable(GTK_EDITABLE(w), FALSE);
 
-	/* Home, scroll all the way back up. */
+	/* Home, scroll all the way back up */
 	if(keyval == GDK_Home)
 	{
 	    if(state)
@@ -360,7 +354,7 @@ gint ViewerViewKeyEventCB(
  */
 	    }
 	}
-	/* End, scroll to the end. */
+	/* End, scroll to the end */
 	else if(keyval == GDK_End)
 	{
 	    if(state)
@@ -373,7 +367,7 @@ gint ViewerViewKeyEventCB(
  */
 	    }
 	}
-	/* Space or enter, scroll one page down. */
+	/* Space or enter, scroll one page down */
 	else if((keyval == GDK_Return) ||
 	        (keyval == ' ') || (keyval == 'n')
 	)
@@ -386,7 +380,7 @@ gint ViewerViewKeyEventCB(
 		gtk_adjustment_value_changed(vadj);
 	    }
 	}
-	/* Backspace or 'b', scroll one page up. */
+	/* Backspace or 'b', scroll one page up */
 	else if((keyval == GDK_BackSpace) ||
 		(keyval == 'b') || (keyval == 'p')
 	)
@@ -418,7 +412,7 @@ void ViewerIndexBranchExpandCB(GtkWidget *widget, gpointer data)
 	GtkCTree *ctree;
 	GtkCTreeNode *branch;
 	GtkCTreeRow *branch_row;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
@@ -454,18 +448,18 @@ void ViewerIndexBranchExpandCB(GtkWidget *widget, gpointer data)
  */
 void ViewerOpenCB(GtkWidget *widget, gpointer data)
 {
-	int status;
+	gint status;
 	medit_core_struct *core_ptr;
 	medit_fetype_list_struct *fetype_list;
 	GtkText *text;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
 	if(!v->initialized)
 	    return;
 
-	/* Check if currently processing. */
+	/* Check if currently processing */
 	if(v->processing)
 	    return;
 
@@ -479,15 +473,13 @@ void ViewerOpenCB(GtkWidget *widget, gpointer data)
 
 	fetype_list = &core_ptr->fetype_list;
 
-	if(1)
+	if(TRUE)
 	{
-	    char **path_rtn;
-	    int path_total_rtns;
+	    gchar *s, **path_rtn;
+	    gint path_total_rtns;
 	    fb_type_struct *type_rtn;
-	    char *tmp_buf;
-	    int tmp_buf_len;
 
-	    /* Map file browser for opening of manual page output. */
+	    /* Map file browser for opening of manual page output */
 	    if(FileBrowserGetResponse(
 		"Open Manual Page File",
 		"Open", "Cancel",
@@ -500,7 +492,7 @@ void ViewerOpenCB(GtkWidget *widget, gpointer data)
 		if(path_total_rtns > 0)
 		{
 		    ViewerSetBusy(v);
-/* Reset scroll positions when user is calling open callback. */
+/* Reset scroll positions when user is calling open callback */
 		    v->last_scroll_hpos = 0.0;
 		    v->last_scroll_vpos = 0.0;
 /*		    ViewerViewTextRecordScrollPositions(v); */
@@ -512,21 +504,18 @@ void ViewerOpenCB(GtkWidget *widget, gpointer data)
 		    switch(status)
 		    {
 		      case 0:
-			/* Success. */
+			/* Success */
 			break;
 
-		      /* No such file. */
+		      /* No such file */
 		      case -2:
-			tmp_buf_len = 256 + strlen(path_rtn[0]);
-			tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-			if(tmp_buf != NULL)
-			    sprintf(tmp_buf,
-"Could not find the manual page file\n`%s'",
-				path_rtn[0]
-			    );
+			s = g_strdup_printf(
+"Could not find the manual page file:\n\n    %s",
+			    path_rtn[0]
+			);
 			CDialogGetResponse(
 			    "Manual page not found!",
-			    tmp_buf,
+			    s,
 "The specified manual page file could not be found\n\
 please verify that the given path exists and has\n\
 read permissions set.",
@@ -534,10 +523,10 @@ read permissions set.",
 			    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 			    CDIALOG_BTNFLAG_OK
 			);
-			free(tmp_buf);  /* Deallocate message buffer. */
+			g_free(s);
 			break;   
 		       
-		      /* Other error. */
+		      /* Other error */
 		      default:
 			CDialogGetResponse(
 "Manual page opening error!",
@@ -552,25 +541,21 @@ read permissions set.",
 		}
 		else
 		{
-		    /* Did not get any paths, abort entire open
-		     * procedure.
-		     */
+		    /* Did not get any paths, abort open */
 		    return;
 		}
 	    }
 	    else
 	    {
-		/* User canceled save as, abort entire open procedure. */
+		/* User canceled save as, abort entire open procedure */
 		return;
 	    }
 	}
 
 	/* Update menus, note that a successful load may have updated
-	 * menus already but it is safe to do it again here.
+	 * menus already but it is safe to do it again here
 	 */
 	ViewerUpdateMenus(v);
-
-	return;
 }
 
 
@@ -582,7 +567,7 @@ void ViewerClearCB(GtkWidget *widget, gpointer data)
 	GtkCTreeNode *branch, *prev_branch;
 	GtkCTreeRow *branch_row;
 	GtkCTree *ctree;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
@@ -605,21 +590,21 @@ void ViewerClearCB(GtkWidget *widget, gpointer data)
 	  case ViewerPageNumIndex:
 	    ctree = (GtkCTree *)v->index_ctree;
 
-	    /* Remove all branches on index ctree. */
+	    /* Remove all branches on index ctree */
 	    gtk_clist_freeze((GtkCList *)ctree);
 	    branch = gtk_ctree_node_nth(ctree, 0);
 	    while(branch != NULL)
 	    {
-		prev_branch = branch;	/* Record current branch. */
+		prev_branch = branch;	/* Record current branch */
 
-		/* Get branch row data. */
+		/* Get branch row data */
 		branch_row = GTK_CTREE_ROW(branch);
-		/* Get next sibling branch. */
+		/* Get next sibling branch */
 		branch = ((branch_row == NULL) ?
 		    NULL : branch_row->sibling
 		);
 
-		/* Remove current branch. */
+		/* Remove current branch */
 		gtk_ctree_remove_node(ctree, prev_branch);
 	    }
 	    gtk_clist_thaw((GtkCList *)ctree);
@@ -638,7 +623,7 @@ void ViewerClearCB(GtkWidget *widget, gpointer data)
  */
 void ViewerStopCB(GtkWidget *widget, gpointer data)
 {
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
@@ -657,7 +642,7 @@ void ViewerIndexGotoParentCB(GtkWidget *widget, gpointer data)
 	GtkCTree *ctree;
 	GtkCTreeNode *branch;
 	GtkCTreeRow *branch_row;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
@@ -671,7 +656,7 @@ void ViewerIndexGotoParentCB(GtkWidget *widget, gpointer data)
 	if(ctree == NULL)
 	    return;
 
-	/* Get selected branch. */
+	/* Get selected branch */
 	branch = v->selected_index_branch;
 	if(branch == NULL)
 	    return;
@@ -695,7 +680,7 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
 	GtkCTree *ctree;
 	GtkCTreeNode *branch;
 	viewer_index_item_struct *item_ptr;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
@@ -709,13 +694,13 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
 	if(ctree == NULL)
 	    return;
 
-	/* Get selected branch. */
+	/* Get selected branch */
 	branch = v->selected_index_branch;
 	if(branch == NULL)
 	    return;
 
-	item_ptr = (viewer_index_item_struct *)gtk_ctree_node_get_row_data(
-	    ctree, branch
+	item_ptr = VIEWER_INDEX_ITEM(
+	    gtk_ctree_node_get_row_data(ctree, branch)
 	);
 	if(item_ptr == NULL)
 	    return;
@@ -734,8 +719,6 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
 		ViewerSetReady(v);
 	    }
 	}
-
-	return;
 }
 
 
@@ -744,16 +727,16 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
  */
 void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 {
-	int i;
-	char **path = NULL;
-	char **name = NULL;
-	int total_paths = 0;
+	gint i;
+	gchar **path = NULL;
+	gchar **name = NULL;
+	gint total_paths = 0;
 	GtkCTree *ctree;
 	GtkWidget *w;
 	GtkCTreeNode *branch, *prev_branch;
 	GtkCTreeRow *branch_row;
 	medit_core_struct *core_ptr;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
@@ -767,19 +750,19 @@ void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 	if(core_ptr == NULL)
 	    return;
 
-	/* Get pointer to viewer's index ctree. */
+	/* Get pointer to viewer's index ctree */
 	ctree = (GtkCTree *)v->index_ctree;
 	if(ctree == NULL)
 	    return;
 
-	/* Get pointer to pref global manpage dirs clist. */
+	/* Get pointer to pref global manpage dirs clist */
 	w = PrefParmGetWidget(
 	    core_ptr->pref,
 	    MEDIT_PREF_PARM_LOCATIONS_MAN_DIRS
 	);
 	if(w != NULL)
 	{
-	    /* Make list of paths and names to load. */
+	    /* Make list of paths and names to load */
 	    GtkCList *paths_clist = (GtkCList *)w;
 
 	    total_paths = paths_clist->rows;
@@ -787,8 +770,12 @@ void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 	    {
 		gchar *path_ptr, *name_ptr;
 
-		path = (char **)calloc(total_paths, sizeof(char *));
-		name = (char **)calloc(total_paths, sizeof(char *));
+		path = (gchar **)g_malloc0(
+		    total_paths * sizeof(gchar *)
+		);
+		name = (gchar **)g_malloc0(
+		    total_paths * sizeof(gchar *)
+		);
 		if((path != NULL) && (name != NULL))
 		{
 		    for(i = 0; i < total_paths; i++)
@@ -805,47 +792,40 @@ void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 			))
 			    name_ptr = NULL;
 
-			path[i] = ((path_ptr == NULL) ?
-			    NULL : strdup(path_ptr)
-			);
-			name[i] = ((name_ptr == NULL) ?
-			    NULL : strdup(name_ptr) 
-			);
+			path[i] = (path_ptr != NULL) ?
+			    g_strdup(path_ptr) : NULL;
+			name[i] = (name_ptr != NULL) ?
+			    g_strdup(name_ptr) : NULL;
 		    }
 		}
 	    }
 	}
 
-	/* Remove all existing branches on index ctree. */
+	/* Remove all existing branches on index ctree */
 	gtk_clist_freeze((GtkCList *)ctree);
 	branch = gtk_ctree_node_nth(ctree, 0);
 	while(branch != NULL)
 	{
-	    prev_branch = branch;	/* Record current branch. */
+	    prev_branch = branch;	/* Record current branch */
 
-	    /* Get branch row data. */
+	    /* Get branch row data */
 	    branch_row = GTK_CTREE_ROW(branch);
-	    /* Get next sibling branch. */
+	    /* Get next sibling branch */
 	    branch = ((branch_row == NULL) ? NULL : branch_row->sibling);
 
-	    /* Remove current branch. */
+	    /* Remove current branch */
 	    gtk_ctree_remove_node(ctree, prev_branch);
 	}
 	gtk_clist_thaw((GtkCList *)ctree);
 
-	/* Load new objects from paths. */
+	/* Load new objects from paths */
 	ViewerIndexDoLoad(
-	    v, (const char **)path, total_paths, (const char **)name
+	    v, total_paths, path, name
 	);
 
-	/* Deallocate paths and names array. */
+	/* Delete paths and names array */
 	strlistfree(path, total_paths);
 	strlistfree(name, total_paths);
-	path = NULL;
-	name = NULL;
-	total_paths = 0;
-
-	return;
 }  
 
 /*
@@ -854,32 +834,31 @@ void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 void ViewerPreferencesCB(GtkWidget *widget, gpointer data)
 {
 	medit_core_struct *core_ptr;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL))
 	    return;
 
 	core_ptr = (medit_core_struct *)v->core_ptr;
 	if(core_ptr != NULL)
 	{
-	    pref_struct *pref = core_ptr->pref;
+	    gchar *s;
 	    GtkCTreeNode *branch;
 	    GtkCTreeRow *branch_row;
 	    GtkCTree *ctree;
-	    char *strptr;
+	    pref_struct *pref = core_ptr->pref;
 
-	    ctree = (GtkCTree *)((pref == NULL) ?
-		NULL : pref->catagory_ctree
-	    ); 
+	    ctree = (pref != NULL) ?
+		(GtkCTree *)pref->catagory_ctree : NULL;
 	    if(ctree != NULL)
 	    {
 		branch = gtk_ctree_node_nth(ctree, 0);
  
 		while(branch != NULL)
 		{
-		    strptr = PrefPanelGetBranchText(pref, branch);
-		    if(strptr != NULL)
+		    s = PrefPanelGetBranchText(pref, branch);
+		    if(s != NULL)
 		    {
-			if(!strcasecmp(strptr, "Viewer"))
+			if(!g_strcasecmp(s, "Viewer"))
 			{
 			    gtk_ctree_expand(ctree, branch);
 			    gtk_ctree_select(ctree, branch);
@@ -888,17 +867,14 @@ void ViewerPreferencesCB(GtkWidget *widget, gpointer data)
 		    }
 	
 		    branch_row = GTK_CTREE_ROW(branch);
-		    branch = ((branch_row == NULL) ?
-			NULL : branch_row->sibling
-		    );
+		    branch = (branch_row != NULL) ?
+			branch_row->sibling : NULL;
 		}
 
 		PrefDoFetch(pref);
 		PrefMap(pref);
 	    }
 	}
-
-	return;
 }
 
 
@@ -907,10 +883,10 @@ void ViewerPreferencesCB(GtkWidget *widget, gpointer data)
  */
 gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
-	static gbool reenterant = FALSE;
+	static gboolean reenterant = FALSE;
 	GtkWidget *w;
 	GdkEventButton *button;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if((v == NULL) || (event == NULL) || (widget == NULL))
 	    return(TRUE);
 
@@ -935,7 +911,7 @@ gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 	    {
 		if(button->button == 3)
 		{
-		    /* Map menu. */
+		    /* Map menu */
 		    gtk_menu_popup(
 			GTK_MENU(w),
 			NULL, NULL, NULL, (gpointer)v,
@@ -950,7 +926,7 @@ gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 		}
 	    }
 	}
-	/* Index ctree. */
+	/* Index ctree */
 	else if (widget == v->index_ctree)
 	{
 	    w = v->index_menu;
@@ -983,7 +959,7 @@ gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 			}
 		    }
 
-		    /* Map menu. */
+		    /* Map menu */
 		    gtk_menu_popup(
 			GTK_MENU(w),
 			NULL, NULL, NULL, (gpointer)v,
@@ -1008,18 +984,15 @@ gint ViewerMenuMapCB(GtkWidget *widget, GdkEvent *event, gpointer data)
  */
 void ViewerManPageActivateCB(GtkWidget *widget, void *data)
 {
-	static gbool reenterant = FALSE;
-	int section = -2;	/* Any. */
-	char *search_string, *name, *tmp_str;
+	static gboolean reenterant = FALSE;
+	gint section = -2;	/* Any */
+	gchar *s, *name, *search_string;
 	GtkCombo *combo;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
-	if(!v->initialized)
-	    return;
-
-	if(v->processing)
+	if(!v->initialized || v->processing)
 	    return;
 
 	if(reenterant)
@@ -1027,7 +1000,7 @@ void ViewerManPageActivateCB(GtkWidget *widget, void *data)
 	else
 	    reenterant = TRUE;
 
-	/* Get manpage combo. */
+	/* Get manpage combo */
 	combo = (GtkCombo *)v->manpage_combo;
 	if(combo == NULL)
 	{
@@ -1035,7 +1008,7 @@ void ViewerManPageActivateCB(GtkWidget *widget, void *data)
 	    return;
 	}
 
-	/* Get category if any. */
+	/* Get category if any */
 	if(v->section_combo != NULL)
 	{
 	    GtkCombo *section_combo = (GtkCombo *)v->section_combo;
@@ -1051,80 +1024,80 @@ void ViewerManPageActivateCB(GtkWidget *widget, void *data)
 		{
 		    section = atoi(section_str);
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_1))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_1))
 		{
 		    section = 1;
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_2))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_2))
 		{
 		    section = 2;
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_3))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_3))
 		{
 		    section = 3;
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_4))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_4))
 		{
 		    section = 4;
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_5))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_5))
 		{
 		    section = 5;
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_6))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_6))
 		{
 		    section = 6;
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_7))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_7))
 		{
 		    section = 7;
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_8))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_8))
 		{
 		    section = 8;
 		}
-		else if(!strcasecmp(section_str, MEDIT_SECT_NAME_EXACT))
+		else if(!g_strcasecmp(section_str, MEDIT_SECT_NAME_EXACT))
 		{
 		    section = -1;
 		}
 		else
 		{
-		    /* All else assume any (-2). */
+		    /* All else assume any (-2) */
 		}
 	    }
 	}
 
 
-	/* Get search string and make a copy of it. */
+	/* Get search string and make a copy of it */
 	search_string = gtk_entry_get_text(
 	    GTK_ENTRY(combo->entry)
 	);
 	if(search_string != NULL)
-	    search_string = strdup(search_string);
+	    search_string = g_strdup(search_string);
 
-	/* Get name, which is just the search string at this point. */
+	/* Get name, which is just the search string at this point */
 	if(search_string != NULL)
-	    name = strdup(search_string);
+	    name = g_strdup(search_string);
 	else
 	    name = NULL;
 
-	/* Check if search string is empty. */
+	/* Check if search string is empty */
 	if((*search_string) == '\0')
 	{
-	    free(search_string);
-	    free(name);
+	    g_free(search_string);
+	    g_free(name);
 	    reenterant = FALSE;
 	    return;
 	}
 
-	/* Add section to beginning of search string. */
+	/* Add section to beginning of search string */
 	switch(section)
 	{
 	  case -1:
 	    /* For exact matches, make sure search_string starts with
-	     * a full path.
+	     * a full path
 	     */
-	    if((*search_string) != DIR_DELIMINATOR)
+	    if(*search_string != G_DIR_SEPARATOR)
 	    {
 		CDialogGetResponse(
 "Invalid path!",
@@ -1138,8 +1111,8 @@ matches.",
 		    CDIALOG_BTNFLAG_OK
 		);
 
-		free(search_string);
-		free(name);
+		g_free(search_string);
+		g_free(name);
 		reenterant = FALSE;
 		return;
 	    }
@@ -1149,20 +1122,19 @@ matches.",
 	    break;
 
 	  default:
-	    tmp_str = search_string;
-
-	    search_string = (char *)malloc((256 + 1) * sizeof(char));
-	    if(search_string != NULL)
-		sprintf(search_string, "%i ", section);
-	    search_string = strcatalloc(search_string, tmp_str);
-
-	    free(tmp_str);
+	    /* Prepend section to the search string */
+	    s = g_strdup_printf(
+		"%i %s",
+		section, search_string
+	    );
+	    g_free(search_string);
+	    search_string = s;
 	    break;
 	}
 
 	/* Call load file procedure, this will run the conversion
 	 * program with the given search string and output any
-	 * matched results.
+	 * matched results
 	 */
 	ViewerSetBusy(v);
 	ViewerViewTextRecordScrollPositions(v);
@@ -1171,16 +1143,12 @@ matches.",
 	ViewerLoadFile(v, search_string, name);
 	ViewerSetReady(v);
 
-	/* Free coppied search string. */
-	free(search_string);
-	search_string = NULL;
-	free(name);
-	name = NULL;
+	g_free(search_string);
+	g_free(name);
 
 	ViewerSetStatusMessage(v, "Search done");
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
@@ -1188,46 +1156,43 @@ matches.",
  *	page on the viewer page.
  */
 static void ViewerDoFindCB(
-	viewer_struct *v, GtkCombo *find_combo, gbool case_sensitive
+	viewer_struct *v, GtkCombo *find_combo, gboolean case_sensitive
 )
 {
-	gbool got_match, search_wrapped;
+	gboolean got_match, search_wrapped;
 	GtkText *text; 
 	GtkEditable *editable;
 	gint start_pos;
-	gchar *strptr, *haystack = NULL, *needle = NULL;
+	gchar *s, *haystack = NULL, *needle = NULL;
 
 
 	if((v == NULL) || (find_combo == NULL))
 	    return;
 
-	/* Get pointer to view text. */
+	/* Get pointer to view text */
 	text = (GtkText *)v->view_text;
 	if(text == NULL)
 	    return;
 	else
 	    editable = GTK_EDITABLE(text);
 
-	/* Get needle buffer (coppied). */
-	strptr = gtk_entry_get_text(GTK_ENTRY(find_combo->entry));
-	if(strptr != NULL)
-	    needle = strdup(strptr);
-	else
-	    needle = NULL;
+	/* Get needle buffer (coppied) */
+	s = gtk_entry_get_text(GTK_ENTRY(find_combo->entry));
+	needle = (s != NULL) ? g_strdup(s) : NULL;
 
-	/* Get haystack from text. */
+	/* Get haystack from text */
 	haystack = gtk_editable_get_chars(editable, 0, -1);
 
-	/* Set starting position plus one. */
+	/* Set starting position plus one */
 	start_pos = gtk_editable_get_position(editable) + 1;
 
-	/* Do find. */
+	/* Do find */
 	got_match = ViewerDoFind(
 	    v, text,
 	    haystack, needle,
-	    (int)gtk_text_get_length(text), start_pos,
+	    (gint)gtk_text_get_length(text), start_pos,
 	    case_sensitive,
-	    TRUE,                   /* Scroll to matched position. */
+	    TRUE,                   /* Scroll to matched position */
 	    &search_wrapped
 	);
 	/* Did we get a match? */
@@ -1260,7 +1225,6 @@ does not exist in the text.",
 	    );
 	}
 
-	/* Deallocate find buffers. */
 	g_free(haystack);
 	g_free(needle);
 }
@@ -1270,7 +1234,7 @@ does not exist in the text.",
  */
 void ViewerFindActivateCB(GtkWidget *widget, void *data)  
 {
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
@@ -1293,21 +1257,21 @@ void ViewerFindActivateCB(GtkWidget *widget, void *data)
  *	Checks if the string given by needle exists in the contents of
  *	the file given by path.
  */
-static gbool ViewerFindInPagesDoGrep(
-	const gchar *path, gchar *expression, gbool case_sensitive
+static gboolean ViewerFindInPagesDoGrep(
+	const gchar *path, gchar *expression, gboolean case_sensitive
 )
 {
-	gbool got_match;
-	glong last_line_start_pos = 0;
-	const gchar *expression_ptr;
+	gboolean got_match;
 	gint c;
+	glong last_line_start_pos = 0l;
+	const gchar *expression_ptr;
 	FILE *fp;
 
 
 	if((path == NULL) || (expression == NULL))
 	    return(FALSE);
 
-	/* Open file for reading. */
+	/* Open file for reading */
 	fp = FOpen(path, "rb");
 	if(fp == NULL)
 	    return(FALSE);
@@ -1315,9 +1279,9 @@ static gbool ViewerFindInPagesDoGrep(
 	got_match = FALSE;
 	expression_ptr = expression;
 
-	while(1)
+	while(TRUE)
 	{
-	    /* Get next character. */
+	    /* Get next character */
 	    c = fgetc(fp);
 	    if(c == EOF)
 		break;
@@ -1327,7 +1291,7 @@ static gbool ViewerFindInPagesDoGrep(
 
 	    /* If this character marks the end of the line then record
 	     * the last line starting position as one character ahead
-	     * of the current position.
+	     * of the current position
 	     */
 	    if(ISCR(c))
 		last_line_start_pos = ftell(fp);
@@ -1335,7 +1299,7 @@ static gbool ViewerFindInPagesDoGrep(
 	    /* This character matches current character of expression?
 	     * If so then increment the expression pointer. Otherwise
 	     * reset the expression pointer back to the start of the
-	     * expression.
+	     * expression
 	     */
 	    if((c == *expression_ptr) && (c != '\0'))
 		expression_ptr++;
@@ -1345,7 +1309,7 @@ static gbool ViewerFindInPagesDoGrep(
 	    /* Matched entire expression? Test if the expression pointer
 	     * has been incremented all the way to the null terminating
 	     * character which suggests that all characters in the
-	     * expression were matched.
+	     * expression were matched
 	     */
 	    if(*expression_ptr == '\0')
 	    {
@@ -1354,7 +1318,7 @@ static gbool ViewerFindInPagesDoGrep(
 	    }
 	}
 
-	/* Close file. */
+	/* Close file */
 	FClose(fp);
 
 	return(got_match);
@@ -1365,31 +1329,30 @@ static gbool ViewerFindInPagesDoGrep(
  *	on the index ctree.
  */
 static void ViewerDoFindInPagesCB(
-	viewer_struct *v, GtkCombo *find_combo, gbool case_sensitive
+	viewer_struct *v, GtkCombo *find_combo, gboolean case_sensitive
 )
 {
-	gbool got_match;
+	gboolean got_match;
+	gint pass, row_num, start_row;
+	gchar *s, *needle = NULL;
 	GList *glist;
 	GtkCList *clist;
 	GtkCTree *ctree;
 	GtkCTreeNode *end_node;
-	gint pass, row_num, start_row;
-	gchar *strptr, *needle = NULL;
-
 
 	if((v == NULL) || (find_combo == NULL))
 	    return;
 
-	/* Get pointer to index ctree. */
+	/* Get pointer to index ctree */
 	ctree = (GtkCTree *)v->index_ctree;
 	if(ctree == NULL)
 	    return;
 	else
 	    clist = GTK_CLIST(ctree);
 
-	/* Get needle buffer (coppied). */
-	strptr = gtk_entry_get_text(GTK_ENTRY(find_combo->entry));
-	needle = (strptr != NULL) ? g_strdup(strptr) : NULL;
+	/* Get needle buffer (coppied) */
+	s = gtk_entry_get_text(GTK_ENTRY(find_combo->entry));
+	needle = (s != NULL) ? g_strdup(s) : NULL;
 	if(needle == NULL)
 	    return;
 
@@ -1397,21 +1360,21 @@ static void ViewerDoFindInPagesCB(
 	    strtoupper(needle);
 
 
-	/* Skip if already processing. */
+	/* Skip if already processing */
 	if(v->processing)
 	{
 	    g_free(needle);
 	    return;
 	}
 
-	/* Mark as processing and reset stop count to begin search. */
+	/* Mark as processing and reset stop count to begin search */
 	v->processing = TRUE;
 	v->stop_count = 0;
 	ViewerSetBusy(v);
 	ViewerUpdateMenus(v);
 
 
-	/* Set starting row plus one and the end node. */
+	/* Set starting row plus one and the end node */
 	start_row = 0;
 	end_node = NULL;
 	glist = clist->selection_end;
@@ -1423,16 +1386,15 @@ static void ViewerDoFindInPagesCB(
 	    );
 	    GtkCListRow *clist_row_ptr = (GtkCListRow *)ctree_row_ptr;
 
-
 	    /* Set end node pointer to be the selected node. This will
-	     * be encountered on the find second pass farther below.
+	     * be encountered on the find second pass farther below
 	     */
 	    end_node = (GtkCTreeNode *)glist->data;
 
 	    /* Iterate through the row pointers, to find which row pointer
 	     * matches the selected row pointer obtained from the selected
 	     * tree node. start_row will be incremented to be one past the
-	     * selected row index.
+	     * selected row index
 	     */
 	    while(glist2 != NULL)
 	    {
@@ -1448,7 +1410,7 @@ static void ViewerDoFindInPagesCB(
 	}
 
 
-	/* Iterate for two passes. */
+	/* Iterate for two passes */
 	got_match = FALSE;
 	pass = 0;
 	while(pass < 2)
@@ -1457,7 +1419,6 @@ static void ViewerDoFindInPagesCB(
 	    GtkCTreeRow *ctree_row_ptr;
 	    viewer_index_item_struct *item_ptr;
 
-
 	    row_num = MAX(start_row, 0);
 
 	    for(row_num = MAX(start_row, 0);
@@ -1476,17 +1437,17 @@ static void ViewerDoFindInPagesCB(
 		if(ctree_row_ptr == NULL)
 		    continue;
 
-		/* Expand this node as needed. */
+		/* Expand this node as needed */
 		if(!ctree_row_ptr->expanded && !ctree_row_ptr->is_leaf)
 		{
-		    /* Expand and skip to next node. */
+		    /* Expand and skip to next node */
 		    gtk_ctree_expand(ctree, node);
 		    continue;
 		}
 
-		/* Get item data structure. */
-		item_ptr = (viewer_index_item_struct *)gtk_ctree_node_get_row_data(
-		    ctree, node
+		/* Get item data structure */
+		item_ptr = VIEWER_INDEX_ITEM(
+		    gtk_ctree_node_get_row_data(ctree, node)
 		);
 		if(item_ptr == NULL)
 		    continue;
@@ -1494,7 +1455,7 @@ static void ViewerDoFindInPagesCB(
 		ViewerSetStatusMessage(v, item_ptr->file_name_full);
 
 		/* Check if the string needle exists in the contents of
-		 * the file referenced by the item data structure.
+		 * the file referenced by the item data structure
 		 */
 		got_match = ViewerFindInPagesDoGrep(
 		    item_ptr->file_name_full, needle, case_sensitive
@@ -1505,21 +1466,21 @@ static void ViewerDoFindInPagesCB(
 		    break;
 		}
 
-		/* Update status bar progress activity. */
+		/* Update status bar progress activity */
 		ViewerSetStatusProgress(v, -1.0);
 	    }
 
 	    if(got_match)
 		break;
 
-	    /* Reset start row back to the beginning. */
+	    /* Reset start row back to the beginning */
 	    start_row = 0;
 
-	    /* Go on to second pass. */
+	    /* Go on to second pass */
 	    pass++;
 	}
 
-	/* Deallocate coppied search string. */
+	/* Delete coppied search string */
 	g_free(needle);
 	needle = NULL;
 
@@ -1536,7 +1497,7 @@ static void ViewerDoFindInPagesCB(
  */
 void ViewerFindInPagesActivateCB(GtkWidget *widget, void *data)
 {
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
@@ -1555,10 +1516,10 @@ void ViewerIndexCTreeSelectCB(
 	GtkCTree *ctree, GtkCTreeNode *branch, gint column, gpointer data
 )
 {
-	static gbool reenterant = FALSE;
+	static gboolean reenterant = FALSE;
 	gint row;
 	GtkCList *clist;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if((ctree == NULL) || (v == NULL))
 	    return;
 
@@ -1581,18 +1542,18 @@ void ViewerIndexCTreeSelectCB(
 		 */
 	    }
 
-	    /* Update selected index branch. */
+	    /* Update selected index branch */
 	    v->selected_index_branch = branch;
- 
-	    /* Set DND drag icon. */
-/*
+
+#if 0 
+	    /* Set DND drag icon */
 	    ViewerDNDSetIcon(
 		v,
 		gtk_ctree_node_get_row_data(ctree, branch)
 	    );
- */
+#endif
 
-	    /* Scroll if row not visibile. */
+	    /* Scroll if row not visibile */
 	    row = gtk_clist_find_row_from_data(
 		clist,
 		gtk_ctree_node_get_row_data(ctree, branch)
@@ -1604,8 +1565,8 @@ void ViewerIndexCTreeSelectCB(
 		)
 		    gtk_clist_moveto(
 			clist,
-			row, 0,         /* Row, column. */
-			0.5, 0.0        /* Row, column. */
+			row, 0,         /* Row, column */
+			0.5, 0.0        /* Row, column */
 		    );
 	    }
 
@@ -1613,9 +1574,9 @@ void ViewerIndexCTreeSelectCB(
 
 /* Fetch values for newly selected branch? */
 
-/* Notify about selection. */
+/* Notify about selection */
 
-	    /* Update menus. */
+	    /* Update menus */
 	    ViewerUpdateMenus(v);
 
 	    ViewerSetReady(v);
@@ -1631,8 +1592,8 @@ void ViewerIndexCTreeUnselectCB(
 	GtkCTree *ctree, GtkCTreeNode *branch, gint column, gpointer data
 )
 {
-	static gbool reenterant = FALSE;
-	viewer_struct *v = (viewer_struct *)data;
+	static gboolean reenterant = FALSE;
+	viewer_struct *v = VIEWER(data);
 	if((ctree == NULL) || (v == NULL))
 	    return;
 
@@ -1651,7 +1612,7 @@ void ViewerIndexCTreeUnselectCB(
 	    /* Clear values? */
 
 
-	    /* Update menus. */
+	    /* Update menus */
 	    ViewerUpdateMenus(v);
 	}
 
@@ -1666,8 +1627,8 @@ void ViewerIndexCTreeExpandCB(
 	GtkCTree *ctree, GtkCTreeNode *node, gpointer data
 )
 {
-	static gbool reenterant = FALSE;
-	viewer_struct *v = (viewer_struct *)data;
+	static gboolean reenterant = FALSE;
+	viewer_struct *v = VIEWER(data);
 	if((ctree == NULL) || (v == NULL))
 	    return;
 
@@ -1691,11 +1652,10 @@ void ViewerIndexCTreeExpandCB(
  */
 void ViewerTextChangeCB(GtkEditable *editable, gpointer data)
 {
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
 
 
 
-	return;
 }
