@@ -1,8 +1,6 @@
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
 #include "../include/string.h"
@@ -23,14 +21,14 @@
 #include "config.h"
 
 
-/* DND data command string parsing. */
+/* DND data command string parsing */
 void ViewerIndexCTreeDNDParseCmd(
-	const char *string,
+	const gchar *string,
 	viewer_struct **viewer_ptr,
-	GtkCTreeNode ***branch, int *total_branches
+	GtkCTreeNode ***branch, gint *total_branches
 );
 
-/* DND handling. */
+/* DND handling */
 void ViewerIndexCTreeDNDDataRequestCB(
 	GtkWidget *widget, GdkDragContext *dc,
 	GtkSelectionData *selection_data, guint info, guint t,
@@ -58,76 +56,76 @@ void ViewerDNDDataDeleteCB(
  *      Parses the given string which should have been recieved as
  *      a DND command.
  *
- *	The only the returned array of branches should be free()'ed,
- *	no other returns should be deallocated.
+ *	The only the returned array of branches should be deleted.
  */
 void ViewerIndexCTreeDNDParseCmd(
-	const char *string,
+	const gchar *string,
 	viewer_struct **viewer_ptr,
-	GtkCTreeNode ***branch, int *total_branches
+	GtkCTreeNode ***branch, gint *total_branches
 )
 {
-	u_int32_t addr_val;
-	int i, n, strc;
-	char **strv;
+	guint32 addr_val;
+	gint i, n, strc;
+	gchar **strv;
 
-	/* Reset returns. */
+	/* Reset returns */
 	if(viewer_ptr != NULL)
-	    (*viewer_ptr) = NULL;
+	    *viewer_ptr = NULL;
 	if(branch != NULL)
-	    (*branch) = NULL;
+	    *branch = NULL;
 	if(total_branches != NULL)
-	    (*total_branches) = 0;
+	    *total_branches = 0;
 
 	if(string == NULL)
 	    return;
 
-	if(strcasepfx(string, "error"))
+	if(g_strcasepfx(string, "error"))
 	    return;
 
 	/* Parse command, format is as follows:
+	 *
 	 * <viewer_ptr> <branch_ptr...>
 	 */
 	strv = strexp(string, &strc);
 	if(strv == NULL)
 	    return;
 
-	/* Get viewer_ptr (format in hex with no "0x" prefix). */
+	/* Get viewer_ptr (format in hex with no "0x" prefix) */
 	if(strc > 0)
-	    i = sscanf(strv[0], "%x", (u_int32_t *)&addr_val);
+	    i = sscanf(strv[0], "%x", (guint32 *)&addr_val);
 	else
 	    i = 0;
 	if((i > 0) && (viewer_ptr != NULL))
 	    (*viewer_ptr) = (viewer_struct *)addr_val;
 
 	/* Get list of branch pointers which should be branches
-	 * on the parsed viewer's index ctree.
+	 * on the parsed viewer's index GtkCTree
 	 */
 	if((branch != NULL) && (total_branches != NULL))
 	{
-	    const char *cstrptr;
+	    const gchar *s;
 
-	    /* Start at parsed argument number 1. */
+	    /* Start at parsed argument number 1 */
 	    for(i = 1; i < strc; i++)
 	    {
-		cstrptr = (const char *)strv[i];
-		if(cstrptr == NULL)
+		s = strv[i];
+		if(s == NULL)
 		    continue;
 
-		n = (*total_branches);
-		(*total_branches) = n + 1;
-		(*branch) = (GtkCTreeNode **)realloc(
+		n = *total_branches;
+		*total_branches = n + 1;
+		*branch = (GtkCTreeNode **)realloc(
 		    *branch,
 		    (*total_branches) * sizeof(GtkCTreeNode *)
 		);
-		if((*branch) == NULL)
+		if(*branch == NULL)
 		{
-		    (*total_branches) = 0;
+		    *total_branches = 0;
 		    break;
 		}
 		else
 		{
-		    i = sscanf(cstrptr, "%x", (u_int32_t *)&addr_val);
+		    i = sscanf(s, "%x", (guint32 *)&addr_val);
 		    if(i > 0)
 			(*branch)[n] = (GtkCTreeNode *)addr_val;
 		    else
@@ -136,7 +134,7 @@ void ViewerIndexCTreeDNDParseCmd(
 	    }
 	}
 
-	/* Free exploded string. */
+	/* Delete exploded strings */
 	strlistfree(strv, strc);
 }
 
@@ -150,11 +148,9 @@ void ViewerIndexCTreeDNDDataRequestCB(
 	gpointer data
 )
 {
-	gboolean data_sent = FALSE;
 	gchar *buf;
-	gint buf_len;
 	GtkCTreeNode *branch_ptr;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL) || (dc == NULL))
 	    return;
 
@@ -163,74 +159,45 @@ void ViewerIndexCTreeDNDDataRequestCB(
 
 	if(widget != v->index_ctree)
 	{
-	    fprintf(
-		stderr,
-		"ViewerIndexCTreeDNDDataRequestCB(): widget != v->index_ctree\n"
+	    g_printerr(
+"ViewerIndexCTreeDNDDataRequestCB(): widget != v->index_ctree\n"
 	    );
 	    return;
 	}
 
-	/* Get selected branch on viewer's index ctree.
-	 * Note currently we only allow one selected branch at
-	 * a time.
+	/* Get selected branch on viewer's index GtkCTree
+	 *
+	 * Note currently we only allow one selected branch at a time
 	 */
 	branch_ptr = v->selected_index_branch;
 
-	/* No need to apply values to branch_ptr. */
+	/* No need to apply values to branch_ptr */
 
-	/* Allocate buffer that we will be sending out, containing
-	 * the following command format:
+	/* Format buffer in the following format:
+	 *
 	 * <viewer_ptr> <branch_ptr...>
 	 */
-	buf_len = 24 + (24 * 1);
-	buf = (gchar *)malloc(buf_len * sizeof(gchar));
-	if(buf != NULL)
-	{
-	    char num_str[80];
-
-
-	    /* Format buf. */
-	    (*buf) = '\0';
-	    sprintf(num_str, "%.8x", (guint32)v);
-	    strcat(buf, num_str);
-
-	    if(branch_ptr != NULL)
-	    {
-		strcat(buf, " ");
-		sprintf(num_str, "%.8x", (guint32)branch_ptr);
-		strcat(buf, num_str);
-	    }
-
-	    /* Send out data. */
-	    gtk_selection_data_set(
-		selection_data,
-		GDK_SELECTION_TYPE_STRING,
-		8,              /* 8 bits per character. */
-		buf, strlen(buf)
+	if(branch_ptr != NULL)
+	    buf = g_strdup_printf(
+		"%.8x %.8x",
+		(guint32)v,
+		(guint32)branch_ptr
 	    );
-	    data_sent = TRUE;
-
-	    /* Free buffer. */
-	    free(buf);
-	    buf = NULL;
-	    buf_len = 0;
-	}
-
-	/* Failed to send out data? */
-	if(!data_sent)
-	{
-	    const char *strptr = "Error";
-
-	    gtk_selection_data_set(
-		selection_data,
-		GDK_SELECTION_TYPE_STRING,
-		8,      /* 8 bits per character. */
-		strptr, strlen(strptr)
+	else
+	    buf = g_strdup_printf(
+		"%.8x",
+		(guint32)v
 	    );
-	    data_sent = TRUE;
-	}
 
-	return;
+	/* Send out data */
+	gtk_selection_data_set(
+	    selection_data,
+	    GDK_SELECTION_TYPE_STRING,
+	    8,			/* 8 bits per character */
+	    buf, strlen(buf)
+	);
+
+	g_free(buf);
 }
 
 
@@ -244,19 +211,19 @@ void ViewerViewTextDNDDataRecievedCB(
 )
 {
 	gboolean need_delete = FALSE;
-	int viewer_num;
+	gint viewer_num;
 	gboolean same;
 	GtkWidget *source_widget;
 	GtkEditable *editable;
 	medit_core_struct *core_ptr;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if((widget == NULL) || (v == NULL) || (dc == NULL))
 		return;
 
 	if(!v->initialized)
 	    return;
 
-	/* Important, check if we got data. */
+	/* Important, check if we got data */
 	if(selection_data == NULL)
 	    return;
 	if(selection_data->length < 0)
@@ -272,7 +239,7 @@ void ViewerViewTextDNDDataRecievedCB(
 	if(dc->action != GDK_ACTION_COPY)
 	    need_delete = TRUE;
 
-	/* Get viewer view text widget. */
+	/* Get viewer view text widget */
 	editable = (GtkEditable *)v->view_text;
 
 	/* Check if viewer view text widget matches the destination
@@ -282,12 +249,12 @@ void ViewerViewTextDNDDataRecievedCB(
 	if((void *)editable != (void *)widget)
 	    editable = NULL;
 
-	/* Get pointer to core structure. */
+	/* Get pointer to core structure */
 	core_ptr = (medit_core_struct *)v->core_ptr;
 	if(core_ptr == NULL)
 	    return;
 
-	/* Get viewer number. */
+	/* Get viewer number */
 	for(viewer_num = 0; viewer_num < core_ptr->total_viewers; viewer_num++)
 	{
 	    if(v == core_ptr->viewer[viewer_num])
@@ -306,14 +273,14 @@ void ViewerViewTextDNDDataRecievedCB(
 		editor_struct *src_editor = NULL;
 		GtkCTreeNode **branch = NULL;
 		gint total_branches = 0;
-		gbool	is_branch_file = FALSE,
-			is_branch_header = FALSE,
-			is_branch_section = FALSE;
+		gboolean	is_branch_file = FALSE,
+				is_branch_header = FALSE,
+				is_branch_section = FALSE;
 
 
-		/* Parse command string. */
+		/* Parse command string */
 		EditorDNDParseCmd(
-		    (const char *)selection_data->data,
+		    (const gchar *)selection_data->data,
 		    &src_editor,
 		    &branch, &total_branches
 		);
@@ -323,9 +290,8 @@ void ViewerViewTextDNDDataRecievedCB(
 		{
 		    editor_item_struct *item_ptr;
 
-
 		    /* Check what types of branch item data types we
-		     * just got.
+		     * just got
 		     */
 		    for(i = 0; i < total_branches; i++)
 		    {
@@ -335,7 +301,7 @@ void ViewerViewTextDNDDataRecievedCB(
 			if(item_ptr == NULL)
 			    continue;
 
-			/* Check item type. */
+			/* Check item type */
 			switch(item_ptr->type)
 			{
 			  case EditorItemTypeFile:
@@ -351,7 +317,7 @@ void ViewerViewTextDNDDataRecievedCB(
 			    break;
 			}
 		    }   
-		    /* `No operation' check. */
+		    /* `No operation' check */
 		    if(same)
 		    {
 			/* No such check possible when droping to the
@@ -360,7 +326,7 @@ void ViewerViewTextDNDDataRecievedCB(
 		    }
 
 		    /* ************************************************ */
-		    /* Handle by branch item data type. */
+		    /* Handle by branch item data type */
 		    /* File (which implies trunk)? */
 		    if(is_branch_file)
 		    {
@@ -369,7 +335,7 @@ void ViewerViewTextDNDDataRecievedCB(
 			 */
 			need_delete = FALSE;
 
-			/* Handle only the first branch. */
+			/* Handle only the first branch */
 			if(total_branches > 0)
 			{
 			    /* Call editor's preview procedure on source
@@ -392,7 +358,7 @@ void ViewerViewTextDNDDataRecievedCB(
 			 */
 			need_delete = FALSE;
 
-			/* Handle only the first branch. */
+			/* Handle only the first branch */
 			if(total_branches > 0)
 			{
 			    GtkCTreeNode *trunk;
@@ -417,11 +383,11 @@ void ViewerViewTextDNDDataRecievedCB(
 			}
 		    }
 		    /* ************************************************ */
-		    /* Add support for other types here. */
+		    /* Add support for other types here */
 		}
 
-		/* Free only list of branches from source editor. */
-		free(branch);
+		/* Free only list of branches from source editor */
+		g_free(branch);
 		branch = NULL;
 		total_branches = 0;
 	    }
@@ -431,7 +397,7 @@ void ViewerViewTextDNDDataRecievedCB(
 	    {
 		viewer_struct *src_viewer = NULL;
 		GtkCTreeNode **branch = NULL;
-		int total_branches = 0;
+		gint total_branches = 0;
 
 
 		/* Parse command string. Value of src_viewer points to
@@ -440,47 +406,48 @@ void ViewerViewTextDNDDataRecievedCB(
 		 * ctree.
 		 */   
 		ViewerIndexCTreeDNDParseCmd(
-		    (const char *)selection_data->data,
+		    (const gchar *)selection_data->data,
 		    &src_viewer,
 		    &branch, &total_branches
 		);
 
 		/* Is source viewer valid? */
-		if((src_viewer == NULL) ?
-		    0 : (src_viewer->index_ctree != NULL)
+		if((src_viewer != NULL) ?
+		    (src_viewer->index_ctree != NULL) : FALSE
 		)
 		{
-		    viewer_index_item_struct *item_ptr;
+		    GtkCTree *ctree = GTK_CTREE(src_viewer->index_ctree);
+		    viewer_index_item_struct *item;
 
-		    /* Handle only the first branch. */
+		    /* Handle only the first branch */
 		    if(total_branches > 0)
 		    {
-			/* Get pointer to index clist item structure. */
-			if(branch[0] == NULL)
-			    item_ptr = NULL;
-			else
-			    item_ptr = (viewer_index_item_struct *)gtk_ctree_node_get_row_data(
-				(GtkCTree *)src_viewer->index_ctree,
-				branch[0]
+			/* Get index item */
+			if(branch[0] != NULL)
+			    item = VIEWER_INDEX_ITEM(
+				gtk_ctree_node_get_row_data(ctree, branch[0])
 			    );
+			else
+			    item = NULL;
 
-			/* Check if source viewer's index clist item
-			 * structure is valid and of the right type.
+			/* Check if source viewer's index item is valid
+			 * and of the currect type
 			 */
-			if((item_ptr == NULL) ?
-			    0 : (item_ptr->type == ViewerIndexItemTypeManualPage)
+			if((item != NULL) ?
+			    (item->type == ViewerIndexItemTypeManualPage) : FALSE
 			)
 			{
 			    /* Load manual page into target viewer's
-			     * view text.
+			     * view text
 			     */
 			    ViewerSetBusy(v);
 			    ViewerViewTextRecordScrollPositions(v);
 			    ViewerTextDelete(v, 0, -1);
 			    ViewerTextInsertPosition(v, 0);
 			    ViewerLoadFile(
-				v, item_ptr->file_name_full,
-				item_ptr->file_name_full
+				v,
+				item->file_name_full,
+				item->file_name_full
 			    );
 			    ViewerSetReady(v);
 			}
@@ -488,20 +455,20 @@ void ViewerViewTextDNDDataRecievedCB(
 
 	     
 		    /* Delete branches that came from source editor
-		     * as needed.
+		     * as needed
 		     */
 		    if(need_delete)
 		    {
-			/* Do not delete branches on source viewer's index
-			 * ctree.
+			/* Do not delete branches on source viewer's
+			 * index GtkCTree
 			 */
 		    }
 		}
 
-		/* Free only list of branches from source viewer's
-		 * index ctree.
+		/* Delete only list of branches from source viewer's
+		 * index GtkCTree
 		 */
-		free(branch);
+		g_free(branch);
 		branch = NULL;  
 		total_branches = 0;
  	    }
@@ -515,7 +482,7 @@ void ViewerViewTextDNDDataRecievedCB(
 		    selection_data->data, selection_data->length
 		);
 
-		/* Load manual page into target viewer's view text. */
+		/* Load manual page into target viewer's view text */
 		ViewerSetBusy(v);
 		ViewerViewTextRecordScrollPositions(v);
 		ViewerTextDelete(v, 0, -1);
@@ -527,7 +494,7 @@ void ViewerViewTextDNDDataRecievedCB(
 	    }
 
 	    /* ******************************************************** */
-	    /* Add support for other types of DND here. */
+	    /* Add support for other types of DND here */
 
 
 	}
@@ -542,6 +509,6 @@ void ViewerDNDDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
-	/* Function no longer used. */
+	/* Function no longer used */
 	return;
 }
