@@ -1,11 +1,8 @@
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-
 #include <sys/stat.h>
-#include <sys/types.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "../include/fio.h"
 #include "../include/disk.h"
@@ -21,26 +18,27 @@
 #include "maneditop.h"
 #include "config.h"
 
-static int ViewerLoadProgressCB(long cur, long max, void *data);
-int ViewerLoadFile(
-	viewer_struct *v, const char *filename, const char *name
+
+static gint ViewerLoadProgressCB(glong cur, glong max, gpointer data);
+gint ViewerLoadFile(
+	viewer_struct *v, const gchar *filename, const gchar *name
 );
 
 
 /*
  *	Viewer load progress callback.
  */
-static int ViewerLoadProgressCB(long cur, long max, void *data)
+static gint ViewerLoadProgressCB(glong cur, glong max, void *data)
 {
 	gfloat percent;
-	viewer_struct *v = (viewer_struct *)data;
+	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return(0);
 
-	if(max > 0)
+	if(max > 0l)
 	    percent = (gfloat)cur / (gfloat)max;
 	else
-	    percent = 1.0;
+	    percent = 1.0f;
 
 	ViewerSetStatusProgress(v, percent);
 
@@ -55,20 +53,19 @@ static int ViewerLoadProgressCB(long cur, long max, void *data)
  *
  *	Returns non-zero on error.
  */
-int ViewerLoadFile(
-	viewer_struct *v, const char *filename, const char *name
+gint ViewerLoadFile(
+	viewer_struct *v, const gchar *filename, const gchar *name
 )
 {
-	int status;
+	gint status;
 	FILE *fp;
-	char *strptr;
-	char *buf;
-	int buf_len;
+	gchar *buf;
+	gint buf_len;
 
-	char *prog_tmp_dir;
-	char *stdout_path;
-	char *stderr_path;
-	const char *converter_cmd;
+	gchar *prog_tmp_dir;
+	gchar *stdout_path;
+	gchar *stderr_path;
+	const gchar *converter_cmd;
 	GtkAdjustment *vadj;
 
 	medit_core_struct *core_ptr;
@@ -85,12 +82,12 @@ int ViewerLoadFile(
 	if(v->processing)
 	    return(-1);
 
-	/* Mark as processing. */
+	/* Mark as processing */
 	v->processing = TRUE;
 
 	/* If given filename is an absolute path, then check if it
 	 * exists. This is to allow the converter program to search for
-	 * relative paths.
+	 * relative paths
 	 */
 	if(ISPATHABSOLUTE(filename))
 	{
@@ -108,8 +105,8 @@ int ViewerLoadFile(
 	    return(-1);
 	}
 
-	/* Get Manual Page to output converter command. */
-	converter_cmd = (const char *)PrefParmGetValueP(
+	/* Get Manual Page to output converter command */
+	converter_cmd = (const gchar *)PrefParmGetValueP(
 	    core_ptr->pref,
 	    MEDIT_PREF_PARM_CONVERTERS_MANPAGE_TO_OUTPUT
 	);
@@ -135,7 +132,7 @@ this command under edit->preferences->converters.",
 	}
 
 	/* Create tempory files directory for this program as needed
-	 * (return string needs to be deallocated).
+	 * (return string needs to be deleted).
 	 */
 	prog_tmp_dir = MEditCreateTempDir(core_ptr);
 	if(prog_tmp_dir == NULL)
@@ -155,29 +152,35 @@ Cannot continue with preview.",
 	}
 
 	/* Get standard output file path to output conversion to,
-	 * note that stdout_path needs to be deallocated later.
+	 * note that stdout_path needs to be deleted later
 	 */
-	stdout_path = tempnam(prog_tmp_dir, "pv");
-	stderr_path = tempnam(prog_tmp_dir, "pv");
+	stdout_path = g_strdup(PrefixPaths(
+	    prog_tmp_dir, "preview_stdoutXXXXXX"
+	));
+	mkstemp(stdout_path);
+	stderr_path = g_strdup(PrefixPaths(
+	    prog_tmp_dir, "preview_stderrXXXXXX"
+	));
+	mkstemp(stderr_path);
 
-	/* Deallocate prog_tmp_dir, it is no longer needed. */
-	free(prog_tmp_dir);
+	/* Delete prog_tmp_dir, it is no longer needed */
+	g_free(prog_tmp_dir);
 	prog_tmp_dir = NULL;
 
 	/* No output file path available? */
 	if(stdout_path == NULL)
 	{
-	    free(stdout_path);
-	    free(stderr_path);
+	    g_free(stdout_path);
+	    g_free(stderr_path);
 
 	    v->processing = FALSE;
 	    return(-1);
 	}
 
-	/* Begin converting. */
+	/* Begin converting */
 
 	ViewerSetBusy(v);
-	ViewerSetStatusProgress(v, 0.0);
+	ViewerSetStatusProgress(v, 0.0f);
 	ViewerSetStatusMessage(v, "Converting...");
 
 	/* Convert file specified by filename to groff output as a tempory
@@ -188,29 +191,29 @@ Cannot continue with preview.",
 
 	status = MEditExecuteFmtBlock(
 	    core_ptr,
-	    converter_cmd,	/* Command. */
-	    filename,		/* Filename. */
-	    NULL,		/* Options. */
-	    stdout_path,	/* Stdout path. */
-	    stderr_path		/* Stderr path. */
+	    converter_cmd,	/* Command */
+	    filename,		/* Filename */
+	    NULL,		/* Options */
+	    stdout_path,	/* Stdout path */
+	    stderr_path		/* Stderr path */
 	);
 
 	ViewerSetStatusMessage(v, "Convert done");
 
-	/* If stderr_path exists, notify of error. */
+	/* If stderr_path exists, notify of error */
 	MEditDialogFromFile(core_ptr, stderr_path);
 
 
-	/* Begin loading tempory output file. */
+	/* Begin loading tempory output file */
 
 	/* Error occured during execution or stdout_path does not exist? */
 	if(status || stat(stdout_path, &stat_buf))
 	{
 	    unlink(stdout_path);
-	    free(stdout_path);
+	    g_free(stdout_path);
 	    unlink(stderr_path);
-	    free(stderr_path);
-	    ViewerSetStatusProgress(v, 0.0);
+	    g_free(stderr_path);
+	    ViewerSetStatusProgress(v, 0.0f);
 	    ViewerSetStatusMessage(v, "Load done");
 	    ViewerSetReady(v);
 
@@ -228,15 +231,15 @@ Cannot continue with preview.",
 	if(buf_len < 0)
 	    buf_len = 0;
 
-	/* Allocate memory to load file contents. */
-	buf = (char *)malloc((buf_len + 1) * sizeof(char));
+	/* Allocate memory to load file contents */
+	buf = (gchar *)g_malloc((buf_len + 1) * sizeof(char));
 	if(buf == NULL)
 	{
 	    unlink(stdout_path);
-	    free(stdout_path);
+	    g_free(stdout_path);
 	    unlink(stderr_path);
-	    free(stderr_path);
-	    ViewerSetStatusProgress(v, 0.0);
+	    g_free(stderr_path);
+	    ViewerSetStatusProgress(v, 0.0f);
 	    ViewerSetStatusMessage(v, "Load done");
 	    ViewerSetReady(v);
 
@@ -245,30 +248,27 @@ Cannot continue with preview.",
 	    return(-1);
 	}
 
-	/* Open file. */
+	/* Open file */
 	fp = FOpen(stdout_path, "rb");
 	if(fp == NULL)
 	{
 	    unlink(stdout_path);
-	    free(stdout_path);
+	    g_free(stdout_path);
 	    unlink(stderr_path);
-	    free(stderr_path);
-	    ViewerSetStatusProgress(v, 0.0);
+	    g_free(stderr_path);
+	    ViewerSetStatusProgress(v, 0.0f);
 	    ViewerSetStatusMessage(v, "Load done");
 	    ViewerSetReady(v);
 
-	    free(buf);
+	    g_free(buf);
 
 	    v->processing = FALSE;
 
 	    return(-2);
 	}
 
-	/* Begin reading file data into buffer. */
-	status = (int)fread(
-	    (void *)buf, (size_t)sizeof(char), (size_t)buf_len,
-	    fp
-	);
+	/* Begin reading file data into buffer */
+	status = (gint)fread(buf, sizeof(char), buf_len, fp);
 	if(status < buf_len)
 	{
 	    if(status > 0)
@@ -279,39 +279,39 @@ Cannot continue with preview.",
 	}
 	else
 	{
-	    buf[buf_len] = '\0';    /* Yes its allocated. */
+	    buf[buf_len] = '\0';    /* Yes its allocated */
 	}
 
-	/* Close file. */
+	/* Close file */
 	FClose(fp);
 	fp = NULL;
 
-	/* Remove tempory output file and deallocate output path. */
+	/* Remove tempory output file and delete output path */
 	unlink(stdout_path);
-	free(stdout_path);
+	g_free(stdout_path);
 	stdout_path = NULL;
 
 	unlink(stderr_path);
-	free(stderr_path);
+	g_free(stderr_path);
 	stderr_path = NULL;
 
 	ViewerSetStatusProgress(v, 0.5);
 
 
-	/* Load buffer to viewer. */
+	/* Load buffer to viewer */
 	ViewerTextInsert(
 	    v, buf, buf_len, (void *)v, ViewerLoadProgressCB
 	);
 
 	ViewerSetStatusProgress(v, 1.0);
 
-	/* Deallocate buffer. */
-	free(buf);
+	/* Delete buffer */
+	g_free(buf);
 	buf = NULL;
 	buf_len = 0;
 
 
-	/* Check last manual page path and see if they match new one. */
+	/* Check last manual page path and see if they match new one */
 	if((v->cur_manpage_name != NULL) && (name != NULL))
 	{
 	    /* Name same? */
@@ -319,7 +319,7 @@ Cannot continue with preview.",
 	        1 : !strcmp(v->cur_manpage_name, name)
 	    )
 	    {
-		/* Names match, so scroll to last view_text position. */
+		/* Names match, so scroll to last view_text position */
 		vadj = ((v->view_text == NULL) ?
 		    NULL : GTK_TEXT(v->view_text)->vadj
 		);
@@ -338,33 +338,33 @@ Cannot continue with preview.",
 
 
 
-	/* Record current opened manual page file on viewer. */
+	/* Record current opened manual page file on viewer */
 	if((filename != v->cur_manpage_path) && (filename != NULL))
 	{
-	    free(v->cur_manpage_path);
-	    v->cur_manpage_path = strdup(filename);
+	    g_free(v->cur_manpage_path);
+	    v->cur_manpage_path = g_strdup(filename);
 	}
 
-	/* Record name. */
+	/* Record name */
 	if((name != v->cur_manpage_name) && (name != NULL))
 	{
-	    free(v->cur_manpage_name);
-	    v->cur_manpage_name = strdup(name);
+	    g_free(v->cur_manpage_name);
+	    v->cur_manpage_name = g_strdup(name);
 	}
 
 
-	/* Update last opened path on viewer. */
-	free(v->last_open_path);
-	v->last_open_path = strdup(filename);
+	/* Update last opened path on viewer */
+	g_free(v->last_open_path);
+	v->last_open_path = g_strdup(filename);
 	if(v->last_open_path != NULL)
 	{
-	    strptr = strrchr(v->last_open_path, DIR_DELIMINATOR);
-	    if(strptr != NULL)
-		(*strptr) = '\0';
+	    gchar *s = strrchr(v->last_open_path, G_DIR_SEPARATOR);
+	    if(s != NULL)
+		*s = '\0';
 	}
 
 
-	ViewerSetStatusProgress(v, 0.0);
+	ViewerSetStatusProgress(v, 0.0f);
 	ViewerSetStatusMessage(v, "Load done");
 
 	v->processing = FALSE;
@@ -372,7 +372,7 @@ Cannot continue with preview.",
 	ViewerUpdateMenus(v);
 	ViewerSetReady(v);
 
-	/* Switch to viewer page. */
+	/* Switch to viewer page */
 	if(v->main_notebook != NULL)
 	{
 	    gtk_notebook_set_page(
@@ -380,18 +380,16 @@ Cannot continue with preview.",
 	    );
 	}
 
-	/* Update text on current manpage combo. */
+	/* Update text on current manpage combo */
 	if(v->manpage_combo != NULL)
 	{
 	    GtkCombo *combo = (GtkCombo *)v->manpage_combo;
-	    const char *tmp_str;
-
-	    tmp_str = (const char *)strrchr((const char *)filename, ' ');
-	    if(tmp_str != NULL)
+	    const gchar *s = strrchr(filename, ' ');
+	    if(s != NULL)
 	    {
-		tmp_str += 1;
-	        GUIComboAddItem(GTK_WIDGET(combo), tmp_str);
-	        gtk_entry_set_text(GTK_ENTRY(combo->entry), tmp_str);
+		s++;
+	        GUIComboAddItem(GTK_WIDGET(combo), s);
+	        gtk_entry_set_text(GTK_ENTRY(combo->entry), s);
 	    }
 	    else
 	    {
@@ -400,16 +398,19 @@ Cannot continue with preview.",
 	    }
 	    gtk_editable_select_region(GTK_EDITABLE(combo->entry), 0, -1);
 
-	    /* Also if the manpage_combo now contains a full path, select
-	     * the `exact' section on the section combo.
+	    /* Also, if manpage_combo specifies a full path, then select
+	     * the exact section on the section combo
 	     */
 	    if(v->section_combo != NULL)
 	    {
-		tmp_str = gtk_entry_get_text(GTK_ENTRY(combo->entry));
-		if((*tmp_str) == DIR_DELIMINATOR)
+		GtkEntry *manpage_entry = GTK_ENTRY(combo->entry);
+
+		s = gtk_entry_get_text(manpage_entry);
+		if((s != NULL) ? (*s == G_DIR_SEPARATOR) : FALSE)
 		{
+		    GtkCombo *section_combo = GTK_COMBO(v->section_combo);
 		    gtk_entry_set_text(
-			GTK_ENTRY(GTK_COMBO(v->section_combo)->entry),
+			GTK_ENTRY(section_combo->entry),
 			MEDIT_SECT_NAME_EXACT
 		    );
 		}
